@@ -38,7 +38,7 @@
 bool SKGBookmarkPluginDockWidget::m_middleClick = false;
 
 SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
-    : SKGTabPage(iDocument), m_mainMenu(NULL), m_actDelete(NULL), m_actRename(NULL), m_actChangeIcon(NULL), m_actAddBookmark(NULL),
+    : SKGWidget(iDocument), m_mainMenu(NULL), m_actDelete(NULL), m_actRename(NULL), m_actChangeIcon(NULL), m_actAddBookmark(NULL), m_actAddBookmarks(NULL),
       m_actAddBookmarkGroup(NULL), m_actSetAutostart(NULL), m_actUnsetAutostart(NULL)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget");
@@ -46,25 +46,72 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
+    QPalette palette = QApplication::palette();
+    palette.setColor(QPalette::Base, Qt::transparent);
+    ui.kBookmarksList->setPalette(palette);
+    ui.kBookmarksList->setRootIsDecorated(false);
+    ui.kBookmarksList->setAnimated(false); //Not compatible with double click
+
     ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
     //Build contextual menu
     ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(showMenu(const QPoint&)));
 
+    m_mainMenu = new KMenu(ui.kBookmarksList);
+    QAction* actExpandAll = m_mainMenu->addAction(KIcon("format-indent-more"), i18nc("Noun, user action", "Expand all"));
+    connect(actExpandAll, SIGNAL(triggered(bool)), ui.kBookmarksList, SLOT(expandAll()));
+
+    QAction* actCollapseAll = m_mainMenu->addAction(KIcon("format-indent-less"), i18nc("Noun, user action", "Collapse all"));
+    connect(actCollapseAll, SIGNAL(triggered(bool)), ui.kBookmarksList, SLOT(collapseAll()));
+    ui.kBookmarksList->insertAction(0, actCollapseAll);
+
+    m_mainMenu->addSeparator();
+
+    m_actAddBookmark = m_mainMenu->addAction(KIcon("list-add"), i18nc("Verb", "Bookmark current page"));
+    connect(m_actAddBookmark, SIGNAL(triggered(bool)), this, SLOT(onAddBookmark()));
+
+    m_actAddBookmarks = m_mainMenu->addAction(KIcon("list-add"), i18nc("Verb", "Bookmark all pages"));
+    connect(m_actAddBookmarks, SIGNAL(triggered(bool)), this, SLOT(onAddBookmarks()));
+
+    m_actAddBookmarkGroup = m_mainMenu->addAction(KIcon("folder-new"), i18nc("Verb", "Add bookmark group"));
+    connect(m_actAddBookmarkGroup, SIGNAL(triggered(bool)), this, SLOT(onAddBookmarkGroup()));
+
+    m_mainMenu->addSeparator();
+
+    m_actDelete = m_mainMenu->addAction(KIcon("list-remove"), i18nc("Verb, delete an item", "Delete"));
+    connect(m_actDelete, SIGNAL(triggered(bool)), this, SLOT(onRemoveBookmark()));
+
+    m_mainMenu->addSeparator();
+
+    m_actSetAutostart = m_mainMenu->addAction(KIcon("user-online"), i18nc("Verb, automatically load when the application is started", "Autostart"));
+    connect(m_actSetAutostart, SIGNAL(triggered(bool)), this, SLOT(onSetAutostart()));
+
+    m_actUnsetAutostart = m_mainMenu->addAction(KIcon("user-offline"), i18nc("Verb", "Remove Autostart"));
+    connect(m_actUnsetAutostart, SIGNAL(triggered(bool)), this, SLOT(onUnsetAutostart()));
+
+    m_actRename = m_mainMenu->addAction(KIcon("edit-rename"), i18nc("Verb, change the name of an item", "Rename"));
+    connect(m_actRename, SIGNAL(triggered(bool)), this, SLOT(onRenameBookmark()));
+
+    m_actChangeIcon = m_mainMenu->addAction(KIcon("view-media-visualization"), i18nc("Verb, change the icon of an item", "Change icon..."));
+    connect(m_actChangeIcon, SIGNAL(triggered(bool)), this, SLOT(onChangeIconBookmark()));
+
+    m_mainMenu->addSeparator();
+    m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("tab_overwritebookmark"));
+
     //Add model
-    m_modelview = new SKGObjectModelBase(getDocument(), "v_node", "1=1 ORDER BY f_sortorder, t_name", this, "r_node_id");
+    m_modelview = new SKGObjectModelBase(getDocument(), "v_node", "1=1 ORDER BY f_sortorder, t_name", this, "rd_node_id");
     SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel(this);
     modelproxy->setSourceModel(m_modelview);
     ui.kBookmarksList->setModel(modelproxy);
 
     ui.kFilterEdit->setProxy(modelproxy);
 
-    connect(ui.kBookmarksList->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)), this, SLOT(refresh()));
+    connect(ui.kBookmarksList, SIGNAL(selectionChangedDelayed()), this, SLOT(refresh()));
     connect(ui.kBookmarksList, SIGNAL(pressed(QModelIndex)), this, SLOT(onBeforeOpenBookmark()));
     connect(ui.kBookmarksList, SIGNAL(clicked(QModelIndex)), this, SLOT(onOpenBookmark(QModelIndex)));
     connect(ui.kBookmarksList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onOpenBookmarkFolder(QModelIndex)));
-    connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(onPageChanged()));
+    connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(onPageChanged()), Qt::QueuedConnection);
 
     connect(m_modelview, SIGNAL(beforeReset()), ui.kBookmarksList, SLOT(saveSelection()));
     connect(m_modelview, SIGNAL(afterReset()), ui.kBookmarksList, SLOT(resetSelection()));
@@ -80,6 +127,7 @@ SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
     m_actRename = NULL;
     m_actChangeIcon = NULL;
     m_actAddBookmark = NULL;
+    m_actAddBookmarks = NULL;
     m_actAddBookmarkGroup = NULL;
     m_actSetAutostart = NULL;
     m_actUnsetAutostart = NULL;
@@ -93,35 +141,7 @@ QWidget* SKGBookmarkPluginDockWidget::mainWidget() const
 
 void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
 {
-    if(!m_mainMenu) {
-        m_mainMenu = new KMenu(ui.kBookmarksList);
-        m_actDelete = m_mainMenu->addAction(KIcon("list-remove"), i18nc("Verb, delete an item", "Delete"));
-        connect(m_actDelete, SIGNAL(triggered(bool)), this, SLOT(onRemoveBookmark()));
-
-        m_actRename = m_mainMenu->addAction(KIcon("edit-rename"), i18nc("Verb, change the name of an item", "Rename"));
-        connect(m_actRename, SIGNAL(triggered(bool)), this, SLOT(onRenameBookmark()));
-
-        m_actChangeIcon = m_mainMenu->addAction(KIcon("view-media-visualization"), i18nc("Verb, change the icon of an item", "Change icon..."));
-        connect(m_actChangeIcon, SIGNAL(triggered(bool)), this, SLOT(onChangeIconBookmark()));
-
-        m_mainMenu->addSeparator();
-        m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("tab_overwritebookmark"));
-        m_mainMenu->addSeparator();
-
-        m_actAddBookmarkGroup = m_mainMenu->addAction(KIcon("folder-new"), i18nc("Verb", "Add bookmark group"));
-        connect(m_actAddBookmarkGroup, SIGNAL(triggered(bool)), this, SLOT(onAddBookmarkGroup()));
-
-        m_actAddBookmark = m_mainMenu->addAction(KIcon("list-add"), i18nc("Verb", "Bookmark current page"));
-        connect(m_actAddBookmark, SIGNAL(triggered(bool)), this, SLOT(onAddBookmark()));
-
-        m_actSetAutostart = m_mainMenu->addAction(KIcon("user-online"), i18nc("Verb, automatically load when the application is started", "Autostart"));
-        connect(m_actSetAutostart, SIGNAL(triggered(bool)), this, SLOT(onSetAutostart()));
-
-        m_actUnsetAutostart = m_mainMenu->addAction(KIcon("user-offline"), i18nc("Verb", "Remove Autostart"));
-        connect(m_actUnsetAutostart, SIGNAL(triggered(bool)), this, SLOT(onUnsetAutostart()));
-    }
     if(m_mainMenu) m_mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
-
 }
 
 void SKGBookmarkPluginDockWidget::onSetAutostart()
@@ -187,7 +207,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
         QStringList data = SKGServices::splitCSVLine(selectedNode.getData());
         if(data.count() > 2) {
             //This bookmark has information ==> we open it
-            SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()));
+            SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()), i == nodes.count() - 1);
             if(page) {
                 SKGTabWidget* tab = dynamic_cast<SKGTabWidget*>(SKGMainPanel::getMainPanel()->centralWidget());
                 if(tab) tab->setTabIcon(SKGMainPanel::getMainPanel()->currentPageIndex(), selectedNode.getIcon());
@@ -273,15 +293,12 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGBookmarkPluginDockWidget::onAddBookmark()
+void SKGBookmarkPluginDockWidget::onAddBookmarks()
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmark");
     SKGError err;
-
-    //Get current page
-    SKGNodeObject node;
-    SKGTabPage* currentPage = SKGMainPanel::getMainPanel()->currentPage();
-    if(currentPage) {
+    SKGNodeObject rootNode;
+    {
         //Get current selection name
         QString name;
         SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
@@ -298,8 +315,73 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
 
         //Add current name
         if(!name.isEmpty()) name += OBJECTSEPARATOR;
+        name += i18nc("Default name for bookmark", "New bookmark");
 
-        QString defaultName = currentPage->objectName();
+        //Create bookmark folder
+        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmarks creation"), err);
+        err = SKGNodeObject::createPathNode(getDocument(), name, rootNode, true);
+        int nb = SKGMainPanel::getMainPanel()->countPages();
+        for(int i = 0; !err && i < nb; ++i) {
+            SKGNodeObject node;
+            err = createNodeFromPage(SKGMainPanel::getMainPanel()->page(i), rootNode, node);
+        }
+    }
+
+    //status bar
+    if(!err) {
+        ui.kBookmarksList->selectObject(rootNode.getUniqueID());
+        err = SKGError(0, i18nc("Successful message after an user action", "Bookmarks created"));
+    }
+    SKGMainPanel::displayErrorMessage(err);
+}
+
+void SKGBookmarkPluginDockWidget::onAddBookmark()
+{
+    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onAddBookmark");
+    SKGError err;
+
+    //Get current page
+    SKGNodeObject node;
+    {
+        //Get current selection
+        SKGNodeObject parentNode;
+        SKGObjectBase::SKGListSKGObjectBase bookmarks = getSelectedObjects();
+        if(bookmarks.count()) parentNode = bookmarks.at(0);
+
+        //Create bookmark
+        err = createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
+    }
+    //status bar
+    if(!err) {
+        ui.kBookmarksList->selectObject(node.getUniqueID());
+        err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
+    }
+    SKGMainPanel::displayErrorMessage(err);
+}
+
+SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, const SKGNodeObject& iParentNode, SKGNodeObject& oCreatedNode) const
+{
+    SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::createNodeFromPage");
+    SKGError err;
+
+    //Get current page
+    oCreatedNode = SKGNodeObject();
+    if(iPage) {
+        //Get current selection name
+        QString name;
+        SKGNodeObject parentNode = iParentNode;
+        if(!parentNode.isFolder()) {
+            //This is not a folder, we have to take the parent
+            SKGNodeObject parentNodeTmp;
+            parentNode.getParentNode(parentNodeTmp);
+            parentNode = parentNodeTmp;
+        }
+        name = parentNode.getFullName();
+
+        //Add current name
+        if(!name.isEmpty()) name += OBJECTSEPARATOR;
+
+        QString defaultName = iPage->objectName();
         QString defaultIcon;
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(defaultName);
         if(plugin) {
@@ -310,24 +392,18 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
 
         //Create bookmark
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err);
-        err = SKGNodeObject::createPathNode(getDocument(), name, node, true);
+        err = SKGNodeObject::createPathNode(getDocument(), name, oCreatedNode, true);
         if(!err) {
-            QString value = SKGServices::stringToCsv(currentPage->objectName()) % ';' %
+            QString value = SKGServices::stringToCsv(iPage->objectName()) % ';' %
                             SKGServices::stringToCsv(defaultName) % ';' %
-                            SKGServices::stringToCsv(currentPage->getState());
+                            SKGServices::stringToCsv(iPage->getState());
 
-            err = node.setData(value);
-            if(!err) err = node.setIcon(defaultIcon);
-            if(!err) err = node.save();
+            err = oCreatedNode.setData(value);
+            if(!err) err = oCreatedNode.setIcon(defaultIcon);
+            if(!err) err = oCreatedNode.save();
         }
     }
-
-    //status bar
-    if(!err) {
-        ui.kBookmarksList->selectObject(node.getUniqueID());
-        err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
-    }
-    SKGMainPanel::displayErrorMessage(err);
+    return err;
 }
 
 void SKGBookmarkPluginDockWidget::onRenameBookmark()
@@ -402,6 +478,7 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
     bool testAdd = getDocument()->getDatabase() != NULL && nbSelectedObjects <= 1;
     if(m_actAddBookmarkGroup) m_actAddBookmarkGroup->setEnabled(testAdd);
     if(m_actAddBookmark) m_actAddBookmark->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
+    if(m_actAddBookmarks) m_actAddBookmarks->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
     if(m_actDelete) m_actDelete->setEnabled(nbSelectedObjects > 0);
     if(m_actRename) m_actRename->setEnabled(nbSelectedObjects == 1);
     if(m_actChangeIcon) m_actChangeIcon->setEnabled(nbSelectedObjects == 1);
@@ -418,8 +495,8 @@ void SKGBookmarkPluginDockWidget::refresh()
         if(m_actSetAutostart) m_actSetAutostart->setEnabled(node.getAttribute("t_autostart") != "Y");
         if(m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(node.getAttribute("t_autostart") == "Y");
     } else {
-        if(m_actSetAutostart) m_actSetAutostart->setEnabled(false);
-        if(m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(false);
+        if(m_actSetAutostart) m_actSetAutostart->setEnabled(nbSelectedObjects > 1);
+        if(m_actUnsetAutostart) m_actUnsetAutostart->setEnabled(nbSelectedObjects > 1);
 
     }
 
