@@ -79,10 +79,8 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     m_currentDocument = iDocument;
     if(m_currentDocument == NULL) return false;
 
-    KComponentData data = SKGFilePluginFactory::componentData();
-    const_cast<KAboutData*>(data.aboutData())->setProgramName(ki18n("%1").subs(KGlobal::mainComponent().aboutData()->programName()));
-    setComponentData(data);
-    setXMLFile("skg_file.rc");
+    setComponentData(KGlobal::mainComponent());
+    setXMLFile("../skg_file/skg_file.rc");
 
     //Menu
     KAction* opennew = KStandardAction::openNew(this, SLOT(actionNew()), actionCollection());
@@ -372,7 +370,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
             err = m_currentDocument->load(fileName, "", restoreTmpFile);
             QApplication::restoreOverrideCursor();
 
-            if(!!err && err.getReturnCode() != ERR_WRITEACCESS) {
+            if(err && err.getReturnCode() == ERR_ENCRYPTION) {
                 m_currentDocument->close();
 
                 //Open failed
@@ -387,7 +385,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                     if(useKWallet) {
                         SKGTRACEINRC(10, "SKGFilePlugin::actionOpen-get kwallet passport", err);
                         //Use KWallet
-                        QString walletName = skgfile_settings::selectedWallet();
+                        QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                         if(walletName.isEmpty()) walletName = "kdewallet";
                         KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
                         if(w) {
@@ -419,7 +417,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
 
                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                         err = m_currentDocument->load(fileName, pwd, restoreTmpFile);
-                        if(!!err) {
+                        if(err) {
                             additionalMessage = i18nc("The user did not provide the correct password", "<b>Wrong password.</b>\n");
                             useKWallet = false;
                         }
@@ -427,7 +425,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
 
                         if(splashScreen) splashScreen->show();
                     }
-                } while(!!err);
+                } while(err);
             }
 
             //status bar
@@ -446,7 +444,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                 //Store password if KDE wallet if needed
                 if(skgfile_settings::storeInKdeWallet() && !useKWallet) {
                     //Use KWallet
-                    QString walletName = skgfile_settings::selectedWallet();
+                    QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                     if(walletName.isEmpty()) walletName = "kdewallet";
                     KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
                     if(w) {
@@ -491,17 +489,17 @@ void SKGFilePlugin::actionChangePassword()
     }
 }
 
-QList< SKGInterfacePlugin::SKGAdvice > SKGFilePlugin::advices() const
+SKGAdviceList SKGFilePlugin::advices() const
 {
     SKGTRACEIN(10, "SKGFilePlugin::advices");
-    QList< SKGInterfacePlugin::SKGAdvice > output;
+    SKGAdviceList output;
 
     //Backup
-    SKGInterfacePlugin::SKGAdvice ad;
-    ad.uuid = "skgfileplugin_notvalidated";
-    ad.priority = 2;
-    ad.shortMessage = i18nc("Advice to the user that he should backup his document", "Backup your document");
-    ad.longMessage = i18nc("Explain the user that he should backup his document", "Don't forget to backup your document on an other device.");
+    SKGAdvice ad;
+    ad.setUUID("skgfileplugin_notvalidated");
+    ad.setPriority(2);
+    ad.setShortMessage(i18nc("Advice to the user that he should backup his document", "Backup your document"));
+    ad.setLongMessage(i18nc("Explain the user that he should backup his document", "Don't forget to backup your document on an other device."));
     output.push_back(ad);
 
     return output;
