@@ -511,7 +511,7 @@ SKGError SKGImportPluginGnc::importFile()
                                     int p = SKGServices::stringToInt(scheduleMult.text());
                                     SKGRecurrentOperationObject::PeriodUnit punit = SKGRecurrentOperationObject::DAY;
                                     if(schedulePeriod.text() == "month") punit = SKGRecurrentOperationObject::MONTH;
-                                    else if(schedulePeriod.text() == "week") p *= 7;
+                                    else if(schedulePeriod.text() == "week") punit = SKGRecurrentOperationObject::WEEK;
 
                                     err = recuOperation.setPeriodIncrement(p);
                                     if(!err) err = recuOperation.setPeriodUnit(punit);
