@@ -50,8 +50,7 @@ SKGImportPluginGsb::SKGImportPluginGsb(QObject* iImporter, const QVariantList& i
 }
 
 SKGImportPluginGsb::~SKGImportPluginGsb()
-{
-}
+{}
 
 bool SKGImportPluginGsb::isImportPossible()
 {
@@ -112,6 +111,8 @@ SKGError SKGImportPluginGsb::importFile()
             QMap<QString, SKGPayeeObject> mapIdPayee;
             QMap<QString, QString> mapIdMode;
 
+            //Specifications: http://wiki.grisbi.org/doku.php?id=docs:dev:format_gsb
+
             //Step 1-Create units
             if(!err) {
                 QDomNodeList currencyList = docElem.elementsByTagName("Currency");
@@ -300,28 +301,35 @@ SKGError SKGImportPluginGsb::importFile()
                     QDomElement transaction = transactionList.at(i).toElement();
 
                     //Creation of the operation
-                    SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
                     SKGOperationObject opObj;
-                    if(!err) err = account.addOperation(opObj);
-                    if(!err) err = opObj.setDate(QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy"));
-                    if(!err) err = opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]);
-                    if(!err) err = opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]);
-                    if(!err) err = opObj.setMode(mapIdMode[getAttribute(transaction,  "Pn")]);
-                    if(!err) err = opObj.setNumber(SKGServices::stringToInt(getAttribute(transaction,  "Pc")));
-                    if(!err) err = opObj.setComment(getAttribute(transaction,  "No"));
-                    if(!err) err = opObj.setImported(true);
-                    if(!err) err = opObj.setImportID("GSB-" % getAttribute(transaction,  "Nb"));
-                    if(!err) err = opObj.setStatus(getAttribute(transaction,  "Re") == "0" ? SKGOperationObject::NONE : SKGOperationObject::CHECKED);
-                    if(!err) err = opObj.setGroupOperation(mapIdOperation[getAttribute(transaction,  "Trt")]);
-                    if(!err) err = opObj.save();
+                    QString parentOpId = getAttribute(transaction,  "Mo");
+                    if(parentOpId == "0") {
+                        SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
+                        if(!err) err = account.addOperation(opObj);
+                        if(!err) err = opObj.setDate(QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy"));
+                        if(!err) err = opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]);
+                        if(!err) err = opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]);
+                        if(!err) err = opObj.setMode(mapIdMode[getAttribute(transaction,  "Pn")]);
+                        if(!err) err = opObj.setNumber(SKGServices::stringToInt(getAttribute(transaction,  "Pc")));
+                        if(!err) err = opObj.setComment(getAttribute(transaction,  "No"));
+                        if(!err) err = opObj.setImported(true);
+                        if(!err) err = opObj.setImportID("GSB-" % getAttribute(transaction,  "Nb"));
+                        if(!err) err = opObj.setStatus(getAttribute(transaction,  "Re") == "0" ? SKGOperationObject::NONE : SKGOperationObject::CHECKED);
+                        if(!err) err = opObj.setGroupOperation(mapIdOperation[getAttribute(transaction,  "Trt")]);
+                        if(!err) err = opObj.save();
+                    } else {
+                        opObj = mapIdOperation[parentOpId];
+                    }
 
-                    SKGSubOperationObject subObj;
-                    if(!err) err = opObj.addSubOperation(subObj);
-                    QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(transaction,  "Ca")) + SKGServices::stringToInt(getAttribute(transaction,  "Sca")));
-                    if(!err) err = subObj.setCategory(mapIdCategory[id]);
-                    if(!err) err = subObj.setComment(getAttribute(transaction,  "No"));
-                    if(!err) err = subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am")));
-                    if(!err) err = subObj.save();
+                    if(getAttribute(transaction,  "Br") == "0") {
+                        SKGSubOperationObject subObj;
+                        if(!err) err = opObj.addSubOperation(subObj);
+                        QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(transaction,  "Ca")) + SKGServices::stringToInt(getAttribute(transaction,  "Sca")));
+                        if(!err) err = subObj.setCategory(mapIdCategory[id]);
+                        if(!err) err = subObj.setComment(getAttribute(transaction,  "No"));
+                        if(!err) err = subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am")));
+                        if(!err) err = subObj.save();
+                    }
 
                     mapIdOperation[getAttribute(transaction,  "Nb")] = opObj;
 
@@ -408,8 +416,7 @@ SKGError SKGImportPluginGsb::importFile()
                             if(!err) err = recuObj.setTimeLimit(1);
 
                         } else if(Pe == "1") {
-                            occu = 7;
-                            period = SKGRecurrentOperationObject::DAY;
+                            period = SKGRecurrentOperationObject::WEEK;
                         } else if(Pe == "2") {
                             period = SKGRecurrentOperationObject::MONTH;
                         } else if(Pe == "3") {
@@ -425,10 +432,8 @@ SKGError SKGImportPluginGsb::importFile()
                             occu = SKGServices::stringToInt(getAttribute(transaction,  "Pep"));
                             QString Pei = getAttribute(transaction,  "Pei");
                             if(Pei == "0") period = SKGRecurrentOperationObject::DAY;
-                            else if(Pei == "1") {
-                                period = SKGRecurrentOperationObject::DAY;
-                                occu *= 7;
-                            } else if(Pei == "2") period = SKGRecurrentOperationObject::MONTH;
+                            else if(Pei == "1") period = SKGRecurrentOperationObject::WEEK;
+                            else if(Pei == "2") period = SKGRecurrentOperationObject::MONTH;
                             else period = SKGRecurrentOperationObject::YEAR;
                         }
 
@@ -472,7 +477,7 @@ QString SKGImportPluginGsb::getAttribute(const QDomElement& iElement, const QStr
 }
 QString SKGImportPluginGsb::getMimeTypeFilter() const
 {
-    return SKGImportPlugin::getMimeTypeFilter();
+    return "*.gsb|" % i18nc("A file format", "Grisbi file");
 }
 
 #include "skgimportplugingsb.moc"
