@@ -32,17 +32,15 @@
 
 #include <QDomDocument>
 #include <QFileInfo>
+#include <qmath.h>
 #include <qfileinfo.h>
 
-#include <math.h>
-
 QSet<QString> SKGImportPluginKmy::m_opTreated;
 QMap<QString, SKGUnitObject> SKGImportPluginKmy::m_mapIdUnit;
 QMap<QString, SKGAccountObject> SKGImportPluginKmy::m_mapIdAccount;
 QMap<QString, SKGCategoryObject> SKGImportPluginKmy::m_mapIdCategory;
 QMap<QString, SKGPayeeObject> SKGImportPluginKmy::m_mapIdPayee;
 
-
 /**
  * This plugin factory.
  */
@@ -60,8 +58,7 @@ SKGImportPluginKmy::SKGImportPluginKmy(QObject* iImporter, const QVariantList& i
 }
 
 SKGImportPluginKmy::~SKGImportPluginKmy()
-{
-}
+{}
 
 bool SKGImportPluginKmy::isImportPossible()
 {
@@ -391,12 +388,10 @@ SKGError SKGImportPluginKmy::importFile()
                                 if(!err) err = recuObj.timeLimit(true);
                                 if(!err) err = recuObj.setTimeLimit(1);
                             } else if(occuType == "2") period = SKGRecurrentOperationObject::DAY;
-                            else if(occuType == "4") {
-                                period = SKGRecurrentOperationObject::DAY;
-                                occu *= 7;
-                            } else if(occuType == "18") {
-                                period = SKGRecurrentOperationObject::DAY;
-                                occu *= 15;
+                            else if(occuType == "4") period = SKGRecurrentOperationObject::WEEK;
+                            else if(occuType == "18") {
+                                period = SKGRecurrentOperationObject::WEEK;
+                                occu *= 2;
                             } else period = SKGRecurrentOperationObject::YEAR;
 
 
@@ -1085,6 +1080,7 @@ SKGError SKGImportPluginKmy::exportFile()
                             int occu = obj.getPeriodIncrement();
                             SKGRecurrentOperationObject::PeriodUnit punit = obj.getPeriodUnit();
                             if(punit == SKGRecurrentOperationObject::MONTH) occuType = "32";
+                            else if(punit == SKGRecurrentOperationObject::WEEK) occuType = '4';
                             else if(punit == SKGRecurrentOperationObject::DAY) occuType = '2';
                             else occuType = "16384";
 
@@ -1171,7 +1167,7 @@ SKGError SKGImportPluginKmy::exportFile()
 
                         QDomElement period = doc.createElement("PERIOD");
                         account.appendChild(period);
-                        period.setAttribute("amount", SKGImportPluginKmy::kmyValue(fabs(obj.getBudgetedAmount())));
+                        period.setAttribute("amount", SKGImportPluginKmy::kmyValue(qAbs(obj.getBudgetedAmount())));
                         period.setAttribute("start", yearString % '-' % (obj.getMonth() == 0 ? "01" : monthString) % "-01");
 
                         if(!err) err = m_importer->getDocument()->stepForward(i + 1);
@@ -1432,7 +1428,7 @@ QString SKGImportPluginKmy::kmyValue(double iValue)
     QString output;
     for(int i = 0; output.isEmpty() && i < 11; ++i) {
         QString d = SKGServices::doubleToString(pow(10, i) * iValue);
-        if(d.indexOf('.') == -1) output = d % '/' % SKGServices::intToString(pow(10, i));
+        if(d.indexOf('.') == -1) output = d % '/' % SKGServices::intToString(qPow(10, i));
     }
     return output;
 }
