@@ -358,13 +358,13 @@ SKGError SKGImportPluginMmb::importFile()
                                     switch(repeats) {
                                     case 1:
                                         //Weekly
-                                        err = recu.setPeriodUnit(SKGRecurrentOperationObject::DAY);
-                                        if(!err) err = recu.setPeriodIncrement(7);
+                                        err = recu.setPeriodUnit(SKGRecurrentOperationObject::WEEK);
+                                        if(!err) err = recu.setPeriodIncrement(1);
                                         break;
                                     case 2:
                                         //Bi-Weekly
-                                        err = recu.setPeriodUnit(SKGRecurrentOperationObject::DAY);
-                                        if(!err) err = recu.setPeriodIncrement(2 * 7);
+                                        err = recu.setPeriodUnit(SKGRecurrentOperationObject::WEEK);
+                                        if(!err) err = recu.setPeriodIncrement(2);
                                         break;
                                     case 3:
                                         //Monthly
@@ -398,8 +398,8 @@ SKGError SKGImportPluginMmb::importFile()
                                         break;
                                     case 9:
                                         //Four weeks
-                                        err = recu.setPeriodUnit(SKGRecurrentOperationObject::DAY);
-                                        if(!err) err = recu.setPeriodIncrement(4 * 7);
+                                        err = recu.setPeriodUnit(SKGRecurrentOperationObject::WEEK);
+                                        if(!err) err = recu.setPeriodIncrement(4);
                                         break;
                                     case 10:
                                         //Daily
