@@ -145,7 +145,7 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
 
 int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void * pv)
 {
-    if(!!SKGImportPluginOfx::m_ofxError) return 0;
+    if(SKGImportPluginOfx::m_ofxError) return 0;
     SKGTRACEINRC(5, "SKGImportPluginOfx::ofxStatementCallback", SKGImportPluginOfx::m_ofxError);
 
     SKGImportExportManager* impotExporter = static_cast<SKGImportExportManager*>(pv);
@@ -173,7 +173,7 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void
 
 int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void * pv)
 {
-    if(!!SKGImportPluginOfx::m_ofxError) return 0;
+    if(SKGImportPluginOfx::m_ofxError) return 0;
     SKGTRACEINRC(5, "SKGImportPluginOfx::ofxAccountCallback", SKGImportPluginOfx::m_ofxError);
 
     SKGImportExportManager* impotExporter = static_cast<SKGImportExportManager*>(pv);
@@ -285,7 +285,7 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void * pv
 
 int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, void * pv)
 {
-    if(!!SKGImportPluginOfx::m_ofxError) return 0;
+    if(SKGImportPluginOfx::m_ofxError) return 0;
     SKGTRACEINRC(5, "SKGImportPluginOfx::ofxTransactionCallback", SKGImportPluginOfx::m_ofxError);
 
     SKGImportExportManager* impotExporter = static_cast<SKGImportExportManager*>(pv);
