@@ -242,7 +242,7 @@ SKGError SKGImportPluginQif::importFile()
                             //Check if the account already exist
                             SKGAccountObject account2;
                             err = SKGNamedObject::getObjectByName(m_importer->getDocument(), "account", val, account2);
-                            if(!!err) {
+                            if(err) {
                                 //Create account
                                 SKGBankObject bank(m_importer->getDocument());
                                 err = bank.setName(i18nc("Noun",  "Bank for import %1", postFix));
@@ -949,8 +949,8 @@ SKGError SKGImportPluginQif::exportFile()
                             SKGSubOperationObject suboperation = suboperations.at(0);
                             //Dump quantity
                             if(unitExported) {
-                                stream << 'Q' << SKGServices::doubleToString(abs(suboperation.getQuantity())) << endl;
-                                stream << 'I' << SKGServices::doubleToString(abs(operation.getCurrentAmount() / suboperation.getQuantity())) << endl;
+                                stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << endl;
+                                stream << 'I' << SKGServices::doubleToString(qAbs(operation.getCurrentAmount() / suboperation.getQuantity())) << endl;
                             }
 
                             //Get category of this simple operation
