@@ -49,6 +49,8 @@ SKGImportPluginSkg::SKGImportPluginSkg(QObject* iImporter, const QVariantList& i
 {
     SKGTRACEIN(10, "SKGImportPluginSkg::SKGImportPluginSkg");
     Q_UNUSED(iArg);
+
+    m_parameters["password"] = "";
 }
 
 SKGImportPluginSkg::~SKGImportPluginSkg()
@@ -70,7 +72,7 @@ SKGError SKGImportPluginSkg::importFile()
     SKGTRACEL(10) << "Input filename=" << iFileName << endl;
 
     SKGDocumentBank docOrigin;
-    err = docOrigin.load(iFileName);
+    err = docOrigin.load(iFileName, m_parameters["password"]);
     if(!err) {
         QMap<QString, SKGObjectBase> mapOriginNew;
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#", 10);
