@@ -315,10 +315,8 @@ SKGError SKGImportPluginXhb::importFile()
                                 int pstep = SKGServices::stringToInt(getAttribute(transaction,  "every"));
                                 SKGRecurrentOperationObject::PeriodUnit p = SKGRecurrentOperationObject::MONTH;
                                 if(punit == 0) p = SKGRecurrentOperationObject::DAY;
-                                else if(punit == 1) {
-                                    p = SKGRecurrentOperationObject::DAY;
-                                    pstep *= 7;
-                                } else if(punit == 3) p = SKGRecurrentOperationObject::YEAR;
+                                else if(punit == 1) p = SKGRecurrentOperationObject::WEEK;
+                                else if(punit == 3) p = SKGRecurrentOperationObject::YEAR;
                                 if(!err) err = recu.setPeriodIncrement(pstep);
                                 if(!err) err = recu.setPeriodUnit(p);
                                 if(!err) err = recu.warnEnabled(flags & (1 << 5));
