@@ -85,11 +85,12 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
             }
             m_graph->setState(doc1.toString());
 
-            connect(ui.kView->getShowWidget(), SIGNAL(stateChanged()), this, SLOT(onRefreshGraph()));
-            onRefreshGraph();
 
             m_timer2.setSingleShot(true);
             connect(&m_timer2, SIGNAL(timeout()), this, SLOT(onRefreshGraph()));
+            m_timer2.start(300);
+
+            connect(ui.kView->getShowWidget(), SIGNAL(stateChanged()), &m_timer2, SIGNAL(timeout()));
         }
     }
 
@@ -105,8 +106,10 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitEdit->setDocument(iDocument);
 
     //Set show widget
-    ui.kView->getShowWidget()->addItem("opened", i18n("Opened"), "", "t_close='N'", "", "", "closed");
-    ui.kView->getShowWidget()->addItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'", "", "", "opened");
+    ui.kView->getShowWidget()->addItem("opened", i18n("Opened"), "", "t_close='N'", "", "highlighted", "closed", "");
+    ui.kView->getShowWidget()->addItem("closed", i18n("Closed"), "dialog-close", "t_close='Y'", "", "highlighted", "opened", "");
+    ui.kView->getShowWidget()->addSeparator();
+    ui.kView->getShowWidget()->addItem("highlighted", i18n("Highlighted only"), "rating", "t_bookmarked='Y'", "", "opened;closed", "opened");
     if(m_graph) {
         ui.kView->getShowWidget()->addSeparator();
         ui.kView->getShowWidget()->addItem("graph", i18n("Graph"), "view-investment", "1=0", "", "", "");
@@ -361,7 +364,8 @@ void SKGBankPluginWidget::onAccountCreatorModified()
 
     bool activatedForWallet = ui.kWidgetSelector->getSelectedMode() != -1 &&
                               ui.kAccountCreatorAccount->text().length() > 0 &&
-                              ui.kUnitEdit->currentText().length() > 0;
+                              ui.kUnitEdit->currentText().length() > 0 &&
+                              (ui.kAmountEdit->valid() || ui.kAmountEdit->text().isEmpty());
     bool activated = activatedForWallet &&
                      ui.kAccountCreatorBank->text().length() > 0;
     bool wallet = ((SKGAccountObject::AccountType)(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()) == SKGAccountObject::WALLET);
@@ -557,12 +561,11 @@ void SKGBankPluginWidget::onModifyAccountClicked()
         if(!err) {
             err = getDocument()->executeSqliteOrder("DELETE FROM bank WHERE NOT EXISTS(SELECT 1 FROM account WHERE account.rd_bank_id = bank.id)");
         }
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("Successfully updated an account", "Account updated."));
-        else err.addError(ERR_FAIL, i18nc("Error message : Could not update an account",  "Update failed"));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("Successfully updated an account", "Account updated."));
+    else err.addError(ERR_FAIL, i18nc("Error message : Could not update an account",  "Update failed"));
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
@@ -729,6 +732,15 @@ QWidget* SKGBankPluginWidget::mainWidget() const
     return ui.kView->getView();
 }
 
+QList< QWidget* > SKGBankPluginWidget::printableWidgets() const
+{
+    QList< QWidget* > output;
+    output.push_back(mainWidget());
+    output.push_back(m_graph);
+    return output;
+}
+
+
 void SKGBankPluginWidget::activateEditor()
 {
     if(ui.kWidgetSelector->getSelectedMode() == -1) ui.kWidgetSelector->setSelectedMode(0);
