@@ -35,8 +35,7 @@
 #include <QDomDocument>
 #include <QDir>
 #include <QKeyEvent>
-
-#include <math.h>
+#include <qmath.h>
 
 SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
@@ -64,7 +63,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
 
     ui.kCreditValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
     ui.kDebitValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
-    for(int i = 0 ; i <= 5 ; i++) {
+    for(int i = 0 ; i <= 5 ; ++i) {
         ui.kCreditValueDate->addItem(i18nc("Used for configurating when interests are paid on an account : %s days after being calculated",  "Day +%1", i));
         ui.kDebitValueDate->addItem(i18nc("Used for configurating when interests are paid on an account : %s days after being calculated",  "Day -%1", i));
     }
@@ -356,8 +355,7 @@ void SKGCalculatorPluginWidget::onFilterChanged()
 
     //Update model
     if(m_objectModel) {
-        m_objectModel->setFilter(filter2);
-        ui.kInterestView->setState(ui.kInterestView->getState());
+        if(m_objectModel->setFilter(filter2)) ui.kInterestView->setState(ui.kInterestView->getState());
 
         //Compute result
         computeInterest();
@@ -448,28 +446,26 @@ void SKGCalculatorPluginWidget::onUpdate()
     SKGObjectBase::SKGListSKGObjectBase updatedInterest = getSelectedObjects();
     int nb = updatedInterest.count();
     {
-        {
-            SKGInterestObject interestObj;
-            SKGBEGINTRANSACTION(*getDocument(), i18nc("Lets the user update parameters for computing interests on an account", "Interest parameter update for account '%1'", accountname), err);
+        SKGInterestObject interestObj;
+        SKGBEGINTRANSACTION(*getDocument(), i18nc("Lets the user update parameters for computing interests on an account", "Interest parameter update for account '%1'", accountname), err);
 
-            for(int i = 0; !err && i < nb; ++i) {
-                interestObj = updatedInterest.at(i);
-                if(nb == 1) {
-                    if(!err) err = interestObj.setDate(ui.kDateEdit->date());
-                    if(!err) err = interestObj.setRate(ui.kRateEdit->value());
-                }
-                if(!err) err = interestObj.setIncomeValueDateMode((SKGInterestObject::ValueDateMode) ui.kCreditValueDate->currentIndex());
-                if(!err) err = interestObj.setExpenditueValueDateMode((SKGInterestObject::ValueDateMode) ui.kDebitValueDate->currentIndex());
-                if(!err) err = interestObj.setInterestComputationMode((SKGInterestObject::InterestMode) ui.kMode->currentIndex());
-                if(!err) err = interestObj.save();
+        for(int i = 0; !err && i < nb; ++i) {
+            interestObj = updatedInterest.at(i);
+            if(nb == 1) {
+                if(!err) err = interestObj.setDate(ui.kDateEdit->date());
+                if(!err) err = interestObj.setRate(ui.kRateEdit->value());
             }
+            if(!err) err = interestObj.setIncomeValueDateMode((SKGInterestObject::ValueDateMode) ui.kCreditValueDate->currentIndex());
+            if(!err) err = interestObj.setExpenditueValueDateMode((SKGInterestObject::ValueDateMode) ui.kDebitValueDate->currentIndex());
+            if(!err) err = interestObj.setInterestComputationMode((SKGInterestObject::InterestMode) ui.kMode->currentIndex());
+            if(!err) err = interestObj.save();
         }
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("User defined parameters for computing interests were successfully updated", "Interest parameter updated"));
-        else err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be updated",  "Interest parameter update failed"));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("User defined parameters for computing interests were successfully updated", "Interest parameter updated"));
+    else err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be updated",  "Interest parameter update failed"));
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
@@ -495,14 +491,14 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
         unit.load();
         unitInfo.NbDecimal = unit.getNumberDecimal();
 
-        int p = pow(10, unitInfo.NbDecimal);
+        int p = qPow(10, unitInfo.NbDecimal);
 
         //Computation
         int periodInMonths = 12;
         int numberPayments = ui.kLenghtEdit->value() * periodInMonths;
         double periodicRate = ui.kAnnualRateEdit->value() / 100 / periodInMonths;
-        double insurance = round(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100 / periodInMonths * p) / p;
-        double periodicAmount = round(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * p) / p;
+        double insurance = qRound(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100 / periodInMonths * p) / p;
+        double periodicAmount = qRound(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * p) / p;
 
         //Fill table
         double dueAmount = ui.kLoanEdit->value();
@@ -510,8 +506,8 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
         ui.kAmortizationTable->setRowCount(numberPayments);
         for(int i = 0; i < numberPayments; ++i) {
             //Compute
-            double roundedInterest = round(dueAmount * periodicRate * p) / p;
-            double principal = round((i == numberPayments - 1 ? dueAmount : periodicAmount - roundedInterest) * p) / p;
+            double roundedInterest = qRound(dueAmount * periodicRate * p) / p;
+            double principal = qRound((i == numberPayments - 1 ? dueAmount : periodicAmount - roundedInterest) * p) / p;
             double amount = roundedInterest + principal;
             dueAmount -= principal;
             sumInterest += roundedInterest;
