@@ -37,6 +37,7 @@
 #include <QDomDocument>
 #include <kencodingfiledialog.h>
 #include <KMessageBox>
+#include <kpassworddialog.h>
 
 /**
  * This plugin factory.
@@ -76,10 +77,8 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     if(m_currentBankDocument == NULL) return false;
 
     // Tell the host application to load my GUI component
-    KComponentData data = SKGImportExportPluginFactory::componentData();
-    const_cast<KAboutData*>(data.aboutData())->setProgramName(ki18n("%1").subs(KGlobal::mainComponent().aboutData()->programName()));
-    setComponentData(data);
-    setXMLFile("skrooge_importexport.rc");
+    setComponentData(KGlobal::mainComponent());
+    setXMLFile("../skrooge_importexport/skrooge_importexport.rc");
 
     //Imports
     KActionMenu* imports = new  KActionMenu(KIcon("document-import"), i18nc("Verb, action to import items from another format", "Import"), this);
@@ -174,7 +173,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     m_mergeImportedOperationAction = new KAction(KIcon("merge"), i18nc("Verb, action to merge", "Merge imported operations"), this);
     connect(m_mergeImportedOperationAction, SIGNAL(triggered(bool)), SLOT(mergeImportedOperation()));
     actionCollection()->addAction(QLatin1String("merge_imported_operation"), m_mergeImportedOperationAction);
-    m_mergeImportedOperationAction->setShortcut(Qt::CTRL + Qt::Key_M);
+    m_mergeImportedOperationAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_M);
 
     if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("merge_imported_operation", m_mergeImportedOperationAction);
 
@@ -192,6 +191,11 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
         }
     }
 
+    //Krunner operations
+    QString dirName = QDir::homePath() % "/.skrooge/";
+    QStringList fileList = QDir(dirName).entryList(QDir::Files);
+    if(fileList.count()) m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's operations to import"));
+
     return true;
 }
 
@@ -328,47 +332,71 @@ void SKGImportExportPlugin::import(const QString& iFile)
                     imp1.setCodec(codec);
 
                     if(QFileInfo(fileName).suffix().toUpper() == "CSV") { //TODO: Better
-                        //Set header line
-                        bool automatic_search_header = skgimportexport_settings::automatic_search_header();
-                        if(!automatic_search_header) {
-                            int header_position = skgimportexport_settings::header_position();
-                            if(!err) err = imp1.setCSVHeaderIndex(header_position);
+                        QMap<QString, QString> parameters = imp1.getImportParameters();
 
-                        }
+                        parameters["automatic_search_header"] = (skgimportexport_settings::automatic_search_header() ? "Y" : "N");
+                        parameters["header_position"] = SKGServices::intToString(skgimportexport_settings::header_position());
 
-                        //Build mapping. WARNING: must be done in all case due to "debit"
-                        QMap<QString, QString> mappingRules;
-                        mappingRules["date"] = skgimportexport_settings::mapping_date();
-                        mappingRules["account"] = skgimportexport_settings::mapping_account();
-                        mappingRules["number"] = skgimportexport_settings::mapping_number();
-                        mappingRules["mode"] = skgimportexport_settings::mapping_mode();
-                        mappingRules["payee"] = skgimportexport_settings::mapping_payee();
-                        mappingRules["comment"] = skgimportexport_settings::mapping_comment();
-                        mappingRules["status"] = skgimportexport_settings::mapping_status();
-                        mappingRules["bookmarked"] = skgimportexport_settings::mapping_bookmarked();
-                        mappingRules["category"] = skgimportexport_settings::mapping_category();
-                        mappingRules["amount"] = skgimportexport_settings::mapping_amount();
-                        mappingRules["quantity"] = skgimportexport_settings::mapping_quantity();
-                        mappingRules["unit"] = skgimportexport_settings::mapping_unit();
-                        mappingRules["idtransaction"] = skgimportexport_settings::mapping_idtransaction();
-                        mappingRules["idgroup"] = skgimportexport_settings::mapping_idgroup();
-                        mappingRules["sign"] = skgimportexport_settings::mapping_sign();
-                        mappingRules["debit"] = skgimportexport_settings::mapping_debit();
-                        mappingRules["property"] = skgimportexport_settings::mapping_property();
-                        if(!err) err = imp1.setCSVMappingRules(mappingRules);
+                        parameters["mapping_date"] = skgimportexport_settings::mapping_date();
+                        parameters["mapping_account"] = skgimportexport_settings::mapping_account();
+                        parameters["mapping_number"] = skgimportexport_settings::mapping_number();
+                        parameters["mapping_mode"] = skgimportexport_settings::mapping_mode();
+                        parameters["mapping_payee"] = skgimportexport_settings::mapping_payee();
+                        parameters["mapping_comment"] = skgimportexport_settings::mapping_comment();
+                        parameters["mapping_status"] = skgimportexport_settings::mapping_status();
+                        parameters["mapping_bookmarked"] = skgimportexport_settings::mapping_bookmarked();
+                        parameters["mapping_category"] = skgimportexport_settings::mapping_category();
+                        parameters["mapping_amount"] = skgimportexport_settings::mapping_amount();
+                        parameters["mapping_quantity"] = skgimportexport_settings::mapping_quantity();
+                        parameters["mapping_unit"] = skgimportexport_settings::mapping_unit();
+                        parameters["mapping_idtransaction"] = skgimportexport_settings::mapping_idtransaction();
+                        parameters["mapping_idgroup"] = skgimportexport_settings::mapping_idgroup();
+                        parameters["mapping_sign"] = skgimportexport_settings::mapping_sign();
+                        parameters["mapping_debit"] = skgimportexport_settings::mapping_debit();
+                        parameters["mapping_property"] = skgimportexport_settings::mapping_property();
 
-                        bool automatic_search_columns = skgimportexport_settings::automatic_search_columns();
-                        if(!automatic_search_columns) {
-                            QStringList columns_positions = skgimportexport_settings::columns_positions().split('|');
-                            if(!err) err = imp1.setCSVMapping(&columns_positions);
-                        }
+                        parameters["automatic_search_columns"] = (skgimportexport_settings::automatic_search_columns() ? "Y" : "N");
+                        parameters["columns_positions"] = skgimportexport_settings::columns_positions();
+                        parameters["mode_csv_unit"] = (sender() == m_importCsvUnitAction ? "Y" : "N");
+
+                        imp1.setImportParameters(parameters);
                     }
 
-                    if(!err) {
-                        if(sender() == m_importCsvUnitAction) err = imp1.importCSVUnit();
-                        else err = imp1.importFile();
+
+                    if(!err) err = imp1.importFile();
+                    if(err && err.getReturnCode() == ERR_ENCRYPTION) {
+                        QString pwd;
+                        QString additionalMessage;
+                        do {
+                            //Reset error
+                            err = SKGError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName));
+                            pwd = "";
+
+                            //Use password dialog
+                            QApplication::restoreOverrideCursor();
+                            QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
+                            dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
+                            if(dlg->exec() == QDialog::Accepted) pwd = dlg->password();
+                            delete dlg;
+                            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+                            //Load file
+                            if(!pwd.isEmpty()) {
+                                QMap<QString, QString> parameters;
+                                parameters["password"] = pwd;
+                                imp1.setImportParameters(parameters);
+                                err = imp1.importFile();
+                                if(err) {
+                                    additionalMessage = i18nc("The user did not provide the correct password", "<b>Wrong password.</b>\n");
+                                }
+                            } else {
+                                err = SKGError(ERR_FAIL, i18nc("Error message", "Import canceled by user"));
+                                break;
+                            }
+                        } while(err);
                     }
-                    if(!!err) {
+
+                    if(err) {
                         err.addError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName));
                     }
 
@@ -497,21 +525,23 @@ void SKGImportExportPlugin::validateImportedOperations()
     if(SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
-        SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate imported operations"), err, nb);
-        for(int i = 0; !err && i < nb; ++i) {
-            SKGOperationObject op = selection[i];
-            if(op.getAttribute("t_imported") == "P") {
-                err = op.setImported(true);
-                if(!err) err = op.save();
+        {
+            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Validate imported operations"), err, nb);
+            for(int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op = selection[i];
+                if(op.getAttribute("t_imported") == "P") {
+                    err = op.setImported(true);
+                    if(!err) err = op.save();
+                }
+                if(!err) err = m_currentBankDocument->stepForward(i + 1);
             }
-            if(!err) err = m_currentBankDocument->stepForward(i + 1);
         }
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Imported operations validated."));
-        else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Imported operations validated."));
+    else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
@@ -542,15 +572,15 @@ void SKGImportExportPlugin::mergeImportedOperation()
                 if(rc == KMessageBox::Yes) {
                     SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Merge imported operations"), err);
                     err = opManual.mergeAttribute(opImported);
-                    if(!!err) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
+                    if(err) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
                 }
             }
         }
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Imported operations merged."));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Imported operations merged."));
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
@@ -592,25 +622,61 @@ void SKGImportExportPlugin::openNotValidated() const
     if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
 }
 
-QList< SKGInterfacePlugin::SKGAdvice > SKGImportExportPlugin::advices() const
+SKGAdviceList SKGImportExportPlugin::advices() const
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::advices");
-    QList< SKGInterfacePlugin::SKGAdvice > output;
+    SKGAdviceList output;
 
     //Check operations not validated
     bool exist = false;
     m_currentBankDocument->existObjects("operation", "t_imported='P'", exist);
     if(exist) {
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgimportexportplugin_notvalidated";
-        ad.priority = 4;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Many operations imported and not yet validated");
-        ad.longMessage = i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed.");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open operations imported and not yet validated"));
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Validate operations that do not require further action"));
+        SKGAdvice ad;
+        ad.setUUID("skgimportexportplugin_notvalidated");
+        ad.setPriority(4);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations imported and not yet validated"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "After importing operations, you should review them, make corrections on, for instance, category, payee. Once done, you should mark the imported operation as validated, so that you know the operation has been fully processed."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations imported and not yet validated"));
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Validate operations that do not require further action"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
+    //Krunner operations
+    QString dirName = QDir::homePath() % "/.skrooge/";
+    QStringList fileList = QDir(dirName).entryList(QDir::Files);
+    int nb = fileList.count();
+    if(nb) {
+        QStringList listAccounts;
+        m_currentBankDocument->getDistinctValues("account", "t_name", "t_type IN ('C', 'D', 'W') and t_close='N'", listAccounts);
+        int nbAccounts = listAccounts.count();
+        for(int i = 0; i < nb; ++i) {
+            QString fileName = dirName % fileList.at(i);
+            QFile file(fileName);
+            if(file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                QTextStream stream(&file);
+                QString action = stream.readLine().trimmed();
+                QString date = KGlobal::locale()->formatDate(SKGServices::stringToTime(stream.readLine().trimmed()).date(), KLocale::ShortDate);
+                QString amount = m_currentBankDocument->formatMoney(SKGServices::stringToDouble(stream.readLine().trimmed()), m_currentBankDocument->getPrimaryUnit())  ;
+                QString payee = stream.readLine().trimmed();
+                SKGAdvice ad;
+                ad.setUUID("skgimportexportplugin_krunner_" % fileName);
+                ad.setPriority(8);
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Krunner's operation ongoing [%1 %2 %3]", date, amount, payee));
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "Operations created through krunner have to be fully created in skrooge."));
+                QStringList autoCorrections;
+                for(int j = 0; j < nbAccounts; ++j) {
+                    autoCorrections.push_back(i18nc("Advice on making the best (action)", "Import operation in %1", listAccounts.at(j)));
+                }
+                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Remove operation"));
+                ad.setAutoCorrections(autoCorrections);
+                output.push_back(ad);
+            }
+            //Close file
+            file.close();
+        }
+    }
     return output;
 }
 
@@ -636,8 +702,89 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
             SKGMainPanel::displayErrorMessage(err);
         }
         return SKGError();
-    }
+    } else if(iAdviceIdentifier.startsWith(QLatin1String("skgimportexportplugin_krunner_")) && m_currentBankDocument) {
+        SKGError err;
+        //Get file name
+        QString fileName = iAdviceIdentifier.right(iAdviceIdentifier.length() - 30);
+        QFile file(fileName);
 
+        //Get accounts
+        QStringList listAccounts;
+        m_currentBankDocument->getDistinctValues("account", "t_name", "t_type IN ('C', 'D', 'W') and t_close='N'", listAccounts);
+        if(iSolution < listAccounts.count()) {
+            //Addition in an account
+
+            if(file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                QTextStream stream(&file);            QString action = stream.readLine().trimmed();
+                QDate date = SKGServices::stringToTime(stream.readLine().trimmed()).date();
+                double amount = SKGServices::stringToDouble(stream.readLine().trimmed());
+                QString payee = stream.readLine().trimmed();
+
+                SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Import krunner's operation"), err);
+
+                //Get account
+                SKGAccountObject act(m_currentBankDocument);
+                err = act.setName(listAccounts.at(iSolution));
+                if(!err) err = act.load();
+
+                //Get unit
+                SKGUnitObject unit(m_currentBankDocument);
+                if(!err) err = unit.setName(m_currentBankDocument->getPrimaryUnit().Name);
+                if(!err) err = unit.load();
+
+                //Add operation
+                SKGOperationObject op;
+                if(!err) err = act.addOperation(op);
+                if(!err) err = op.setDate(date);
+                if(!err) err = op.setUnit(unit);
+
+                if(!payee.isEmpty()) {
+                    //Get payee
+                    SKGPayeeObject pa;
+                    if(!err) err = SKGPayeeObject::createPayee(m_currentBankDocument, payee, pa, true);
+                    if(!err) err = op.setPayee(pa);
+                }
+                if(!err) {
+                    int pos1 = fileName.indexOf("{");
+                    int pos2 = fileName.indexOf("}");
+                    if(pos1 != -1 && pos2 > pos1) err = op.setImportID("KR-" % fileName.mid(pos1 + 1, pos2 - pos1 - 1));
+                }
+                if(!err) err = op.save();
+
+                //Add suboperation
+                SKGSubOperationObject sop;
+                if(!err) err = op.addSubOperation(sop);
+                if(!err) err = sop.setQuantity(-amount);
+                if(!err) err = sop.save();
+
+                //Finalize the importation
+                if(!err) {
+                    bool automatic_validation = skgimportexport_settings::automatic_validation();
+                    bool automatic_rule = skgimportexport_settings::apply_rules();
+
+                    SKGImportExportManager imp1(m_currentBankDocument);
+                    imp1.setAutomaticValidation(automatic_validation);
+                    imp1.setAutomaticApplyRules(automatic_rule);
+                    err = imp1.finalizedImportedOperations();
+                }
+            }
+            //Close file
+            file.close();
+
+            //status bar
+            if(!err) {
+                err = SKGError(0, i18nc("Message for successful user action", "Operations imported."));
+                QFile::remove(fileName);
+            } else err.addError(ERR_FAIL, i18nc("Error message", "Import failed"));
+        } else {
+            err = SKGError(0, i18nc("Message for successful user action", "Operations removed."));
+            QFile::remove(fileName);
+        }
+
+        //Display error
+        SKGMainPanel::displayErrorMessage(err);
+        return SKGError();
+    }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
 }
 
