@@ -27,6 +27,8 @@
 #include "skgoperationobject.h"
 #include "skgaccountobject.h"
 #include "skgsuboperationobject.h"
+#include "skgcategoryobject.h"
+#include "skgpayeeobject.h"
 #include "skgtransactionmng.h"
 #include "skgmainpanel.h"
 #include "skgtableview.h"
@@ -60,7 +62,6 @@ SKGOperationPlugin::~SKGOperationPlugin()
     m_currentBankDocument = NULL;
     m_duplicateAction = NULL;
     m_switchToPointedAction = NULL;
-    m_switchHighLight = NULL;
     m_openHighLights = NULL;
     m_openLastModified = NULL;
     m_groupOperation = NULL;
@@ -80,10 +81,8 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     m_currentBankDocument->setComputeBalances(skgoperation_settings::computeBalances());
 
-    KComponentData data = SKGOperationPluginFactory::componentData();
-    const_cast<KAboutData*>(data.aboutData())->setProgramName(ki18n("%1").subs(KGlobal::mainComponent().aboutData()->programName()));
-    setComponentData(data);
-    setXMLFile("skrooge_operation.rc");
+    setComponentData(KGlobal::mainComponent());
+    setXMLFile("../skrooge_operation/skrooge_operation.rc");
 
     //Menu
     //------------
@@ -118,14 +117,6 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("fast_edition", fastEditionAction);
 
-    //------------
-    m_switchHighLight = new KAction(KIcon("rating"), i18nc("Verb", "Switch highlight"), this);
-    connect(m_switchHighLight, SIGNAL(triggered(bool)), this, SLOT(actionSwitchHighLight()));
-    actionCollection()->addAction(QLatin1String("edit_switch_highlight"), m_switchHighLight);
-    m_switchHighLight->setShortcut(Qt::CTRL + Qt::Key_H);
-
-    if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_switch_highlight", m_switchHighLight);
-
     //------------
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
@@ -201,11 +192,8 @@ void SKGOperationPlugin::refresh()
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         if(selection.count() > 0) {
             bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
-            bool onAccount = (selection.at(0).getRealTable() == "account");
-            bool onRule = (selection.at(0).getRealTable() == "rule");
             if(m_duplicateAction) m_duplicateAction->setEnabled(onOperation);
             if(m_createTemplateAction) m_createTemplateAction->setEnabled(onOperation);
-            if(m_switchHighLight) m_switchHighLight->setEnabled(onOperation || onAccount || onRule);
             if(m_switchToPointedAction) m_switchToPointedAction->setEnabled(onOperation);
             if(m_groupOperation) m_groupOperation->setEnabled(onOperation && selection.count() >= 2);
             if(m_ungroupOperation) m_ungroupOperation->setEnabled(onOperation);
@@ -213,7 +201,6 @@ void SKGOperationPlugin::refresh()
         } else {
             if(m_duplicateAction) m_duplicateAction->setEnabled(false);
             if(m_createTemplateAction) m_createTemplateAction->setEnabled(false);
-            if(m_switchHighLight) m_switchHighLight->setEnabled(false);
             if(m_switchToPointedAction) m_switchToPointedAction->setEnabled(false);
             if(m_groupOperation) m_groupOperation->setEnabled(false);
             if(m_ungroupOperation) m_ungroupOperation->setEnabled(false);
@@ -389,43 +376,6 @@ void SKGOperationPlugin::actionSwitchToPointed()
     }
 }
 
-void SKGOperationPlugin::actionSwitchHighLight()
-{
-    SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::actionSwitchHighLight", err);
-    //Get Selection
-    if(SKGMainPanel::getMainPanel() && m_currentBankDocument) {
-        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
-        int nb = selection.count();
-        {
-            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Highlight"), err, nb);
-            for(int i = 0; !err && i < nb; ++i) {
-                if(selection.at(i).getRealTable() == "account") {
-                    SKGAccountObject obj = selection.at(i);
-                    if(!err) err = obj.bookmark(!obj.isBookmarked());
-                    if(!err) err = obj.save();
-                } else if(selection.at(i).getRealTable() == "operation") {
-                    SKGOperationObject obj = selection.at(i);
-                    if(!err) err = obj.bookmark(!obj.isBookmarked());
-                    if(!err) err = obj.save();
-                } else if(selection.at(i).getRealTable() == "rule") {
-                    SKGRuleObject obj = selection.at(i);
-                    if(!err) err = obj.bookmark(!obj.isBookmarked());
-                    if(!err) err = obj.save();
-                }
-                if(!err) err = m_currentBankDocument->stepForward(i + 1);
-            }
-        }
-
-        //status bar
-        if(!err)  err = SKGError(0, i18nc("Successful message after an user action", "Highlighted."));
-        else err.addError(ERR_FAIL, i18nc("Error message",  "Highlight failed"));
-
-        //Display error
-        SKGMainPanel::displayErrorMessage(err);
-    }
-}
-
 void SKGOperationPlugin::actionDuplicate()
 {
     SKGError err;
@@ -594,10 +544,10 @@ void SKGOperationPlugin::actionOpenSubOperations()
     if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
 }
 
-QList< SKGInterfacePlugin::SKGAdvice > SKGOperationPlugin::advices() const
+SKGAdviceList SKGOperationPlugin::advices() const
 {
     SKGTRACEIN(10, "SKGOperationPlugin::advices");
-    QList< SKGInterfacePlugin::SKGAdvice > output;
+    SKGAdviceList output;
 
     //Search duplicate number on operation
     SKGStringListList result;
@@ -609,12 +559,14 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGOperationPlugin::advices() const
         QString account = line.at(1);
         QString number = line.at(2);
 
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgoperationplugin_duplicate|" % number % ';' % account;
-        ad.priority = 7;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Duplicate number %1 in account '%2'", number, account);
-        ad.longMessage = i18nc("Advice on making the best (long)", "Your account '%1' contains more than one operation with number %2.The operation number should be unique (check number, transaction reference...)", account, number);
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Edit operations with duplicate number"));
+        SKGAdvice ad;
+        ad.setUUID("skgoperationplugin_duplicate|" % number % ';' % account);
+        ad.setPriority(7);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Duplicate number %1 in account '%2'", number, account));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Your account '%1' contains more than one operation with number %2.The operation number should be unique (check number, transaction reference...)", account, number));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit operations with duplicate number"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
@@ -626,12 +578,14 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGOperationPlugin::advices() const
         QStringList line = result.at(i);
         QString account = line.at(1);
 
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgoperationplugin_notreconciliated|" % account;
-        ad.priority = 9;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Many operations of '%1' not reconciliated", account);
-        ad.longMessage = i18nc("Advice on making the best (long)", "Don't forget to reconciliate your accounts. By doing so, you acknowledge that your bank has indeed processed these operations on your account. This is how you enforce compliance with your bank's statements. See online help for more details");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open account '%1' for reconciliation", account));
+        SKGAdvice ad;
+        ad.setUUID("skgoperationplugin_notreconciliated|" % account);
+        ad.setPriority(9);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations of '%1' not reconciliated", account));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget to reconciliate your accounts. By doing so, you acknowledge that your bank has indeed processed these operations on your account. This is how you enforce compliance with your bank's statements. See online help for more details"));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open account '%1' for reconciliation", account));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
@@ -639,24 +593,28 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGOperationPlugin::advices() const
     bool exist = false;
     m_currentBankDocument->existObjects("v_operation_display", "EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
     if(exist) {
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgoperationplugin_nocategory";
-        ad.priority = 5;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Many operations don't have category");
-        ad.longMessage = i18nc("Advice on making the best (long)", "Don't forget to associate a category for each operation. This will allow you to generate better reports.");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open operations without category"));
+        SKGAdvice ad;
+        ad.setUUID("skgoperationplugin_nocategory");
+        ad.setPriority(5);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations don't have category"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget to associate a category for each operation. This will allow you to generate better reports."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations without category"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
     //Check operations without payee
     m_currentBankDocument->existObjects("v_operation_display", "r_payee_id=0", exist);
     if(exist) {
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgoperationplugin_nopayee";
-        ad.priority = 5;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Many operations don't have payee");
-        ad.longMessage = i18nc("Advice on making the best (long)", "Don't forget to associate a payee for each operation. This will allow you to generate better reports.");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open operations without payee"));
+        SKGAdvice ad;
+        ad.setUUID("skgoperationplugin_nopayee");
+        ad.setPriority(5);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations don't have payee"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget to associate a payee for each operation. This will allow you to generate better reports."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations without payee"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
@@ -675,11 +633,11 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGOperationPlugin::advices() const
             //Get parameters
             QString account = result.at(i).at(0);
 
-            SKGInterfacePlugin::SKGAdvice ad;
-            ad.uuid = "skgoperationplugin_too_much_money|" % account;
-            ad.priority = 6;
-            ad.shortMessage = i18nc("Advice on making the best (short)", "Too much money in your account '%1'", account);
-            ad.longMessage = i18nc("Advice on making the best (long)", "You could save money on an account with a better rate. Example: '%1' (%2%)", target, rate);
+            SKGAdvice ad;
+            ad.setUUID("skgoperationplugin_too_much_money|" % account);
+            ad.setPriority(6);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Too much money in your account '%1'", account));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "You could save money on an account with a better rate. Example: '%1' (%2%)", target, rate));
             output.push_back(ad);
         }
     }
@@ -787,12 +745,12 @@ void SKGOperationPlugin::actionMergeSubOperations()
                 err = op.mergeSuboperations(op2);
             }
         }
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Operations merged."));
-        else err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Operations merged."));
+    else err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
