@@ -30,12 +30,13 @@
 #include "skgsplittabledelegate.h"
 #include "skgpayeeobject.h"
 #include "skgoperation_settings.h"
-#include <skgcalculatoredit.h>
+#include "skgcalculatoredit.h"
 
 #include <kstandarddirs.h>
 #include <kstandardaction.h>
 #include <kmessagebox.h>
 #include <kinputdialog.h>
+#include <kcolorscheme.h>
 
 #include <QtGui/QHeaderView>
 #include <QDomDocument>
@@ -51,6 +52,9 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
     SKGTRACEIN(1, "SKGOperationPluginWidget::SKGOperationPluginWidget");
     if(!iDocument) return;
 
+    m_timer.setSingleShot(true);
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onRefreshInformationZone()));
+
     ui.setupUi(this);
 
     ui.kAccountLabel->setText(i18n("%1:", iDocument->getDisplay("t_ACCOUNT")));
@@ -84,6 +88,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
         SKGTRACEIN(10, "SKGOperationPluginWidget::SKGOperationPluginWidget-model creation");
         //Bind operation view
         m_objectModel = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_operation_display", "1=0", this, "", false);
+
         SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel(this);
         modelproxy->setSourceModel(m_objectModel);
         modelproxy->setSortRole(Qt::UserRole);
@@ -128,8 +133,10 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
     ui.kResetInternalFilter->setIcon(KIcon("dialog-cancel"));
     ui.kReconciliatorButton->setIcon(KIcon("object-rotate-left"));
     ui.kValidate->setIcon(KIcon("dialog-ok-apply"));
+    ui.kValidate->setIconSize(QSize(48, 48));
     ui.kAutoPoint->setIcon(KIcon("games-solve"));
     ui.kCreateFakeOperation->setIcon(KIcon("list-add"));
+    ui.kFastEditBtn->setIcon(KIcon("games-solve"));
 
     {
         SKGWidgetSelector::SKGListQWidget list;
@@ -198,6 +205,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
     m_tableDelegate = new SKGSplitTableDelegate(ui.kSubOperationsTable, getDocument());
     m_tableDelegate->addParameterValue("total", '0');
     ui.kSubOperationsTable->setItemDelegate(m_tableDelegate);
+    ui.kSubOperationsTable->setTextElideMode(Qt::ElideMiddle);
     connect(ui.kSubOperationsTable, SIGNAL(removeSelectedItems()), this, SLOT(onRemoveSubOperation()));
 
     ui.kTargetAccountEdit->hide();
@@ -233,7 +241,13 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
 
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection);
 
-    fillComboBoxes();
+    connect(ui.kUnitEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+    connect(ui.kAmountEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+    connect(ui.kAmountSharesEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+    connect(ui.kCommissionEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+    connect(ui.kTaxEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+
+    dataModified("", 0);
     onOperationCreatorModified();
 
     setAllWidgetsEnabled();
@@ -347,6 +361,7 @@ void SKGOperationPluginWidget::onFreeze()
 
 void SKGOperationPluginWidget::setAllWidgetsEnabled()
 {
+    SKGTRACEIN(10, "SKGOperationPluginWidget::setAllWidgetsEnabled");
     //Enable widgets
     setWidgetEditionEnabled(ui.kTypeEdit->lineEdit(), true);
     setWidgetEditionEnabled(ui.kUnitEdit->lineEdit(), true);
@@ -457,7 +472,7 @@ void SKGOperationPluginWidget::onSelectionChanged()
 
     Q_EMIT selectionChanged();
 
-    if(m_modeInfoZone == 2) onRefreshInformationZone();
+    if(m_modeInfoZone == 2) onRefreshInformationZoneDelayed();
 }
 
 void SKGOperationPluginWidget::onOperationCreatorModified()
@@ -687,7 +702,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
 
                 if(oldQuantity == 0) {
                     //Bug 192832 – Do not take amount sign into account vvv
-                    if(abs(operationQuantity) != operationQuantity) {
+                    if(qAbs(operationQuantity) != operationQuantity) {
                         operationQuantity = -operationQuantity;
                         err = getDocument()->sendMessage(i18nc("An information message",  "Absolute value has been used for transfer creation."));
                     }
@@ -819,7 +834,22 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             err = SKGPayeeObject::createPayee(static_cast<SKGDocumentBank*>(getDocument()), payeeName, payeeObject, true);
             if(!err) err = operationObj.setPayee(payeeObject);
         }
-        if(!err && ui.kUnitEdit->text() != NOUPDATE) err = operationObj.setUnit(ui.kUnitEdit->getUnit());
+        if(!err && ui.kUnitEdit->text() != NOUPDATE) {
+            //Correction bug 282983 vvv
+            //Check unit of target account
+            SKGAccountObject account;
+            if(!err) err = operationObj.getParentAccount(account);
+            SKGUnitObject unitTargetAccount;
+            if(!err) err = account.getUnit(unitTargetAccount);
+
+            SKGUnitObject unit = ui.kUnitEdit->getUnit();
+
+            if(!err && unitTargetAccount.exist() && unit != unitTargetAccount) {
+                err = getDocument()->sendMessage(i18nc("Warning message", "Warning: you created an operation in %1 in an account in %2.", unit.getSymbol(), unitTargetAccount.getSymbol()));
+            }
+            //Correction bug 282983 ^^^
+            if(!err) err = operationObj.setUnit(unit);
+        }
 
         //Save
         if(!err) err = operationObj.save();
@@ -921,7 +951,7 @@ void SKGOperationPluginWidget::onAddOperationClicked()
             if(!err) {
                 SKGUnitObject unitOfUnit;
                 err = unit.getUnit(unitOfUnit);
-                if(!!err) {
+                if(err) {
                     unitOfUnit = SKGUnitObject(getDocument());
                     err = unitOfUnit.setSymbol(static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol);
                     if(!err) err = unitOfUnit.load();
@@ -1104,107 +1134,85 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
     //Refresh widgets
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
-    if(db != NULL && (iTableName == "operation" || iTableName.isEmpty())) {
-        //Correction bug 2299394 vvv
-        if(ui.kOperationView->isAutoResized()) ui.kOperationView->resizeColumnsToContentsDelayed();
-        //Correction bug 2299394 ^^^
-
-        //Fill comboboxes
-        fillComboBoxes();
-
-        //Correction 215658: vvv because the table is modified, the selection is modified
-        onSelectionChanged();
-        //Correction 215658: ^^^
-
-        if(m_modeInfoZone != 2) onRefreshInformationZone();  //Because mode 2 is linked to selection (see onSelectionChanged)
-    }
-}
-
-void SKGOperationPluginWidget::fillComboBoxes()
-{
-    SKGTRACEIN(1, "SKGOperationPluginWidget::fillComboBoxes");
-
-    //Refresh account summary
-    QSqlDatabase* db = getDocument()->getDatabase();
-    setEnabled(db != NULL);
     if(db != NULL) {
-        //Disconnect combo filter account
-        disconnect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onAccountChanged()));
-        disconnect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onRefreshInformationZone()));
-        disconnect(ui.kUnitEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
-        disconnect(ui.kDisplayAccountCombo, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
-        disconnect(ui.kAmountEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
-        disconnect(ui.kAmountSharesEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
-        disconnect(ui.kCommissionEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
-        disconnect(ui.kTaxEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
+        if(iTableName == "account" || iTableName.isEmpty()) {
+            //Disconnect combo filter account
+            disconnect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onAccountChanged()));
+            disconnect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onRefreshInformationZoneDelayed()));
+            disconnect(ui.kDisplayAccountCombo, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()));
 
-        //Set account combos
-        QString current = ui.kDisplayAccountCombo->currentText();
+            //Set account combos
+            QString current = ui.kDisplayAccountCombo->currentText();
 
-        //Clear
-        ui.kDisplayAccountCombo->clear();
-        ui.kAccountEdit->clear();
-        ui.kPaymentAccountEdit->clear();
-        ui.kTargetAccountEdit->clear();
+            //Clear
+            ui.kDisplayAccountCombo->clear();
+            ui.kAccountEdit->clear();
+            ui.kPaymentAccountEdit->clear();
+            ui.kTargetAccountEdit->clear();
 
-        ui.kDisplayAccountCombo->addItem(i18nc("Noun", "All"));
+            ui.kDisplayAccountCombo->addItem(i18nc("Noun", "All"));
 
-        SKGStringListList listAccount;
-        getDocument()->executeSelectSqliteOrder(QString("SELECT t_ICON, t_name from v_account_display ") % (m_showClosedAccounts ? "" : "where t_close='N' order by t_name"), listAccount);
+            SKGStringListList listAccount;
+            getDocument()->executeSelectSqliteOrder(QString("SELECT t_ICON, t_name from v_account_display ") % (m_showClosedAccounts ? "" : "where t_close='N' order by t_name"), listAccount);
 
-        int nbAccounts = listAccount.count();
-        if(nbAccounts == 0) {
-            ui.kTitle->setText(i18nc("Message", "First you have to create an account."));
-            ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22) , KTitleWidget::ImageLeft);
-            ui.kTitle->show();
-        } else {
-            if(!m_lastState.hasChildNodes()) ui.kTitle->hide();
+            int nbAccounts = listAccount.count();
+            if(nbAccounts == 0) {
+                ui.kTitle->setText(i18nc("Message", "First you have to create an account."));
+                ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22) , KTitleWidget::ImageLeft);
+                ui.kTitle->show();
+            } else {
+                if(!m_lastState.hasChildNodes()) ui.kTitle->hide();
 
-            QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
-            for(int i = 1; i < nbAccounts; ++i) {  //Ignore header
-                QIcon icon(dirLogo.absoluteFilePath(listAccount.at(i).at(0)));
-                QString text = listAccount.at(i).at(1);
-                ui.kDisplayAccountCombo->addItem(icon, text);
-                ui.kAccountEdit->addItem(icon, text);
-                ui.kPaymentAccountEdit->addItem(icon, text);
-                ui.kTargetAccountEdit->addItem(icon, text);
+                QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
+                for(int i = 1; i < nbAccounts; ++i) {  //Ignore header
+                    QIcon icon(dirLogo.absoluteFilePath(listAccount.at(i).at(0)));
+                    QString text = listAccount.at(i).at(1);
+                    ui.kDisplayAccountCombo->addItem(icon, text);
+                    ui.kAccountEdit->addItem(icon, text);
+                    ui.kPaymentAccountEdit->addItem(icon, text);
+                    ui.kTargetAccountEdit->addItem(icon, text);
+                }
             }
+
+            int pos = ui.kDisplayAccountCombo->findText(current);
+            if(pos == -1) pos = 0;
+            ui.kDisplayAccountCombo->setCurrentIndex(pos);
+            if(!ui.kAccountEdit->isEnabled()) ui.kAccountEdit->setText(current);
+
+            //Connect combo filter account
+            connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onAccountChanged()), Qt::QueuedConnection);
+            connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onRefreshInformationZoneDelayed()), Qt::QueuedConnection);
+            connect(ui.kDisplayAccountCombo, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
         }
+        if(iTableName == "category" || iTableName.isEmpty()) {
+            SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
+        }
+        if(iTableName == "refund" || iTableName.isEmpty()) {
+            SKGMainPanel::fillWithDistinctValue(ui.kTrackerEdit, getDocument(), "refund", "t_name", "t_close='N'");
+        }
+        if(iTableName == "payee" || iTableName.isEmpty()) {
+            SKGMainPanel::fillWithDistinctValue(ui.kPayeeEdit, getDocument(), "payee", "t_name", "");
+        }
+        if(iTableName == "operation" || iTableName.isEmpty()) {
+            //Correction bug 2299394 vvv
+            if(ui.kOperationView->isAutoResized()) ui.kOperationView->resizeColumnsToContentsDelayed();
+            //Correction bug 2299394 ^^^
 
-        int pos = ui.kDisplayAccountCombo->findText(current);
-        if(pos == -1) pos = 0;
-        ui.kDisplayAccountCombo->setCurrentIndex(pos);
-        if(!ui.kAccountEdit->isEnabled()) ui.kAccountEdit->setText(current);
+            SKGMainPanel::fillWithDistinctValue(ui.kTypeEdit, getDocument(), "operation", "t_mode", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "operation", "t_comment", "", true);
 
-        //Set type combo
-        SKGMainPanel::fillWithDistinctValue(ui.kTypeEdit, getDocument(), "operation", "t_mode", "", true);
+            //Set type number
+            m_numberFieldIsNotUptodate = true;
 
-        //Set type category
-        SKGMainPanel::fillWithDistinctValue(ui.kCategoryEdit, getDocument(), "category", "t_fullname", "");
+            //Correction 215658: vvv because the table is modified, the selection is modified
+            onSelectionChanged();
+            //Correction 215658: ^^^
 
-        //Set type tracker
-        SKGMainPanel::fillWithDistinctValue(ui.kTrackerEdit, getDocument(), "refund", "t_name", "t_close='N'");
-
-        //Set type payee
-        SKGMainPanel::fillWithDistinctValue(ui.kPayeeEdit, getDocument(), "payee", "t_name", "");
-
-        //Set type comment
-        SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "operation", "t_comment", "", true);
-
-        //Set type number
-        m_numberFieldIsNotUptodate = true;
-
-        //Connect combo filter account
-        connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onAccountChanged()), Qt::QueuedConnection);
-        connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onRefreshInformationZone()), Qt::QueuedConnection);
-        connect(ui.kUnitEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
-        connect(ui.kDisplayAccountCombo, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
-        connect(ui.kAmountEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
-        connect(ui.kAmountSharesEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
-        connect(ui.kCommissionEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
-        connect(ui.kTaxEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+            if(m_modeInfoZone != 2) onRefreshInformationZoneDelayed();  //Because mode 2 is linked to selection (see onSelectionChanged)
+        }
     }
 }
+
 void SKGOperationPluginWidget::openOperation(const SKGOperationObject& iOperation)
 {
     _SKGTRACEIN(10, "SKGOperationPluginWidget::openOperation");
@@ -1306,6 +1314,11 @@ void SKGOperationPluginWidget::onResetInternalFilter()
     onFilterChanged();
 }
 
+void SKGOperationPluginWidget::onRefreshInformationZoneDelayed()
+{
+    m_timer.start(300);
+}
+
 void SKGOperationPluginWidget::onRefreshInformationZone()
 {
     SKGTRACEIN(1, "SKGOperationPluginWidget::onRefreshInformationZone");
@@ -1417,8 +1430,9 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
                     //Comparison
                     QString zero = doc->formatMoney(0, unit1);
                     QString negativezero = doc->formatMoney(-EPSILON, unit1);
-                    ui.kValidate->setEnabled(sdiff == zero || sdiff == negativezero);
-                    ui.kCreateFakeOperation->setEnabled(!ui.kValidate->isEnabled());
+                    ui.kValidate->setVisible(sdiff == zero || sdiff == negativezero);
+                    ui.kCreateFakeOperation->setVisible(!ui.kValidate->isVisible());
+                    ui.kAutoPoint->setVisible(!ui.kValidate->isVisible());
 
                     if(!unit2.Symbol.isEmpty() && unit2.Value) {
                         sdiff = doc->formatMoney(diff, unit2);
@@ -1468,14 +1482,14 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
 
                 double amo = i.value();
                 if(!addition.isEmpty() && amo > 0) addition += '+';
-                addition += QString("<font color=\"") % (amo < 0 ? "red" : "black") % "\">" %
-                            locale->formatMoney(amo, i.key(), decimalPerUnit[i.key()]) %
-                            "</font>";
+                SKGServices::SKGUnitInfo u2;
+                u2.Symbol = i.key();
+                u2.Value = 1.0;
+                u2.NbDecimal = decimalPerUnit[i.key()];
+                addition += doc->formatMoney(amo, u2);
             }
 
-            QString v2 = QString("<font color=\"")  % (amount < 0 ? "red" : "black") % "\">" %
-                         locale->formatMoney(amount / unit1.Value, unit1.Symbol, unit1.NbDecimal) %
-                         "</font>";
+            QString v2 = doc->formatMoney(amount / unit1.Value, unit1);
             if(nb == 0 || v2 == addition) {
                 addition = "";
             } else {
@@ -1485,7 +1499,7 @@ void SKGOperationPluginWidget::onRefreshInformationZone()
             if(nb) {
                 ui.kInfo->setText(i18np("Selection: %1 operation for %2", "Selection: %1 operations for %2", nb, v2));
                 if(!unit2.Symbol.isEmpty() && unit2.Value) {
-                    v2 = addition % "<font color=\""  % (amount < 0 ? "red" : "black") % "\">" % locale->formatMoney(amount / unit2.Value, unit2.Symbol, unit2.NbDecimal) % "</font>";
+                    v2 = addition % doc->formatMoney(amount / unit2.Value, unit2);
                 }
                 ui.kInfo->setToolTip(i18np("Selection: %1 operation for %2", "Selection: %1 operations for %2", nb, v2));
             } else {
@@ -1553,8 +1567,7 @@ void SKGOperationPluginWidget::onFilterChanged()
 
     //Update model
     if(m_objectModel) {
-        m_objectModel->setFilter(filter2);
-        ui.kOperationView->setState(ui.kOperationView->getState());
+        if(m_objectModel->setFilter(filter2)) ui.kOperationView->setState(ui.kOperationView->getState());
     }
     QApplication::restoreOverrideCursor();
 }
@@ -1893,7 +1906,7 @@ void SKGOperationPluginWidget::onSubopCellChanged(int row, int column)
         if(subop_cell->text().toDouble() != 0) {
             onQuantityChanged();
         } else {
-            base_brush.setColor(Qt::red);
+            base_brush = KColorScheme(QPalette::Normal).foreground(KColorScheme::NegativeText);
         }
         subop_cell->setForeground(base_brush);
     }
@@ -1950,7 +1963,7 @@ void SKGOperationPluginWidget::displayBalance()
     ui.kReconciliatorFrame2->hide();
     ui.kInfo->show();
     m_modeInfoZone = 0;
-    onRefreshInformationZone();
+    onRefreshInformationZoneDelayed();
 }
 
 void SKGOperationPluginWidget::displayReconciliationInfo()
@@ -1960,7 +1973,7 @@ void SKGOperationPluginWidget::displayReconciliationInfo()
         ui.kReconciliatorFrame2->show();
         ui.kInfo->hide();
         m_modeInfoZone = 1;
-        onRefreshInformationZone();
+        onRefreshInformationZoneDelayed();
     } else {
         // If more than one account is displayed, skip reconciliation mode
         // (it doesn't make sense to reconciliate several accounts at once)
@@ -1975,9 +1988,10 @@ void SKGOperationPluginWidget::displaySelectionAmount()
     ui.kReconciliatorFrame2->hide();
     ui.kInfo->show();
     m_modeInfoZone = 2;
-    onRefreshInformationZone();
+    onRefreshInformationZoneDelayed();
 }
 
+
 void SKGOperationPluginWidget::onAutoPoint()
 {
     SKGError err;
@@ -2033,7 +2047,7 @@ void SKGOperationPluginWidget::onAddFakeOperation()
     }
 
     //status bar
-    if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Operation created."));
+    if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Fake operation created."));
     else err.addError(ERR_FAIL, i18nc("Error message",  "Creation failed"));
 
     //Display error
@@ -2059,6 +2073,7 @@ void SKGOperationPluginWidget::onValidatePointedOperations()
             if(!err) err = getDocument()->stepForward(i + 1);
         }
     }
+
     //status bar
     if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Operation checked."));
     else err.addError(ERR_FAIL, i18nc("Error message",  "Switch failed"));
@@ -2079,11 +2094,14 @@ void SKGOperationPluginWidget::addSubOperationLine(int row, const QString & cate
 
     // Category
     QTableWidgetItem* categoryItem = new QTableWidgetItem(category);
+    categoryItem->setToolTip(category);
     categoryItem->setData(Qt::UserRole, id);
     ui.kSubOperationsTable->setItem(row, 0, categoryItem);
 
     // Comment
-    ui.kSubOperationsTable->setItem(row, 2, new QTableWidgetItem(comment));
+    QTableWidgetItem* commentItem = new QTableWidgetItem(comment);
+    commentItem->setToolTip(comment);
+    ui.kSubOperationsTable->setItem(row, 2, commentItem);
 
     // Quantity
     QString t = SKGServices::doubleToString(quantity);
@@ -2094,6 +2112,7 @@ void SKGOperationPluginWidget::addSubOperationLine(int row, const QString & cate
 
     // Refund
     QTableWidgetItem* trackerItem = new QTableWidgetItem(tracker);
+    trackerItem->setToolTip(tracker);
     categoryItem->setData(Qt::UserRole, id);
     ui.kSubOperationsTable->setItem(row, 3, trackerItem);
 
