@@ -85,10 +85,8 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
     if(m_currentBankDocument == NULL) return false;
 
-    KComponentData data = SKGSearchPluginFactory::componentData();
-    const_cast<KAboutData*>(data.aboutData())->setProgramName(ki18n("%1").subs(KGlobal::mainComponent().aboutData()->programName()));
-    setComponentData(data);
-    setXMLFile("skrooge_search.rc");
+    setComponentData(KGlobal::mainComponent());
+    setXMLFile("../skrooge_search/skrooge_search.rc");
 
     //Create yours actions here
     //Execute on all operation
@@ -376,10 +374,10 @@ bool SKGSearchPlugin::isInPagesChooser() const
     return true;
 }
 
-QList< SKGInterfacePlugin::SKGAdvice > SKGSearchPlugin::advices() const
+SKGAdviceList SKGSearchPlugin::advices() const
 {
     SKGTRACEIN(10, "SKGSearchPlugin::advices");
-    QList< SKGInterfacePlugin::SKGAdvice > output;
+    SKGAdviceList output;
 
     //Alarms
     SKGObjectBase::SKGListSKGObjectBase rules;
@@ -392,15 +390,16 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGSearchPlugin::advices() const
             SKGRuleObject rule = rules.at(i);
             SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
-            double pourcent = 100 * alarm.Amount / alarm.Limit;
-            if(pourcent >= 80) {
-                SKGInterfacePlugin::SKGAdvice ad;
-                ad.uuid = "skgsearchplugin_alarm|" % SKGServices::intToString(rule.getID());
-                ad.priority = 9;
-                ad.shortMessage = alarm.Message;
-                ad.longMessage = i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.<br>%2 / %3", alarm.Message, m_currentBankDocument->formatMoney(alarm.Amount, primary), m_currentBankDocument->formatMoney(alarm.Limit, primary));
-                ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm"));
-
+            double percent = 100 * alarm.Amount / alarm.Limit;
+            if(percent >= 80) {
+                SKGAdvice ad;
+                ad.setUUID("skgsearchplugin_alarm|" % SKGServices::intToString(rule.getID()));
+                ad.setPriority(9);
+                ad.setShortMessage(alarm.Message);
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.<br>%2 / %3", alarm.Message, m_currentBankDocument->formatMoney(alarm.Amount, primary), m_currentBankDocument->formatMoney(alarm.Limit, primary)));
+                QStringList autoCorrections;
+                autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open operations corresponding to this alarm"));
+                ad.setAutoCorrections(autoCorrections);
                 output.push_back(ad);
             }
         }
