@@ -64,10 +64,8 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
     if(m_currentBankDocument == NULL) return false;
 
-    KComponentData data = SKGUnitPluginFactory::componentData();
-    const_cast<KAboutData*>(data.aboutData())->setProgramName(ki18n("%1").subs(KGlobal::mainComponent().aboutData()->programName()));
-    setComponentData(data);
-    setXMLFile("skrooge_unit.rc");
+    setComponentData(KGlobal::mainComponent());
+    setXMLFile("../skrooge_unit/skrooge_unit.rc");
 
     //Menu
     m_splitShareAction = new KAction(KIcon("skrooge_split_stock"), i18nc("Verb", "Split share..."), this);
@@ -129,13 +127,28 @@ void SKGUnitPlugin::refresh()
                             err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, locale->currencyCode(), unit);
                         }
                     } else if(skgunit_settings::download_on_open()) {
-                        //download all units
-                        SKGObjectBase::SKGListSKGObjectBase selection;
-                        err = m_currentBankDocument->getObjects("unit", "", selection);
-                        int nb = selection.count();
-                        for(int i = 0; !err && i < nb; ++i) {
-                            SKGUnitObject unit = selection.at(i);
-                            err = SKGUnitPluginWidget::downloadUnitValue(unit);
+                        //Check frequency
+                        QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD");
+                        if(lastAutomaticDownload.isEmpty()) lastAutomaticDownload = "1970-01-01";
+                        QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
+                        if((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
+                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
+                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
+
+                        {
+                            //Download all units
+                            SKGObjectBase::SKGListSKGObjectBase selection;
+                            err = m_currentBankDocument->getObjects("unit", "", selection);
+                            int nb = selection.count();
+                            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb);
+                            for(int i = 0; !err && i < nb; ++i) {
+                                SKGUnitObject unit = selection.at(i);
+                                err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
+                                if(!err) err = m_currentBankDocument->stepForward(i + 1);
+                            }
+
+                            //Memorize the last download date
+                            if(!err) err = m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd"));
                         }
                     }
                 }
@@ -234,10 +247,10 @@ void SKGUnitPlugin::actionSplitShare()
     }
 }
 
-QList< SKGInterfacePlugin::SKGAdvice > SKGUnitPlugin::advices() const
+SKGAdviceList SKGUnitPlugin::advices() const
 {
     SKGTRACEIN(10, "SKGUnitPlugin::advices");
-    QList< SKGInterfacePlugin::SKGAdvice > output;
+    SKGAdviceList output;
 
     //Get all currencies
     SKGStringListList result;
@@ -249,13 +262,15 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGUnitPlugin::advices() const
         //Get unit
         QString unit = result.at(1).at(1);
 
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgunitplugin_primaryunit|" % unit;
-        ad.priority = 8;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Define a primary currency");
-        ad.longMessage = i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit));
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+        SKGAdvice ad;
+        ad.setUUID("skgunitplugin_primaryunit|" % unit);
+        ad.setPriority(8);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a primary currency"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "To avoid misunderstanding and conflicts between units at conversion time, you should define a primary currency. It is the currency against which all other will be converted"));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as primary currency", unit));
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
 
         --nb;
@@ -266,13 +281,15 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGUnitPlugin::advices() const
         //Get unit
         QString unit = result.at(1).at(1);
 
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgunitplugin_secondaryunit|" % unit;
-        ad.priority = 2;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Define a secondary currency");
-        ad.longMessage = i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information.");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit));
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+        SKGAdvice ad;
+        ad.setUUID("skgunitplugin_secondaryunit|" % unit);
+        ad.setPriority(2);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Define a secondary currency"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "When a secondary unit is defined, Skrooge will display it as an additional amount information."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Set '%1' as secondary currency", unit));
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
@@ -285,13 +302,15 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGUnitPlugin::advices() const
         QString unit = line.at(0);
         QString internet_code = line.at(1);
 
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgunitplugin_notdownloaded|" % unit;
-        ad.priority = 5;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit);
-        ad.longMessage = i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
-        if(!internet_code.isEmpty()) ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
+        SKGAdvice ad;
+        ad.setUUID("skgunitplugin_notdownloaded|" % unit);
+        ad.setPriority(5);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has not been downloaded for more than a month", unit));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget download units to have a better view of your accounts"));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+        if(!internet_code.isEmpty()) autoCorrections.push_back(i18nc("Advice on making the best (action)", "Download '%1'", unit));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
@@ -299,12 +318,14 @@ QList< SKGInterfacePlugin::SKGAdvice > SKGUnitPlugin::advices() const
     bool exist = false;
     m_currentBankDocument->existObjects("unit", "t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)", exist);
     if(exist) {
-        SKGInterfacePlugin::SKGAdvice ad;
-        ad.uuid = "skgunitplugin_unused";
-        ad.priority = 5;
-        ad.shortMessage = i18nc("Advice on making the best (short)", "Many unused units");
-        ad.longMessage = i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered.");
-        ad.autoCorrection.push_back(i18nc("Advice on making the best (action)", "Delete unused units"));
+        SKGAdvice ad;
+        ad.setUUID("skgunitplugin_unused");
+        ad.setPriority(5);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Delete unused units"));
+        ad.setAutoCorrections(autoCorrections);
         output.push_back(ad);
     }
 
@@ -382,7 +403,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             SKGUnitObject unitObj(m_currentBankDocument);
             err = unitObj.setName(unit);
             if(!err) err = unitObj.load();
-            if(!err) err = SKGUnitPluginWidget::downloadUnitValue(unitObj);
+            if(!err) err = SKGUnitPluginWidget::downloadUnitValue(unitObj, SKGUnitPluginWidget::getDownloadModeFromSettings());
 
             //Display error
             SKGMainPanel::displayErrorMessage(err);
@@ -406,12 +427,12 @@ void SKGUnitPlugin::deleteUnusedUnits() const
         //Modification of payee object
         QString sql = "DELETE FROM unit WHERE t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)";
         err = m_currentBankDocument->executeSqliteOrder(sql);
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Unused units deleted"));
-        else err.addError(ERR_FAIL, i18nc("Error message", "Unused units deletion failed"));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("Successful message after an user action", "Unused units deleted"));
+    else err.addError(ERR_FAIL, i18nc("Error message", "Unused units deletion failed"));
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
