@@ -101,6 +101,42 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitUpdate->setIcon(KIcon("dialog-ok-apply"));
     ui.kUnitValueDownload->setIcon(KIcon("download"));
 
+    KAction* downloadMonthlyAction = new KAction(KIcon("download"), i18n("download all monthly values"), this);
+    downloadMonthlyAction->setData(SKGUnitObject::ALL_MONTHLY);
+    connect(downloadMonthlyAction, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadWeeklyAction = new KAction(KIcon("download"), i18n("download all weekly values"), this);
+    downloadWeeklyAction->setData(SKGUnitObject::ALL_WEEKLY);
+    connect(downloadWeeklyAction, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadDailyAction = new KAction(KIcon("download"), i18n("download all daily values"), this);
+    downloadDailyAction->setData(SKGUnitObject::ALL_DAILY);
+    connect(downloadDailyAction, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadLastMonthlyAction = new KAction(KIcon("download"), i18n("download monthly values since last known value"), this);
+    downloadLastMonthlyAction->setData(SKGUnitObject::LAST_MONTHLY);
+    connect(downloadLastMonthlyAction, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadLastWeeklyAction = new KAction(KIcon("download"), i18n("download weekly values since last known value"), this);
+    downloadLastWeeklyAction->setData(SKGUnitObject::LAST_WEEKLY);
+    connect(downloadLastWeeklyAction, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+    KAction* downloadLastDailyAction = new KAction(KIcon("download"), i18n("download daily values since last known value"), this);
+    downloadLastDailyAction->setData(SKGUnitObject::LAST_DAILY);
+    connect(downloadLastDailyAction, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
+
+
+    KMenu* downloadMenu = new KMenu();
+    downloadMenu->addAction(downloadMonthlyAction);
+    downloadMenu->addAction(downloadWeeklyAction);
+    downloadMenu->addAction(downloadDailyAction);
+    downloadMenu->addAction(downloadLastMonthlyAction);
+    downloadMenu->addAction(downloadLastWeeklyAction);
+    downloadMenu->addAction(downloadLastDailyAction);
+
+
+    ui.kUnitValueDownload->setMenu(downloadMenu);
+    connect(ui.kUnitValueDownload, SIGNAL(clicked(bool)), SLOT(onDownloadUnitValue()));
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kStandardFrm);
@@ -111,7 +147,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kManualFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(KIcon("user-properties"), i18n("Manual"), i18n("Display the edition panel for manual units"), list);
+        ui.kWidgetSelector->addButton(KIcon("user-properties"), i18n("Manual / Share"), i18n("Display the edition panel for manual units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
@@ -282,10 +318,14 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
 
             SKGObjectModel* model = static_cast<SKGObjectModel*>(ui.kUnitValueTableViewEdition->model());
             if(model) {
-                SKGUnitValueObject unit(model->getObject(idx));
+                SKGUnitValueObject unitValue(model->getObject(idx));
+                SKGUnitObject unit;
+                unitValue.getUnit(unit);
 
-                ui.kDateEdit->setDate(unit.getDate());
-                ui.kAmountEdit->setText(KGlobal::locale()->formatMoney(SKGServices::stringToDouble(unit.getAttribute("f_quantity")), "", 2));
+                ui.kDateEdit->setDate(unitValue.getDate());
+                ui.kAmountEdit->setText(KGlobal::locale()->formatMoney(SKGServices::stringToDouble(unitValue.getAttribute("f_quantity")),
+                                        "",
+                                        SKGServices::stringToInt(unit.getAttribute("i_nbdecimal"))));
             }
         } else {
             ui.kDateEdit->setDate(QDate::currentDate());
@@ -305,7 +345,7 @@ void SKGUnitPluginWidget::onUnitCreatorModified()
 
     int nbSelect = getNbSelectedObjects();
 
-    ui.kUnitAdd->setEnabled(activated || ui.kWidgetSelector->getSelectedMode() == 0);
+    ui.kUnitAdd->setEnabled((activated && (ui.kAmountEdit->valid() || ui.kWidgetSelector->getSelectedMode() != 2)) || ui.kWidgetSelector->getSelectedMode() == 0);
     ui.kUnitUpdate->setEnabled(activated && nbSelect > 0 && ui.kWidgetSelector->getSelectedMode() == 1);
 
     ui.kWidgetSelector->setEnabledMode(2, nbSelect == 1);
@@ -355,7 +395,8 @@ void SKGUnitPluginWidget::onAddUnit()
         //status bar
         if(!err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Unit value created for '%1'", untiname));
-            //TODO doesn't work because of unit table is modified an refreshed ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
+            //TODO doesn't work because of unit table is modified an refreshed
+            ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
         } else err.addError(ERR_FAIL, i18nc("Error message", "Unit value creation failed"));
     }
 
@@ -394,7 +435,7 @@ void SKGUnitPluginWidget::onModifyUnit()
             nb = 1;
         }
 
-        for(int i = 0; !err && i < nb; i++) {
+        for(int i = 0; !err && i < nb; ++i) {
             //Modification of unit object
             SKGUnitObject unitObj = selection[i];
             if(!err) err = unitObj.setName(ui.kNameCreatorUnit->text());
@@ -407,12 +448,12 @@ void SKGUnitPluginWidget::onModifyUnit()
             if(!err) err = unitObj.save();
             if(!err) err = getDocument()->stepForward(i + 1);
         }
-
-        //status bar
-        if(!err) err = SKGError(0, i18nc("Message for successful user action", "Unit updated"));
-        else err.addError(ERR_FAIL, i18nc("Error message", "Unit update failed"));
     }
 
+    //status bar
+    if(!err) err = SKGError(0, i18nc("Message for successful user action", "Unit updated"));
+    else err.addError(ERR_FAIL, i18nc("Error message", "Unit update failed"));
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 }
@@ -461,10 +502,8 @@ void SKGUnitPluginWidget::onDoubleClickUnit()
     }
 }
 
-SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit)
+SKGUnitObject::UnitDownloadMode SKGUnitPluginWidget::getDownloadModeFromSettings()
 {
-    SKGError err;
-    SKGTRACEINRC(10, "SKGUnitPluginWidget::downloadUnitValue", err);
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
     if(skgunit_settings::last()) mode = SKGUnitObject::LAST;
     else if(skgunit_settings::last_monthly()) mode = SKGUnitObject::LAST_MONTHLY;
@@ -473,6 +512,13 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit)
     else if(skgunit_settings::all_monthly())  mode = SKGUnitObject::ALL_MONTHLY;
     else if(skgunit_settings::all_weekly())   mode = SKGUnitObject::ALL_WEEKLY;
     else if(skgunit_settings::all_daily())    mode = SKGUnitObject::ALL_DAILY;
+    return mode;
+}
+
+SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, SKGUnitObject::UnitDownloadMode mode)
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGUnitPluginWidget::downloadUnitValue", err);
 
     QString unitname = iUnit.getName();
     QString code = iUnit.getInternetCode();
@@ -489,12 +535,16 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGUnitPluginWidget::onDownloadUnitValue", err);
-    {
-        SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
-        int nb = selection.count();
-        for(int i = 0; !err && i < nb; ++i) {
-            err = downloadUnitValue(selection.at(i));
-        }
+
+    SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
+    KAction* act = qobject_cast<KAction*>(sender());
+    if(act) mode = (SKGUnitObject::UnitDownloadMode) act->data().toInt();
+    else mode = SKGUnitPluginWidget::getDownloadModeFromSettings();
+
+    SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
+    int nb = selection.count();
+    for(int i = 0; !err && i < nb; ++i) {
+        err = downloadUnitValue(selection.at(i), mode);
     }
 
     //Display error
