@@ -20,7 +20,7 @@
 #include <Plasma/DataEngine>
 
 #include <skgdocument.h>
-
+#include <skgdocumentbank.h>
 
 /**
  * This class is the skrooge dataengine. It allows fetching data
@@ -32,21 +32,21 @@ class SKGDataEngine : public Plasma::DataEngine
     Q_OBJECT
 
 public:
-
-
     /**
      * Reimplemented from Plasma::DataEngine
      */
     SKGDataEngine(QObject* parent, const QVariantList& args);
 
-
     /**
      * Destructor
      */
     virtual ~SKGDataEngine();
 
 
-
+    /**
+     * Reimplemented from Plasma::DataEngine
+     */
+    virtual void init();
 
 protected:
 
@@ -66,24 +66,48 @@ protected:
      * Sets the Document to use
      * @param iDocument the document
      */
-    virtual void setDocument(SKGDocument* iDocument);
+    virtual void setDocument(SKGDocumentBank* iDocument);
 
     /**
      * Returns the current document
      * @return the document
      */
-    SKGDocument* getDocument();
-
+    virtual SKGDocumentBank* getDocument() const;
 
     /**
      * Get some basic data on Accounts
      */
-    bool getAccountData();
+    virtual bool getAccountData();
+
+    /**
+     * Get some basic data on Banks
+     */
+    virtual bool getBankData();
 
     /**
      * Get Income and Expenditure Data
      */
-    bool getIncomeExpenditureData();
+    virtual bool getIncomeExpenditureData();
+
+    /**
+     * Get Highlighted operations
+     */
+    virtual bool getHighlightedOperationData();
+
+    /**
+     * Get Scheduled operations
+     */
+    virtual bool getScheduledOperationData();
+
+    /**
+     * Get data on Units
+     */
+    virtual bool getUnitsData();
+
+    /**
+     * Get data on Advices
+     */
+    virtual bool getAdvicesData();
 
     /**
      * Reimplemented from Plasma::DataEngine
@@ -97,7 +121,7 @@ private:
     /**
      * The document used to retrieve data
      */
-    SKGDocument* document;
+    SKGDocumentBank* document;
 
 };
 
