@@ -50,7 +50,7 @@
 SKGObjectModel::SKGObjectModel(SKGDocumentBank* iDocument,
                                const QString& iTable,
                                const QString& iWhereClause,
-                               QObject *parent,
+                               QWidget *parent,
                                const QString& iParentAttribute,
                                bool iResetOnCreation)
     : SKGObjectModelBase(iDocument, iTable, iWhereClause, parent, iParentAttribute, false)
@@ -89,12 +89,12 @@ void SKGObjectModel::buidCache()
             m_cacheUnit.Name = parent.getName();
             m_cacheUnit.Symbol = parent.getSymbol();
             m_cacheUnit.Value = 1;
-            m_cacheUnit.NbDecimal = parent.getNumberDecimal();
+            m_cacheUnit.NbDecimal = unitObject.getNumberDecimal();
         } else {
             m_cacheUnit.Name = "";
             m_cacheUnit.Symbol = "";
             m_cacheUnit.Value = 1;
-            m_cacheUnit.NbDecimal = 2;
+            m_cacheUnit.NbDecimal = unitObject.getNumberDecimal();
         }
         if(m_cacheUnit.Symbol.isEmpty()) m_cacheUnit.Symbol = ' ';
 
@@ -122,7 +122,7 @@ void SKGObjectModel::buidCache()
         m_fontDisabledScheduleColor = qVariantFromValue(pref.readEntry("fontFutureColor", QColor(Qt::gray)));
     }
 
-    if(m_operationTable || m_recurrentoperationTable || m_accountTable || m_ruleTable) {
+    if(m_operationTable || m_recurrentoperationTable || m_accountTable || m_ruleTable || m_categoryTable || m_payeeTable) {
         m_iconFavorite = KIcon("rating");
     }
 
@@ -178,7 +178,6 @@ void SKGObjectModel::buidCache()
             m_iconCategoryPlus = KIcon("skrooge_category", NULL, overlay);
         }
     }
-    m_fontRedColor = qVariantFromValue(qVariantFromValue(QColor(Qt::red)));
 }
 
 SKGObjectModel::~SKGObjectModel()
@@ -202,19 +201,40 @@ QVariant SKGObjectModel::headerData(int section, Qt::Orientation orientation, in
     return SKGObjectModelBase::headerData(section, orientation, role);
 }
 
+QString SKGObjectModel::getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const
+{
+    if(m_recurrentoperationTable && iAttribute == "i_nb_times") {
+        if(iObject.getAttribute("t_times") != "Y") return QChar(8734);
+    } else if(m_ruleTable && iAttribute == "t_action_type") {
+        QString val = iObject.getAttribute(iAttribute);
+        if(val == "S") val = i18nc("Noun, a search", "Search");
+        else if(val == "U") val = i18nc("Noun, a modification", "Update");
+        else val = i18nc("Noun, an alarm", "Alarm");
+        return val;
+    } else if(iAttribute == "t_bookmarked" || iAttribute == "t_close") {
+        QString val = iObject.getAttribute(iAttribute);
+        return val == "Y" ? i18n("Yes") : i18n("No");
+    } else if(iAttribute == "t_status") {
+        QString val = iObject.getAttribute(iAttribute);
+        return val == "N" ? i18n("None") : val == "P" ? i18n("Pointed") : i18n("Checked");
+    }
+    return SKGObjectModelBase::getAttributeForGrouping(iObject, iAttribute);
+}
+
 QVariant SKGObjectModel::data(const QModelIndex &index, int role) const
 {
     if(!index.isValid()) return QVariant();
     _SKGTRACEIN(10, "SKGObjectModel::data");
+    SKGObjectBase* obj = getObjectPointer(index);
+    if(obj->getTable().isEmpty()) return SKGObjectModelBase::data(index, role);
 
     switch(role) {
     case Qt::DisplayRole:
     case Qt::EditRole:
     case Qt::UserRole: {
-        SKGObjectBase* obj = getObjectPointer(index);
         QString att = m_listAttibutes[index.column()];
         QString val = obj->getAttribute(att);
-        if(((m_operationTable || m_recurrentoperationTable || m_trackerTable || m_accountTable || m_ruleTable) &&
+        if(((m_operationTable || m_recurrentoperationTable || m_trackerTable || m_accountTable || m_ruleTable || m_categoryTable || m_payeeTable) &&
                 (att == "t_bookmarked" || att == "t_status" || att == "i_NBRECURRENT" || att == "t_imported"))
                 || (att == "t_close")
                 || (att == "t_action_type")
@@ -316,12 +336,10 @@ QVariant SKGObjectModel::data(const QModelIndex &index, int role) const
 
             return SKGServices::stringToInt(val);
         }
-
         break;
     }
     case Qt::DecorationRole: {
         //decoration
-        SKGObjectBase* obj = getObjectPointer(index);
         QString att = m_listAttibutes[index.column()];
         if(m_operationTable || m_recurrentoperationTable) {
             if(att == "t_mode") {
@@ -392,6 +410,12 @@ else return KIcon();
                 if(t_TYPEEXPENSE == "-") return m_iconCategoryMoins;
                 else if(t_TYPEEXPENSE == "+") return m_iconCategoryPlus;
                 return m_iconCategory;
+            } else if(att == "t_bookmarked") {
+                if(obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
+            }
+        } else if(m_payeeTable) {
+            if(att == "t_bookmarked") {
+                if(obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
             }
         } else if(m_budgetTable) {
             if(att == "f_DELTA" || att == "f_DELTABEFORETRANSFER") {
@@ -411,11 +435,10 @@ else return KIcon();
     }
     case Qt::TextColorRole: {
         //Text color
-        SKGObjectBase* obj = getObjectPointer(index);
         QString att = m_listAttibutes[index.column()];
         if(m_recurrentoperationTable) {
             if(obj->getAttribute("i_nb_times") == "0") return  m_fontDisabledScheduleColor;
-            else if(att == "d_date" && SKGServices::stringToTime(obj->getAttribute("d_date")).date() <= QDate::currentDate()) return m_fontRedColor;
+            else if(att == "d_date" && SKGServices::stringToTime(obj->getAttribute("d_date")).date() <= QDate::currentDate()) return m_fontNegativeColor;
         } else if(m_operationTable) {
             if(SKGServices::stringToTime(obj->getAttribute("d_date")).date() > QDate::currentDate()) return m_fontFutureOperationsColor;
             else if(getAttributeType(index.column()) != SKGServices::FLOAT) {
@@ -436,54 +459,50 @@ else return KIcon();
         }
         break;
     }
-
     case Qt::CheckStateRole: {
         //CheckState
-        SKGObjectBase* obj = getObjectPointer(index);
-        if(obj) {
-            QString att = m_listAttibutes[index.column()];
-            if(m_operationTable && att == "t_status") {
-                QString cond = obj->getAttribute("t_status");
-                if(cond == "P") return Qt::PartiallyChecked;
-                else if(cond == "Y") return Qt::Checked;
-                else if(cond == "N") return Qt::Unchecked;
-            } else if(att == "t_close") {
-                QString cond = obj->getAttribute("t_close");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_recurrentoperationTable && att == "i_auto_write_days") {
-                QString cond = obj->getAttribute("t_auto_write");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_recurrentoperationTable && att == "i_warn_days") {
-                QString cond = obj->getAttribute("t_warn");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_recurrentoperationTable && att == "i_nb_times") {
-                QString cond = obj->getAttribute("t_times");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_budgetRuleTable && att == "t_CATEGORYCONDITION") {
-                QString cond = obj->getAttribute("t_category_condition");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_budgetRuleTable && att == "i_year") {
-                QString cond = obj->getAttribute("t_year_condition");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_budgetRuleTable && att == "i_month") {
-                QString cond = obj->getAttribute("t_month_condition");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_budgetRuleTable && att == "t_CATEGORY") {
-                QString cond = obj->getAttribute("t_category_target");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            } else  if(m_budgetTable && att == "t_CATEGORY") {
-                QString cond = obj->getAttribute("t_including_subcategories");
-                if(cond == "Y") return Qt::Checked;
-                else return Qt::Unchecked;
-            }
+        QString att = m_listAttibutes[index.column()];
+        if(m_operationTable && att == "t_status") {
+            QString cond = obj->getAttribute("t_status");
+            if(cond == "P") return Qt::PartiallyChecked;
+            else if(cond == "Y") return Qt::Checked;
+            else if(cond == "N") return Qt::Unchecked;
+        } else if(att == "t_close") {
+            QString cond = obj->getAttribute("t_close");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_recurrentoperationTable && att == "i_auto_write_days") {
+            QString cond = obj->getAttribute("t_auto_write");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_recurrentoperationTable && att == "i_warn_days") {
+            QString cond = obj->getAttribute("t_warn");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_recurrentoperationTable && att == "i_nb_times") {
+            QString cond = obj->getAttribute("t_times");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_budgetRuleTable && att == "t_CATEGORYCONDITION") {
+            QString cond = obj->getAttribute("t_category_condition");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_budgetRuleTable && att == "i_year") {
+            QString cond = obj->getAttribute("t_year_condition");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_budgetRuleTable && att == "i_month") {
+            QString cond = obj->getAttribute("t_month_condition");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_budgetRuleTable && att == "t_CATEGORY") {
+            QString cond = obj->getAttribute("t_category_target");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
+        } else  if(m_budgetTable && att == "t_CATEGORY") {
+            QString cond = obj->getAttribute("t_including_subcategories");
+            if(cond == "Y") return Qt::Checked;
+            else return Qt::Unchecked;
         }
         break;
     }
@@ -492,70 +511,63 @@ else return KIcon();
         QString toolTipString;
         QString att = m_listAttibutes[index.column()];
         if(getAttributeType(index.column()) == SKGServices::FLOAT) {
-            SKGObjectBase* obj = getObjectPointer(index);
-            if(obj) {
-                //Add secondary unit
-                if(!att.contains("QUANTITY") && att != "f_coef" && att != "f_rate") {
-                    SKGServices::SKGUnitInfo secondaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
-                    if(!secondaryUnit.Symbol.isEmpty()) {
-                        double val = SKGServices::stringToDouble(obj->getAttribute(att));
-                        if((!att.endsWith(QLatin1String("_INCOME")) && !att.endsWith(QLatin1String("_EXPENSE"))) || val != 0) {
-                            if(secondaryUnit.Value)  toolTipString = KGlobal::locale()->formatMoney(val / secondaryUnit.Value, secondaryUnit.Symbol, secondaryUnit.NbDecimal);
-
-                        }
+            //Add secondary unit
+            if(!att.contains("QUANTITY") && att != "f_coef" && att != "f_rate") {
+                SKGServices::SKGUnitInfo secondaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
+                if(!secondaryUnit.Symbol.isEmpty()) {
+                    double val = SKGServices::stringToDouble(obj->getAttribute(att));
+                    if((!att.endsWith(QLatin1String("_INCOME")) && !att.endsWith(QLatin1String("_EXPENSE"))) || val != 0) {
+                        if(secondaryUnit.Value)  toolTipString = KGlobal::locale()->formatMoney(val / secondaryUnit.Value, secondaryUnit.Symbol, secondaryUnit.NbDecimal);
 
                     }
-                }
 
-                //Add original amount
-                QString originalAmount = obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
-                if(!originalAmount.isEmpty()) {
+                }
+            }
+
+            //Add original amount
+            QString originalAmount = obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
+            if(!originalAmount.isEmpty()) {
+                if(!toolTipString.isEmpty()) toolTipString += "\n\n";
+                double val1 = SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
+                double val2 = SKGServices::stringToDouble(originalAmount);
+                double gain = (val2 != 0 ? 100.0 * (val1 - val2) / val2 : 0);
+                SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                toolTipString += i18nc("Noun", "Original amount=%1 (%2 %)",
+                                       KGlobal::locale()->formatMoney(val2, primaryUnit.Symbol, primaryUnit.NbDecimal),
+                                       gain);
+            }
+
+            //Add balance
+            if(m_operationTable) {
+                SKGOperationObject op = *obj;
+                if(!op.isTemplate()) {
                     if(!toolTipString.isEmpty()) toolTipString += "\n\n";
-                    double val1 = SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
-                    double val2 = SKGServices::stringToDouble(originalAmount);
-                    double gain = (val2 != 0 ? 100.0 * (val1 - val2) / val2 : 0);
                     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
-                    toolTipString += i18nc("Noun", "Original amount=%1 (%2 %)",
-                                           KGlobal::locale()->formatMoney(val2, primaryUnit.Symbol, primaryUnit.NbDecimal),
-                                           gain);
+                    toolTipString += i18nc("Noun", "Account balance=%1",
+                                           KGlobal::locale()->formatMoney(op.getBalance(), primaryUnit.Symbol, primaryUnit.NbDecimal));
                 }
+            }
 
-                //Add balance
-                if(m_operationTable) {
-                    SKGOperationObject op = *obj;
-                    if(!op.isTemplate()) {
-                        if(!toolTipString.isEmpty()) toolTipString += "\n\n";
-                        SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
-                        toolTipString += i18nc("Noun", "Account balance=%1",
-                                               KGlobal::locale()->formatMoney(op.getBalance(), primaryUnit.Symbol, primaryUnit.NbDecimal));
-                    }
-                }
+            if(m_budgetTable) {
+                if(att == "f_DELTA") {
+                    double val = SKGServices::stringToDouble(obj->getAttribute("f_DELTABEFORETRANSFER"));
 
-                if(m_budgetTable) {
-                    if(att == "f_DELTA") {
-                        SKGObjectBase* obj = getObjectPointer(index);
-                        if(obj) {
-                            double val = SKGServices::stringToDouble(obj->getAttribute("f_DELTABEFORETRANSFER"));
+                    if(!toolTipString.isEmpty()) toolTipString += "\n\n";
 
-                            if(!toolTipString.isEmpty()) toolTipString += "\n\n";
-
-                            SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
-                            toolTipString += i18nc("Noun", "Original delta=%1",
-                                                   KGlobal::locale()->formatMoney(val, primaryUnit.Symbol, primaryUnit.NbDecimal));
-                        }
-                    }
+                    SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                    toolTipString += i18nc("Noun", "Original delta=%1",
+                                           KGlobal::locale()->formatMoney(val, primaryUnit.Symbol, primaryUnit.NbDecimal));
                 }
             }
         } else if(m_operationTable || m_recurrentoperationTable) {
             if(att == "t_imported") {
-                SKGOperationObject op = *(getObjectPointer(index));
+                SKGOperationObject op = *obj;
                 if(m_recurrentoperationTable) {
-                    SKGRecurrentOperationObject rop = *(getObjectPointer(index));
+                    SKGRecurrentOperationObject rop = *obj;
                     rop.getParentOperation(op);
                 }
                 toolTipString = op.getImportID();
             } else if(att == "t_REFUND" || att == "t_REALREFUND") {
-                SKGObjectBase* obj = getObjectPointer(index);
                 QString trackerName;
                 if(obj) trackerName = obj->getAttribute(att);
                 if(!trackerName.isEmpty()) {
@@ -566,9 +578,9 @@ else return KIcon();
                     toolTipString = KGlobal::locale()->formatMoney(tracker.getCurrentAmount(), unit.Symbol, unit.NbDecimal);
                 }
             } else if(att == "t_CATEGORY") {
-                SKGOperationObject op = *(getObjectPointer(index));
+                SKGOperationObject op = *obj;
                 if(m_recurrentoperationTable) {
-                    SKGRecurrentOperationObject rop = *(getObjectPointer(index));
+                    SKGRecurrentOperationObject rop = *obj;
                     rop.getParentOperation(op);
                 }
                 if(SKGServices::stringToInt(op.getAttribute("i_NBSUBCATEGORY")) > 1) {
@@ -579,9 +591,9 @@ else return KIcon();
                     }
                 }
             } else if(att == "t_mode") {
-                SKGOperationObject op = *(getObjectPointer(index));
+                SKGOperationObject op = *obj;
                 if(m_recurrentoperationTable) {
-                    SKGRecurrentOperationObject rop = *(getObjectPointer(index));
+                    SKGRecurrentOperationObject rop = *obj;
                     rop.getParentOperation(op);
                 }
                 if(op.getAttribute("i_group_id") != "0") {
@@ -599,7 +611,7 @@ else return KIcon();
             }
 
             if(m_operationTable && toolTipString.isEmpty()) {
-                SKGOperationObject op = *(getObjectPointer(index));
+                SKGOperationObject op = *obj;
                 if(op.getStatus() == SKGOperationObject::POINTED) {
                     toolTipString = i18nc("A tool tip", "This operation is pointed but not checked yet.");
                     toolTipString += '\n';
@@ -648,91 +660,93 @@ bool SKGObjectModel::setData(const QModelIndex & index, const QVariant & value,
 
     if(role == Qt::CheckStateRole) {
         SKGError err;
-        if(m_accountTable) {
-            SKGAccountObject obj = getObject(index);
-            SKGBEGINTRANSACTION(*getDocument(),
-                                ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
-            err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
-            if(!err) err = obj.save();
-        } else if(m_trackerTable) {
-            SKGTrackerObject obj = getObject(index);
-            SKGBEGINTRANSACTION(*getDocument(),
-                                ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
-            err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
-            if(!err) err = obj.save();
-        } else if(m_operationTable) {
-            SKGOperationObject obj = getObject(index);
-            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
-            SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
-            SKGOperationObject::OperationStatus t_status = statusinitial;
-            if(QApplication::keyboardModifiers() &Qt::ControlModifier) {
-                //2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
-                t_status = SKGOperationObject::CHECKED ;
-                //t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
-            } else {
-                //2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
-                t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::POINTED : (t_status == SKGOperationObject::POINTED ? SKGOperationObject::NONE : SKGOperationObject::POINTED));
-                //t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
-            }
-            if(t_status != statusinitial) {
-                err = obj.setStatus(t_status);
+        {
+            if(m_accountTable) {
+                SKGAccountObject obj = getObject(index);
+                SKGBEGINLIGHTTRANSACTION(*getDocument(),
+                                         ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
+                err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
                 if(!err) err = obj.save();
-            }
-        } else if(m_recurrentoperationTable) {
-            QString att = m_listAttibutes[index.column()];
-
-            //Get the real object, not the object from the view
-            SKGObjectBase* objtmp = getObjectPointer(index);
-            if(objtmp) {
-                SKGRecurrentOperationObject obj = SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
-
-                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err);
-                if(att == "i_warn_days") {
-                    err = obj.warnEnabled(!obj.isWarnEnabled());
-                    if(!err) err = obj.save();
-                } else if(att == "i_auto_write_days") {
-                    err = obj.autoWriteEnabled(!obj.isAutoWriteEnabled());
-                    if(!err) err = obj.save();
-                } else if(att == "i_nb_times") {
-                    err = obj.timeLimit(!obj.hasTimeLimit());
+            } else if(m_trackerTable) {
+                SKGTrackerObject obj = getObject(index);
+                SKGBEGINLIGHTTRANSACTION(*getDocument(),
+                                         ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
+                err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
+                if(!err) err = obj.save();
+            } else if(m_operationTable) {
+                SKGOperationObject obj = getObject(index);
+                SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
+                SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
+                SKGOperationObject::OperationStatus t_status = statusinitial;
+                if(QApplication::keyboardModifiers() &Qt::ControlModifier) {
+                    //2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
+                    t_status = SKGOperationObject::CHECKED ;
+                    //t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
+                } else {
+                    //2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
+                    t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::POINTED : (t_status == SKGOperationObject::POINTED ? SKGOperationObject::NONE : SKGOperationObject::POINTED));
+                    //t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
+                }
+                if(t_status != statusinitial) {
+                    err = obj.setStatus(t_status);
                     if(!err) err = obj.save();
                 }
-            }
-        } else if(m_budgetRuleTable) {
-            QString att = m_listAttibutes[index.column()];
+            } else if(m_recurrentoperationTable) {
+                QString att = m_listAttibutes[index.column()];
 
-            //Get the real object, not the object from the view
-            SKGObjectBase* objtmp = getObjectPointer(index);
-            if(objtmp) {
-                SKGBudgetRuleObject obj = SKGBudgetRuleObject(objtmp->getDocument(), objtmp->getID());
+                //Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(index);
+                if(objtmp) {
+                    SKGRecurrentOperationObject obj = SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
 
-                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err);
-                if(att == "i_year") {
-                    err = obj.enableYearCondition(!obj.isYearConditionEnabled());
-                    if(!err) err = obj.save();
-                } else if(att == "i_month") {
-                    err = obj.enableMonthCondition(!obj.isMonthConditionEnabled());
-                    if(!err) err = obj.save();
-                } else if(att == "t_CATEGORYCONDITION") {
-                    err = obj.enableCategoryCondition(!obj.isCategoryConditionEnabled());
-                    if(!err) err = obj.save();
-                } else if(att == "t_CATEGORY") {
-                    err = obj.enableCategoryChange(!obj.isCategoryChangeEnabled());
-                    if(!err) err = obj.save();
+                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err);
+                    if(att == "i_warn_days") {
+                        err = obj.warnEnabled(!obj.isWarnEnabled());
+                        if(!err) err = obj.save();
+                    } else if(att == "i_auto_write_days") {
+                        err = obj.autoWriteEnabled(!obj.isAutoWriteEnabled());
+                        if(!err) err = obj.save();
+                    } else if(att == "i_nb_times") {
+                        err = obj.timeLimit(!obj.hasTimeLimit());
+                        if(!err) err = obj.save();
+                    }
                 }
-            }
-        } else if(m_budgetTable) {
-            QString att = m_listAttibutes[index.column()];
+            } else if(m_budgetRuleTable) {
+                QString att = m_listAttibutes[index.column()];
 
-            //Get the real object, not the object from the view
-            SKGObjectBase* objtmp = getObjectPointer(index);
-            if(objtmp) {
-                SKGBudgetObject obj = SKGBudgetObject(objtmp->getDocument(), objtmp->getID());
+                //Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(index);
+                if(objtmp) {
+                    SKGBudgetRuleObject obj = SKGBudgetRuleObject(objtmp->getDocument(), objtmp->getID());
 
-                SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget update"), err);
-                if(att == "t_CATEGORY") {
-                    err = obj.enableSubCategoriesInclusion(!obj.isSubCategoriesInclusionEnabled());
-                    if(!err) err = obj.save();
+                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err);
+                    if(att == "i_year") {
+                        err = obj.enableYearCondition(!obj.isYearConditionEnabled());
+                        if(!err) err = obj.save();
+                    } else if(att == "i_month") {
+                        err = obj.enableMonthCondition(!obj.isMonthConditionEnabled());
+                        if(!err) err = obj.save();
+                    } else if(att == "t_CATEGORYCONDITION") {
+                        err = obj.enableCategoryCondition(!obj.isCategoryConditionEnabled());
+                        if(!err) err = obj.save();
+                    } else if(att == "t_CATEGORY") {
+                        err = obj.enableCategoryChange(!obj.isCategoryChangeEnabled());
+                        if(!err) err = obj.save();
+                    }
+                }
+            } else if(m_budgetTable) {
+                QString att = m_listAttibutes[index.column()];
+
+                //Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(index);
+                if(objtmp) {
+                    SKGBudgetObject obj = SKGBudgetObject(objtmp->getDocument(), objtmp->getID());
+
+                    SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget update"), err);
+                    if(att == "t_CATEGORY") {
+                        err = obj.enableSubCategoriesInclusion(!obj.isSubCategoriesInclusionEnabled());
+                        if(!err) err = obj.save();
+                    }
                 }
             }
         }
@@ -754,7 +768,7 @@ Qt::ItemFlags SKGObjectModel::flags(const QModelIndex & index) const
         if(att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable) flags = flags & ~Qt::ItemIsEditable;
     }
 
-    if(m_categoryTable || m_payeeTable || m_accountTable || m_unitTable) {
+    if(m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
         if(index.isValid()) flags |= Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
         else flags |= Qt::ItemIsDropEnabled;
     }
@@ -764,13 +778,13 @@ Qt::ItemFlags SKGObjectModel::flags(const QModelIndex & index) const
 
 Qt::DropActions SKGObjectModel::supportedDragActions() const
 {
-    if(m_categoryTable || m_payeeTable || m_accountTable || m_unitTable) return Qt::MoveAction;
+    if(m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) return Qt::MoveAction;
     return SKGObjectModelBase::supportedDragActions();
 }
 
 Qt::DropActions SKGObjectModel::supportedDropActions() const
 {
-    if(m_categoryTable || m_payeeTable || m_accountTable || m_unitTable) return Qt::MoveAction;
+    if(m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) return Qt::MoveAction;
     return SKGObjectModelBase::supportedDropActions();
 }
 
@@ -784,6 +798,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData * data,
     if(!data || !(data->hasFormat("application/skg.category.ids") ||
                   data->hasFormat("application/skg.payee.ids") ||
                   data->hasFormat("application/skg.account.ids") ||
+                  data->hasFormat("application/skg.refund.ids") ||
                   data->hasFormat("application/skg.unit.ids")
                  )) return false;
     if(column > 0) return false;
@@ -871,6 +886,25 @@ bool SKGObjectModel::dropMimeData(const QMimeData * data,
                 if(!err) err = parentUnit.merge(child);
             }
         }
+    } else if(data->hasFormat("application/skg.refund.ids")) {
+        QByteArray encodedData = data->data("application/skg.refund.ids");
+        QDataStream stream(&encodedData, QIODevice::ReadOnly);
+        QStringList newItems;
+
+        if(parent.isValid()) {
+            SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge trackers"), err);
+            SKGTrackerObject trackerUnit = getObject(parent);
+            while(!stream.atEnd() && !err) {
+                int o_id;
+                QString o_table;
+                stream >> o_table;
+                stream >> o_id;
+
+                SKGTrackerObject child(getDocument(), o_id);
+                err = child.load();
+                if(!err) err = trackerUnit.merge(child);
+            }
+        }
     }
     SKGMainPanel::displayErrorMessage(err);
     return !err;
