@@ -50,7 +50,7 @@ public:
     SKGObjectModel(SKGDocumentBank* iDocument,
                    const QString& iTable,
                    const QString& iWhereClause,
-                   QObject *parent = NULL,
+                   QWidget *parent = NULL,
                    const QString& iParentAttribute = "",
                    bool iResetOnCreation = true);
 
@@ -135,6 +135,14 @@ protected Q_SLOTS:
      */
     virtual void dataModified(const QString& iTableName, int iIdTransaction);
 
+    /**
+     * Get the attribute value for grouping
+     * @param iObject the object
+     * @param iAttribute the attribute name
+     * @return the value of the attribute
+     */
+    virtual QString getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const;
+
 private:
     Q_DISABLE_COPY(SKGObjectModel);
 
@@ -157,7 +165,6 @@ private:
     QVariant m_fontFutureOperationsColor;
     QVariant m_fontNotValidatedOperationsColor;
     QVariant m_fontSubOperationsColor;
-    QVariant m_fontRedColor;
 
     QVariant m_iconTransfer;
     QVariant m_iconSplit;
