@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,7 +26,6 @@
 #include "skgbankgui_export.h"
 
 #include <QWidget>
-#include <QtDesigner/QDesignerExportWidget>
 #include <skgservices.h>
 
 class SKGDocument;
@@ -57,7 +56,8 @@ public:
      * Set parameters
      * @param iDocument the document
      * @param iTable the table
-     * @param iListAttribute the list of attribute (empty means all attributes supported of the table)
+     * @param iEditableAttribute the list of attributes (empty means all attributes supported of the table)
+     * @param iOtherAttributes the list of other attributes (empty means all attributes supported of the table)
      */
     virtual void setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iEditableAttribute, const QStringList& iOtherAttributes);
 
@@ -68,45 +68,24 @@ public:
      */
     virtual void setXMLCondition(QString iXML);
 
-
-    QString getAttribute();
-    QString getOperator();
-    QString getValue();
-    QString getValue2();
-    QString getAtt();
-    QString getAtt2();
-    QString getAtt2s();
-
-    void setAttribute(QString attribute);
-    void setOperator(QString operation);
-    void setValue(QString value);
-    void setValue2(QString value2);
-    void setAtt(QString att);
-    void setAtt2s(QString att2s);
-
 public Q_SLOTS:
 
     /**
      * Shows or hide relevant widgets depending on the attribute type and selected operation
      */
-    void setupWidgets();
-
-
+    virtual void setupWidgets();
 
 private:
     Q_DISABLE_COPY(SKGPropertyEditor);
 
-
     Ui::skgpropertyeditor_base ui;
 
-    QString table;
-    SKGDocument* document;
-    SKGServices::SKGAttributesList listAtts;
-    SKGServices::SKGAttributesList listOtherAtts;
-
-    QStringList listOperations;
-
+    QString m_table;
+    SKGDocument* m_document;
+    SKGServices::SKGAttributesList m_listAtts;
+    SKGServices::SKGAttributesList m_listOtherAtts;
 
+    QStringList m_listOperations;
 };
 
 #endif // SKGPROPERTYEDITOR_H
