@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -29,49 +29,49 @@
 #include <QPainter>
 
 SKGQueryDelegate::SKGQueryDelegate(QObject* parent, SKGDocument* iDoc, bool iModeUpdate, const QStringList& iListAtt):
-        QItemDelegate(parent), document(iDoc), updateMode(iModeUpdate), listAtt(iListAtt)
+    QItemDelegate(parent), m_document(iDoc), m_updateMode(iModeUpdate), m_listAtt(iListAtt)
 {
 }
 
 SKGQueryDelegate::~SKGQueryDelegate()
 {
-    document=NULL;
+    m_document = NULL;
 }
 
 QWidget* SKGQueryDelegate::createEditor(QWidget *parent,
                                         const QStyleOptionViewItem & option ,
-                                        const QModelIndex & index ) const
+                                        const QModelIndex & index) const
 {
     SKGTRACEIN(1, "SKGQueryDelegate::createEditor");
     Q_UNUSED(option);
 
-    QTableWidgetItem* it_h=((QTableWidget*) this->parent())->horizontalHeaderItem(index.column());
-    QString attname=it_h->data(Qt::UserRole).toString();
+    QTableWidgetItem* it_h = ((QTableWidget*) this->parent())->horizontalHeaderItem(index.column());
+    QString attname = it_h->data(Qt::UserRole).toString();
 
-    SKGPredicatCreator* editor=new SKGPredicatCreator(parent, document, attname, updateMode, listAtt);
+    SKGPredicatCreator* editor = new SKGPredicatCreator(parent, m_document, attname, m_updateMode, m_listAtt);
     connect(editor, SIGNAL(editingFinished()), this, SLOT(commitAndCloseEditor()));
     return editor;
 }
 
-void SKGQueryDelegate::setEditorData ( QWidget * editor, const QModelIndex & index ) const
+void SKGQueryDelegate::setEditorData(QWidget * editor, const QModelIndex & index) const
 {
     SKGTRACEIN(1, "SKGQueryDelegate::setEditorData");
-    SKGPredicatCreator *pred = dynamic_cast<SKGPredicatCreator*>(editor);
-    if (pred) {
+    SKGPredicatCreator *pred = qobject_cast<SKGPredicatCreator*>(editor);
+    if(pred) {
         pred->setXmlDescription(index.model()->data(index, Qt::UserRole).toString());
-    } else QItemDelegate::setEditorData (editor, index);
+    } else QItemDelegate::setEditorData(editor, index);
 }
 
 void SKGQueryDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
                                     const QModelIndex &index) const
 {
     SKGTRACEIN(1, "SKGQueryDelegate::setModelData");
-    SKGPredicatCreator *pred = dynamic_cast<SKGPredicatCreator*>(editor);
-    if (pred && model) {
-        QString xml=pred->xmlDescription();
+    SKGPredicatCreator *pred = qobject_cast<SKGPredicatCreator*>(editor);
+    if(pred && model) {
+        QString xml = pred->xmlDescription();
         model->setData(index, pred->text(), Qt::DisplayRole);
         model->setData(index, xml, Qt::UserRole);
-    } else QItemDelegate::setModelData (editor, model, index);
+    } else QItemDelegate::setModelData(editor, model, index);
 }
 
 void SKGQueryDelegate::commitAndCloseEditor()
