@@ -80,7 +80,7 @@ void SKGUnitComboBox::refershList()
     if(m_document) {
         SKGMainPanel::fillWithDistinctValue(this, m_document, "unit", "ifnull(t_symbol,t_name)", m_fillWhereClause);
         SKGServices::SKGUnitInfo primary = m_document->getPrimaryUnit();
-        if(!primary.Symbol.isEmpty()) setText(primary.Symbol);
+        if(!primary.Symbol.isEmpty()) this->setCurrentIndex(this->findText(primary.Symbol));
     }
 }
 
