@@ -219,7 +219,7 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
             } else {
                 //No
                 SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
-                coef = unit.getAmount(iDate);
+                if(unit.getType() != SKGUnitObject::PRIMARY) coef = unit.getAmount(iDate);
             }
 
             output += coef * SKGServices::stringToDouble(quantity);
@@ -318,10 +318,10 @@ SKGError SKGAccountObject::getInterest(const QDate& iDate, SKGInterestObject& oI
                    oInterest);
 
     //If not found then get first
-    if(!!err) err = SKGObjectBase::getDocument()->getObject("v_interest",
-                        "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
-                        SKGServices::intToString(getID()) % ')',
-                        oInterest);
+    if(err) err = SKGObjectBase::getDocument()->getObject("v_interest",
+                      "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
+                      SKGServices::intToString(getID()) % ')',
+                      oInterest);
     return err;
 }
 
