@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -45,25 +45,26 @@ public:
      * Describe a interest item
      */
     struct SKGInterestItem {
-        SKGObjectBase object; 	/**< The object (an operation, an interest or nothing for initial balance) */
-        QDate date; 	        /**< The date */
-        QDate valueDate; 	/**< The valueDate */
-        int base; 	        /**< Base */
-        double amount; 	        /**< Amount */
-        double coef; 	        /**< Coef */
-        double rate; 	        /**< Rate */
-        double annualInterest; 	/**< Annual Interest */
+        SKGObjectBase object;   /**< The object (an operation, an interest or nothing for initial balance) */
+        QDate date;             /**< The date */
+        QDate valueDate;    /**< The valueDate */
+        int base;           /**< Base */
+        double amount;          /**< Amount */
+        double coef;            /**< Coef */
+        double rate;            /**< Rate */
+        double annualInterest;  /**< Annual Interest */
         double accruedInterest; /**< Accrued Interest */
     } ;
 
     /**
      * This enumerate defines type of account
      */
-    enum AccountType {CURRENT, 	/**< to define a bank account*/
-                      CREDITCARD, 	/**< to define a credit card account*/
-                      INVESTMENT, 	/**< to define an account for investment */
-                      ASSETS, 	/**< to define a assets account */
-                      OTHER		/**< other kind of account */
+    enum AccountType {CURRENT,  /**< to define a bank account*/
+                      CREDITCARD,   /**< to define a credit card account*/
+                      INVESTMENT,   /**< to define an account for investment */
+                      ASSETS,   /**< to define a assets account */
+                      OTHER,     /**< other kind of account */
+                      WALLET   /**< to define a wallet account */
                      };
 
     /**
@@ -71,7 +72,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGAccountObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGAccountObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -206,6 +207,14 @@ public:
      */
     virtual int getNbOperation() const;
 
+    /**
+     * Get all operations of this account
+     * @param oOperations all operations of this account
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getOperations(SKGListSKGObjectBase& oOperations) const;
+
     /**
      * Get the current amount
      * @return the current amount
@@ -304,7 +313,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getInterestItems(QList<SKGAccountObject::SKGInterestItem>& oInterestList, double& oInterests, int iYear=0) const;
+    virtual SKGError getInterestItems(QList<SKGAccountObject::SKGInterestItem>& oInterestList, double& oInterests, int iYear = 0) const;
 
     /**
      * Compute all items
@@ -314,7 +323,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError computeInterestItems(QList<SKGAccountObject::SKGInterestItem>& ioInterestList, double& oInterests, int iYear=0) const;
+    virtual SKGError computeInterestItems(QList<SKGAccountObject::SKGInterestItem>& ioInterestList, double& oInterests, int iYear = 0) const;
 
     /**
      * Try to point all imported operations to obtain the expected balance
@@ -323,13 +332,21 @@ public:
      *   @see SKGError
      */
     virtual SKGError autoReconcile(double iBalance);
+
+    /**
+     * Merge iAccount in current account
+     * @param iAccount the account. All operations will be transferred into this account. The account will be removed
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError merge(const SKGAccountObject& iAccount);
 };
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGAccountObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGAccountObject, Q_MOVABLE_TYPE);
 /**
   * Declare the class
   */
-Q_DECLARE_TYPEINFO ( SKGAccountObject::SKGInterestItem, Q_PRIMITIVE_TYPE );
+Q_DECLARE_TYPEINFO(SKGAccountObject::SKGInterestItem, Q_PRIMITIVE_TYPE);
 #endif
