@@ -71,10 +71,10 @@ QString SKGCategoryObject::getWhereclauseId() const
         if(!(getAttribute("t_name").isEmpty())) {
             output = "t_name='" % SKGServices::stringToSqlString(getAttribute("t_name")) % '\'';
         }
-        QString r_category_id = getAttribute("r_category_id");
+        QString rd_category_id = getAttribute("rd_category_id");
         if(!output.isEmpty()) output += " AND ";
-        if(r_category_id.isEmpty()) output += "(r_category_id=0 OR r_category_id IS NULL OR r_category_id='')";
-        else output += "r_category_id=" % r_category_id;
+        if(rd_category_id.isEmpty()) output += "(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')";
+        else output += "rd_category_id=" % rd_category_id;
     }
     return output;
 }
@@ -163,7 +163,7 @@ SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
     if(getID() == 0)  err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database." , QString("SKGCategoryObject::addCategory")));
     else {
         oCategory = SKGCategoryObject(static_cast<SKGDocumentBank*>(getDocument()));
-        err = oCategory.setAttribute("r_category_id", SKGServices::intToString(getID()));
+        err = oCategory.setAttribute("rd_category_id", SKGServices::intToString(getID()));
     }
     return err;
 }
@@ -186,20 +186,20 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
             }
         } while(!err && current.getID() != 0);
 
-        if(!err) err = setAttribute("r_category_id", SKGServices::intToString(iCategory.getID()));
+        if(!err) err = setAttribute("rd_category_id", SKGServices::intToString(iCategory.getID()));
     }
     return err;
 }
 
 SKGError SKGCategoryObject::removeParentCategory()
 {
-    return setAttribute("r_category_id", "");
+    return setAttribute("rd_category_id", "");
 }
 
 SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) const
 {
     SKGError err;
-    QString parent_id = getAttribute("r_category_id");
+    QString parent_id = getAttribute("rd_category_id");
     if(!parent_id.isEmpty()) err = getDocument()->getObject("v_category", "id=" % parent_id , oCategory);
     return err;
 }
@@ -225,7 +225,7 @@ SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
 SKGError SKGCategoryObject::getCategories(SKGListSKGObjectBase& oCategoryList) const
 {
     return getDocument()->getObjects("v_category",
-                                     "r_category_id=" % SKGServices::intToString(getID()),
+                                     "rd_category_id=" % SKGServices::intToString(getID()),
                                      oCategoryList);
 }
 
@@ -243,6 +243,17 @@ SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperation
     return err;
 }
 
+SKGError SKGCategoryObject::bookmark(bool iBookmark)
+{
+    return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
+
+}
+
+bool SKGCategoryObject::isBookmarked() const
+{
+    return (getAttribute("t_bookmarked") == "Y" ? true : false);
+}
+
 SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
 {
     SKGError err;
