@@ -86,6 +86,21 @@ public:
      */
     virtual SKGError setName(const QString& iName);
 
+    /**
+     * To bookmark or not a category
+     * @param iBookmark the bookmark: true or false
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError bookmark(bool iBookmark);
+
+    /**
+     * To know if the category is bookmarked
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual bool isBookmarked() const;
+
     /**
      * Get the full name of this category.
      * The full name is the unique name of the category.
@@ -167,7 +182,7 @@ public:
 protected:
     /**
      * Get where clause needed to identify objects.
-     * For this class, the whereclause is based on name + r_category_id
+     * For this class, the whereclause is based on name + rd_category_id
      * @return the where clause
      */
     virtual QString getWhereclauseId() const;
