@@ -184,17 +184,16 @@ public Q_SLOTS:
     /**
      * Get budget report
      * @param iMonth the month
-     * @return the html report
+     * @return the report
      */
-    virtual QString getBudget(const QString& iMonth);
+    virtual QVariantList getBudget(const QString& iMonth);
 
     /**
      * Get 5 main category report
      * @param iMonth the month
-     * @param iChart to add chart
-     * @return the html report
+     * @return the report
      */
-    virtual QString get5MainCategories(const QString& iMonth, bool iChart = true);
+    virtual QVariantList get5MainCategories(const QString& iMonth);
 
     /**
      * Get 5 main variation of categories report
@@ -206,15 +205,6 @@ public Q_SLOTS:
      */
     virtual QStringList get5MainCategoriesVariationList(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
 
-    /**
-     * Get 5 main variation of categories report
-     * @param iMonth the month
-     * @param iPreviousMonth the previous month
-     * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
-     * @return the html report
-     */
-    virtual QString get5MainCategoriesVariation(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false);
-
     /**
      * Enable/disable balances computation
      */
@@ -237,6 +227,7 @@ protected:
      *   @see SKGError
      */
     virtual SKGError computeBalances();
+
     /**
      * Compute the budgets categories links.
      * @return an object managing the error.
@@ -255,4 +246,8 @@ private:
     QStringList m_5mainVariationsCat_cache;
     bool m_computeBalances;
 };
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGDocumentBank, Q_MOVABLE_TYPE);
 #endif
