@@ -41,29 +41,11 @@
 SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
         const QString& iFileName)
     : QObject(), m_document(iDocument), m_fileName(iFileName),
-      m_csvSeparator(';'), m_csvHeaderIndex(-1),
-      m_defaultAccount(NULL), m_defaultUnit(NULL)
+      m_defaultAccount(NULL), m_defaultUnit(NULL),
+      m_importPlugin(NULL), m_exportPlugin(NULL)
 {
     setAutomaticValidation(true);
     setAutomaticApplyRules(false);
-
-    m_csvMapper["date"] = "^date";
-    m_csvMapper["account"] = "^account";
-    m_csvMapper["number"] = "^number|^num?ro";
-    m_csvMapper["mode"] = "^mode|^type";
-    m_csvMapper["payee"] = "^payee|^tiers";
-    m_csvMapper["comment"] = "^comment|^libell?|^d?tail|^info";
-    m_csvMapper["status"] = "^status|^pointage";
-    m_csvMapper["bookmarked"] = "^bookmarked";
-    m_csvMapper["category"] = "^cat\\w*gor\\w*";
-    m_csvMapper["amount"] = "^value|^amount|^valeur|^montant";
-    m_csvMapper["quantity"] = "^quantity";
-    m_csvMapper["unit"] = "^unit";
-    m_csvMapper["sign"] = "^sign|^sens";
-    m_csvMapper["debit"] = "^-|^debit|^withdrawal";
-    m_csvMapper["idgroup"] = "^idgroup";
-    m_csvMapper["idtransaction"] = "^idtransaction";
-    m_csvMapper["property"] = "";
 }
 
 SKGImportExportManager::~SKGImportExportManager()
@@ -73,9 +55,10 @@ SKGImportExportManager::~SKGImportExportManager()
     m_document = NULL;
     m_defaultAccount = NULL;
     m_defaultUnit = NULL;
+    m_importPlugin = NULL;
+    m_exportPlugin = NULL;
 }
 
-
 SKGError SKGImportExportManager::setDefaultAccount(SKGAccountObject* iAccount)
 {
     SKGError err;
@@ -252,10 +235,23 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
     return err;
 }
 
+void SKGImportExportManager::setImportParameters(const QMap< QString, QString >& iParameters)
+{
+    SKGImportPlugin* plugin = getImportPlugin();
+    if(plugin) plugin->setImportParameters(iParameters);
+}
+
+QMap< QString, QString > SKGImportExportManager::getImportParameters()
+{
+    QMap< QString, QString > output;
+    SKGImportPlugin* plugin = getImportPlugin();
+    if(plugin) output = plugin->getImportParameters();
+    return output;
+}
+
 QString SKGImportExportManager::getImportMimeTypeFilter()
 {
-    QString output;
-    QString all;
+    QMap<QString, QString> tmp;
     KService::List offers = KServiceTypeTrader::self()->query(QLatin1String("SKG IMPORT/Plugin"));
     int nb = offers.count();
     for(int i = 0; i < nb; ++i) {
@@ -267,22 +263,34 @@ QString SKGImportExportManager::getImportMimeTypeFilter()
             if(pluginInterface && pluginInterface->isImportPossible()) {
                 QString mime = pluginInterface->getMimeTypeFilter();
                 if(!mime.isEmpty()) {
-                    if(!output.isEmpty()) output += '\n';
-                    output += mime;
-
-                    if(!all.isEmpty()) all += ' ';
-                    all += SKGServices::splitCSVLine(mime, '|').at(0);
+                    QStringList lines = SKGServices::splitCSVLine(mime, '\n');
+                    int nblines = lines.count();
+                    for(int l = 0; l < nblines; ++l) {
+                        QStringList items = SKGServices::splitCSVLine(lines.at(l), '|');
+                        tmp[items.at(1)] = items.at(0);
+                    }
                 }
             }
         }
     }
-    return all % '|' % i18nc("A file format", "All supported formats") % '\n' % output;
+
+    QStringList descriptions = tmp.keys();
+    qSort(descriptions);
+    QStringList regexps = tmp.values();
+
+    QString output = regexps.join(" ") % '|' % i18nc("A file format", "All supported formats");
+    nb = descriptions.count();
+    for(int i = 0; i < nb; ++i) {
+        if(!output.isEmpty()) output += '\n';
+        output += tmp[descriptions.at(i)] % '|' % descriptions.at(i);
+    }
+
+    return output;
 }
 
 QString SKGImportExportManager::getExportMimeTypeFilter()
 {
-    QString output;
-    QString all;
+    QMap<QString, QString> tmp;
     KService::List offers = KServiceTypeTrader::self()->query(QLatin1String("SKG IMPORT/Plugin"));
     int nb = offers.count();
     for(int i = 0; i < nb; ++i) {
@@ -294,16 +302,78 @@ QString SKGImportExportManager::getExportMimeTypeFilter()
             if(pluginInterface && pluginInterface->isExportPossible()) {
                 QString mime = pluginInterface->getMimeTypeFilter();
                 if(!mime.isEmpty()) {
-                    if(!output.isEmpty()) output += '\n';
-                    output += mime;
-
-                    if(!all.isEmpty()) all += ' ';
-                    all += SKGServices::splitCSVLine(mime, '|').at(0);
+                    QStringList lines = SKGServices::splitCSVLine(mime, '\n');
+                    int nblines = lines.count();
+                    for(int l = 0; l < nblines; ++l) {
+                        QStringList items = SKGServices::splitCSVLine(lines.at(l), '|');
+                        tmp[items.at(1)] = items.at(0);
+                    }
                 }
             }
         }
     }
-    return all % '|' % i18nc("A file format", "All supported formats") % '\n' % output;
+
+    QStringList descriptions = tmp.keys();
+    qSort(descriptions);
+    QStringList regexps = tmp.values();
+
+    QString output = regexps.join(" ") % '|' % i18nc("A file format", "All supported formats");
+    nb = descriptions.count();
+    for(int i = 0; i < nb; ++i) {
+        if(!output.isEmpty()) output += '\n';
+        output += tmp[descriptions.at(i)] % '|' % descriptions.at(i);
+    }
+
+    return output;
+}
+
+
+SKGImportPlugin* SKGImportExportManager::getImportPlugin()
+{
+    if(!m_importPlugin) {
+        KService::List offers = KServiceTypeTrader::self()->query(QLatin1String("SKG IMPORT/Plugin"));
+        int nb = offers.count();
+        for(int i = 0; !m_importPlugin && i < nb; ++i) {
+            KService::Ptr service = offers.at(i);
+            QString id = service->property("X-Krunner-ID", QVariant::String).toString();
+            KPluginLoader loader(service->library());
+            KPluginFactory *factory = loader.factory();
+            if(factory) {
+                SKGImportPlugin *pluginInterface = factory->create<SKGImportPlugin> (this);
+                if(pluginInterface && pluginInterface->isImportPossible()) {
+                    //Import
+                    m_importPlugin = pluginInterface;
+                }
+            } else {
+                if(m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
+            }
+        }
+    }
+    return m_importPlugin;
+}
+
+SKGImportPlugin* SKGImportExportManager::getExportPlugin()
+{
+    if(!m_exportPlugin) {
+        KService::List offers = KServiceTypeTrader::self()->query(QLatin1String("SKG IMPORT/Plugin"));
+        int nb = offers.count();
+        for(int i = 0; !m_exportPlugin && i < nb; ++i) {
+            KService::Ptr service = offers.at(i);
+            QString id = service->property("X-Krunner-ID", QVariant::String).toString();
+            KPluginLoader loader(service->library());
+            KPluginFactory *factory = loader.factory();
+            if(factory) {
+                SKGImportPlugin *pluginInterface = factory->create<SKGImportPlugin> (this);
+                if(pluginInterface && pluginInterface->isExportPossible()) {
+                    //Import
+                    m_exportPlugin = pluginInterface;
+                }
+            } else {
+                if(m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
+            }
+        }
+    }
+    return m_exportPlugin;
 }
 
 SKGError SKGImportExportManager::importFile()
@@ -315,24 +385,11 @@ SKGError SKGImportExportManager::importFile()
         if(!err) {
             //Search plugins
             bool fileTreated = false;
-            KService::List offers = KServiceTypeTrader::self()->query(QLatin1String("SKG IMPORT/Plugin"));
-            int nb = offers.count();
-            SKGTRACEL(1) << nb << " plugins found" << endl;
-            for(int i = 0; !err && i < nb; ++i) {
-                KService::Ptr service = offers.at(i);
-                QString id = service->property("X-Krunner-ID", QVariant::String).toString();
-                KPluginLoader loader(service->library());
-                KPluginFactory *factory = loader.factory();
-                if(factory) {
-                    SKGImportPlugin *pluginInterface = factory->create<SKGImportPlugin> (this);
-                    if(pluginInterface && pluginInterface->isImportPossible()) {
-                        //Import
-                        fileTreated = true;
-                        err = pluginInterface->importFile();
-                    }
-                } else {
-                    err = m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
-                }
+            SKGImportPlugin *pluginInterface = getImportPlugin();
+            if(pluginInterface) {
+                //Import
+                fileTreated = true;
+                err = pluginInterface->importFile();
             }
 
             if(!err && !fileTreated) {
@@ -356,24 +413,11 @@ SKGError SKGImportExportManager::exportFile()
         if(!err) {
             //Search plugins
             bool fileTreated = false;
-            KService::List offers = KServiceTypeTrader::self()->query(QLatin1String("SKG IMPORT/Plugin"));
-            int nb = offers.count();
-            SKGTRACEL(1) << nb << " plugins found" << endl;
-            for(int i = 0; !err && i < nb; ++i) {
-                KService::Ptr service = offers.at(i);
-                QString id = service->property("X-Krunner-ID", QVariant::String).toString();
-                KPluginLoader loader(service->library());
-                KPluginFactory *factory = loader.factory();
-                if(factory) {
-                    SKGImportPlugin *pluginInterface = factory->create<SKGImportPlugin> (this);
-                    if(pluginInterface && pluginInterface->isExportPossible()) {
-                        //Export
-                        fileTreated = true;
-                        err = pluginInterface->exportFile();
-                    }
-                } else {
-                    err = m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
-                }
+            SKGImportPlugin *pluginInterface = getExportPlugin();
+            if(pluginInterface) {
+                //Import
+                fileTreated = true;
+                err = pluginInterface->exportFile();
             }
 
             if(!err && !fileTreated) {
@@ -386,278 +430,6 @@ SKGError SKGImportExportManager::exportFile()
     return err;
 }
 
-QStringList SKGImportExportManager::getCSVMappingFromLine(const QString& iLine)
-{
-    QStringList output;
-    QString line = iLine.trimmed();
-
-    //Split first line
-    QStringList csvAttributes = SKGServices::splitCSVLine(line, ';', true, &m_csvSeparator);
-    int nb = csvAttributes.count();
-    for(int i = 0; i < nb; ++i) {
-        QString att = csvAttributes[i].toLower();
-
-        //Search if this csv column is mapping a std attribute
-        QMapIterator<QString, QString> csvMapperIterator(m_csvMapper);
-        bool found = false;
-        while(!found && csvMapperIterator.hasNext()) {
-            csvMapperIterator.next();
-
-            QString key = csvMapperIterator.key();
-            if(key != "debit" &&
-                    key != "property" &&
-                    !csvMapperIterator.value().isEmpty() &&
-                    QRegExp(csvMapperIterator.value(), Qt::CaseInsensitive).indexIn(att) != -1 &&
-                    (!output.contains(key) || key == "comment" || key == "category" || key == "amount")) {
-                output.push_back(key);
-                found = true;
-            }
-        }
-
-        //Search if this csv column must be added as a property
-        if(!found &&
-                !m_csvMapper["property"].isEmpty() &&
-                QRegExp(m_csvMapper["property"], Qt::CaseInsensitive).indexIn(att) != -1 &&
-                !output.contains(att)) {
-            output.push_back(att);
-            found = true;
-        }
-
-        if(!found) output.push_back("");       //To ignore this column
-    }
-    return output;
-}
-
-QMap<QString, QString> SKGImportExportManager::getCSVMappingRules()
-{
-    return m_csvMapper;
-}
-
-SKGError SKGImportExportManager::setCSVMappingRules(const QMap<QString, QString>& iCSVMappingRules)
-{
-    SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::setCSVMappingRules", err);
-    m_csvMapper = iCSVMappingRules;
-    return err;
-}
-
-SKGError SKGImportExportManager::setCSVMapping(const QStringList* iCSVMapping)
-{
-    SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::setCSVMapping", err);
-
-    m_csvMapping.clear();
-
-    if(iCSVMapping == NULL) {
-        //Automatic build
-        //Open file
-        QFile file(m_fileName);
-        if(!file.open(QIODevice::ReadOnly)) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_fileName));
-        } else {
-            QTextStream stream(&file);
-            if(!m_codec.isEmpty()) stream.setCodec(m_codec.toAscii().constData());
-
-            //Ignore useless lines
-            int headerIndex = getCSVHeaderIndex();
-            for(int i = 1; i < headerIndex; ++i)
-                stream.readLine();
-
-            //Get mapping
-            if(!stream.atEnd()) {
-                m_csvMapping = getCSVMappingFromLine(stream.readLine());
-            } else {
-                err.setReturnCode(ERR_INVALIDARG);
-            }
-
-            //close file
-            file.close();
-        }
-    } else {
-        //Manual build
-        m_csvMapping = *iCSVMapping;
-    }
-
-    if(!err) {
-        //Check if mandatory attributes have been found
-        if(!m_csvMapping.contains("date") || !m_csvMapping.contains("amount"))
-            err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings."));
-    }
-
-    return err;
-}
-
-QStringList SKGImportExportManager::getCSVMapping() const
-{
-    SKGTRACEIN(10, "SKGImportExportManager::getCSVMapping");
-    return m_csvMapping;
-}
-
-SKGError SKGImportExportManager::setCSVHeaderIndex(int iIndex)
-{
-    SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::setCSVHeaderIndex", err);
-
-    if(iIndex == -1) {
-        //Automatic build
-        //Open file
-        QFile file(m_fileName);
-        if(!file.open(QIODevice::ReadOnly)) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_fileName));
-        } else {
-            QTextStream stream(&file);
-            if(!m_codec.isEmpty()) stream.setCodec(m_codec.toAscii().constData());
-
-            int i = 1;
-            m_csvHeaderIndex = -1;
-            while(!stream.atEnd() && m_csvHeaderIndex == -1) {
-                //Read line
-                QStringList map = getCSVMappingFromLine(stream.readLine());
-                if(map.contains("date") && map.contains("amount")) m_csvHeaderIndex = i;
-
-                ++i;
-            }
-
-            //close file
-            file.close();
-        }
-    } else {
-        //Manual build
-        m_csvHeaderIndex = iIndex;
-    }
-
-    return err;
-}
-
-int SKGImportExportManager::getCSVHeaderIndex()
-{
-    SKGTRACEIN(10, "SKGImportExportManager::getCSVHeaderIndex");
-    if(m_csvHeaderIndex == -1) setCSVHeaderIndex(-1);
-    return m_csvHeaderIndex;
-}
-
-QChar SKGImportExportManager::getCSVSeparator()
-{
-    SKGTRACEIN(10, "SKGImportExportManager::getCSVSeparator");
-    return m_csvSeparator;
-}
-
-SKGError SKGImportExportManager::importCSVUnit()
-{
-    SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::importCSVUnit", err);
-    SKGTRACEL(10) << "Input filename=" << m_fileName << endl;
-
-    if(m_document) {
-        //Begin transaction
-        err = m_document->beginTransaction("#INTERNAL#", 3);
-        if(!err) {
-            //File name is the name of the unit
-            QFileInfo fInfo(m_fileName);
-            QString unitName = fInfo.baseName();
-
-            //Default mapping
-            if(getCSVMapping().count() == 0) {
-                err = setCSVMapping(NULL);
-                if(!err) err = m_document->sendMessage(i18nc("An information message",  "Use automatic search of the columns"));
-            }
-
-            //Step 1 done
-            if(!err) err = m_document->stepForward(1);
-
-            //Open file
-            if(!err) {
-                QFile file(m_fileName);
-                if(!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                    err.setReturnCode(ERR_INVALIDARG);
-                    err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_fileName));
-                } else {
-                    QTextStream stream(&file);
-                    if(!m_codec.isEmpty()) stream.setCodec(m_codec.toAscii().constData());
-
-                    //Ignore useless lines
-                    int headerIndex = getCSVHeaderIndex();
-                    for(int i = 1; i <= headerIndex; ++i)
-                        stream.readLine();
-
-                    //Get data column
-                    QStringList dates;
-                    QStringList lines;
-                    int posdate = m_csvMapping.indexOf("date");
-                    if(posdate != -1) {
-                        while(!stream.atEnd()) {
-                            //Read line
-                            QString line = stream.readLine().trimmed();
-                            if(!line.isEmpty()) {
-                                lines.push_back(line);
-
-                                //Get date
-                                QStringList field = SKGServices::splitCSVLine(line);
-                                if(posdate < field.count()) dates.push_back(field.at(posdate));
-                            }
-                        }
-                    }
-
-                    //close file
-                    file.close();
-
-                    //Select dateformat
-                    QString dateFormat = SKGServices::getDateFormat(dates);
-                    if(dateFormat.isEmpty()) {
-                        err.setReturnCode(ERR_FAIL);
-                        err.setMessage(i18nc("Error message",  "Date format not supported"));
-                    }
-                    if(!err)
-                        err = m_document->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_fileName, m_codec, dateFormat));
-
-                    //Step 2 done
-                    if(!err) err = m_document->stepForward(2);
-
-                    //Treat all lines
-                    if(!err) {
-                        int nb = lines.size();
-                        err = m_document->beginTransaction("#INTERNAL#", nb);
-
-                        //Save last mapping used in a settings
-                        QString mappingDesc;
-                        int nbMap = m_csvMapping.count();
-                        for(int i = 0; i < nbMap; ++i) {
-                            if(i) mappingDesc += '|';
-                            mappingDesc += m_csvMapping.at(i);
-                        }
-                        if(!err) err = m_document->setParameter("SKG_LAST_CSV_UNIT_MAPPING_USED", mappingDesc);
-
-                        int posdate = m_csvMapping.indexOf("date");
-                        int posvalue = m_csvMapping.indexOf("amount");
-                        if(posdate != -1 && posvalue != -1) {
-                            for(int i = 0; !err && i < nb; ++i) {
-                                QStringList atts = SKGServices::splitCSVLine(lines.at(i));
-                                err = m_document->addOrModifyUnitValue(unitName,
-                                                                       SKGServices::stringToTime(SKGServices::dateToSqlString(atts.at(posdate), dateFormat)).date(),
-                                                                       SKGServices::stringToDouble(atts.at(posvalue)));
-
-                                if(!err) err = m_document->stepForward(i + 1);
-                            }
-                        }
-
-                        if(!err) err = m_document->endTransaction(true);
-                        else  m_document->endTransaction(false);
-
-                        //Lines treated
-                        if(!err) err = m_document->stepForward(3);
-                    }
-                }
-            }
-        }
-        if(!err) err = m_document->endTransaction(true);
-        else  m_document->endTransaction(false);
-    }
-
-    return err;
-}
-
 SKGError SKGImportExportManager::cleanBankImport()
 {
     SKGError err;
