@@ -32,17 +32,14 @@
 #include <klocale.h>
 
 SKGOperationObject::SKGOperationObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, "v_operation", iID)
-{
-}
+{}
 
 SKGOperationObject::~SKGOperationObject()
-{
-}
+{}
 
 SKGOperationObject::SKGOperationObject(const SKGOperationObject& iObject)
     : SKGObjectBase(iObject)
-{
-}
+{}
 
 SKGOperationObject::SKGOperationObject(const SKGObjectBase& iObject)
 {
@@ -238,6 +235,7 @@ bool SKGOperationObject::isInGroup() const
 
 bool SKGOperationObject::isTransfer(SKGOperationObject& oOperation) const
 {
+    SKGTRACEIN(10, "SKGOperationObject::isTransfer")
     SKGObjectBase::SKGListSKGObjectBase ops;
     getGroupedOperations(ops);
     if(ops.count() == 2) {
