@@ -106,6 +106,17 @@ double SKGPayeeObject::getCurrentAmount() const
     return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
 }
 
+SKGError SKGPayeeObject::bookmark(bool iBookmark)
+{
+    return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
+
+}
+
+bool SKGPayeeObject::isBookmarked() const
+{
+    return (getAttribute("t_bookmarked") == "Y" ? true : false);
+}
+
 SKGError SKGPayeeObject::merge(const SKGPayeeObject& iPayee)
 {
     SKGError err;
