@@ -83,13 +83,14 @@ SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUn
 {
     QString t_period_unit = getAttribute("t_period_unit");
     if(t_period_unit == "D") return SKGRecurrentOperationObject::DAY;
+    else if(t_period_unit == "W") return SKGRecurrentOperationObject::WEEK;
     else if(t_period_unit == "M") return SKGRecurrentOperationObject::MONTH;
     return SKGRecurrentOperationObject::YEAR;
 }
 
 SKGError SKGRecurrentOperationObject::setPeriodUnit(SKGRecurrentOperationObject::PeriodUnit iPeriod)
 {
-    return setAttribute("t_period_unit", (iPeriod == SKGRecurrentOperationObject::DAY ? "D" : (iPeriod == SKGRecurrentOperationObject::MONTH ? "M" : "Y")));
+    return setAttribute("t_period_unit", (iPeriod == SKGRecurrentOperationObject::DAY ? "D" : (iPeriod == SKGRecurrentOperationObject::WEEK ? "W" : (iPeriod == SKGRecurrentOperationObject::MONTH ? "M" : "Y"))));
 }
 
 SKGError SKGRecurrentOperationObject::setAutoWriteDays(int iDays)
@@ -132,6 +133,7 @@ SKGError SKGRecurrentOperationObject::setTimeLimit(const QDate& iLastDate)
     //Compute nb time
     int nbd = firstDate.daysTo(iLastDate);
     if(period == SKGRecurrentOperationObject::DAY) nbd = nbd / occu;
+    else if(period == SKGRecurrentOperationObject::WEEK) nbd = nbd / (7 * occu);
     else if(period == SKGRecurrentOperationObject::MONTH) {
         nbd = (iLastDate.day() >= firstDate.day() ? 0 : -1) + (iLastDate.year() - firstDate.year()) * 12 + (iLastDate.month() - firstDate.month());
     } else if(period == SKGRecurrentOperationObject::YEAR) nbd = nbd / (365 * occu);
@@ -160,6 +162,7 @@ QDate SKGRecurrentOperationObject::getNextDate() const
     SKGRecurrentOperationObject::PeriodUnit punit = getPeriodUnit();
     int p = getPeriodIncrement();
     if(punit == SKGRecurrentOperationObject::DAY) nextDate = nextDate.addDays(p);
+    else if(punit == SKGRecurrentOperationObject::WEEK) nextDate = nextDate.addDays(7 * p);
     else if(punit == SKGRecurrentOperationObject::MONTH) nextDate = nextDate.addMonths(p);
     else if(punit == SKGRecurrentOperationObject::YEAR) nextDate = nextDate.addYears(p);
     return nextDate;
