@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -41,7 +41,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGSubOperationObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGSubOperationObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -141,9 +141,23 @@ public:
      */
     virtual double getQuantity() const;
 
+    /**
+     * Set the formula
+     * @param iFormula the formula
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setFormula(const QString& iFormula);
+
+    /**
+     * Get the formula
+     * @return the formula
+     */
+    virtual QString getFormula() const;
+
 };
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGSubOperationObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGSubOperationObject, Q_MOVABLE_TYPE);
 #endif
