@@ -32,7 +32,7 @@
 
 #include <QRegExp>
 #include <QFile>
-#include <math.h>
+#include <qmath.h>
 
 SKGUnitObject::SKGUnitObject(SKGDocument* iDocument, int iID)
     : SKGNamedObject(iDocument, "v_unit", iID)
@@ -105,7 +105,14 @@ QStringList SKGUnitObject::getListofKnownCurrencies(bool iIncludingObsolete)
             << i18nc("Noun, a currency", "CAC 40")
             << i18nc("Noun, a currency", "Dow Jones (DJIA)")
             << i18nc("Noun, a currency", "NASDAQ")
-            << i18nc("Noun, a currency", "SBF 120");
+            << i18nc("Noun, a currency", "SBF 120")
+            << i18nc("Noun, a currency", "S&P 500")
+            << i18nc("Noun, a currency", "FTSE 100")
+            << i18nc("Noun, a currency", "DAX")
+            << i18nc("Noun, a currency", "NIKKEI 225")
+            << i18nc("Noun, a currency", "HANG SENG")
+            << i18nc("Noun, a currency", "STRAITS TIMES");
+
     return output;
 }
 
@@ -187,6 +194,48 @@ SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo(const QString& iUnitName)
         info.Country = i18nc("Noun, a country", "France");
         info.Date = QDate(1990, 12, 31);
         info.Internet = "^SBF120";
+    } else if(iUnitName == i18nc("Noun, a currency", "S&P 500")) {
+        //S&P 500
+        info.Name = iUnitName;
+        info.Symbol = iUnitName;
+        info.Country = i18nc("Noun, a country", "United States");
+        info.Date = QDate(1920, 1, 1);
+        info.Internet = "^GSPC";
+    } else if(iUnitName == i18nc("Noun, a currency", "FTSE 100")) {
+        //FTSE 100
+        info.Name = iUnitName;
+        info.Symbol = iUnitName;
+        info.Country = i18nc("Noun, a country", "England");
+        info.Date = QDate(1984, 1, 3);
+        info.Internet = "^FTSE";
+    } else if(iUnitName == i18nc("Noun, a currency", "DAX")) {
+        //DAX
+        info.Name = iUnitName;
+        info.Symbol = iUnitName;
+        info.Country = i18nc("Noun, a country", "Germany");
+        info.Date = QDate(1920, 1, 1);
+        info.Internet = "^GDAXI";
+    } else if(iUnitName == i18nc("Noun, a currency", "NIKKEI 225")) {
+        //NIKKEI 225
+        info.Name = iUnitName;
+        info.Symbol = iUnitName;
+        info.Country = i18nc("Noun, a country", "Japan");
+        info.Date = QDate(1920, 1, 1);
+        info.Internet = "^N225";
+    } else if(iUnitName == i18nc("Noun, a currency", "HANG SENG")) {
+        //HANG SENG
+        info.Name = iUnitName;
+        info.Symbol = iUnitName;
+        info.Country = i18nc("Noun, a country", "China");
+        info.Date = QDate(1920, 1, 1);
+        info.Internet = "^HSI";
+    } else if(iUnitName == i18nc("Noun, a currency", "STRAITS TIMES")) {
+        //STRAITS TIMES
+        info.Name = iUnitName;
+        info.Symbol = iUnitName;
+        info.Date = QDate(1920, 1, 1);
+        info.Country = i18nc("Noun, a country", "Singapore");
+        info.Internet = "^STI";
     }
 
     return info;
@@ -398,10 +447,10 @@ SKGError SKGUnitObject::getUnitValue(const QDate& iDate, SKGUnitValueObject& oUn
                    oUnitValue);
 
     //If not found then get first
-    if(!!err) err = SKGObjectBase::getDocument()->getObject("v_unitvalue",
-                        "rd_unit_id=" % SKGServices::intToString(getID()) % " AND d_date=(select MIN(d_date) from unitvalue where rd_unit_id=" %
-                        SKGServices::intToString(getID()) % ')',
-                        oUnitValue);
+    if(err) err = SKGObjectBase::getDocument()->getObject("v_unitvalue",
+                      "rd_unit_id=" % SKGServices::intToString(getID()) % " AND d_date=(select MIN(d_date) from unitvalue where rd_unit_id=" %
+                      SKGServices::intToString(getID()) % ')',
+                      oUnitValue);
     return err;
 }
 
@@ -456,7 +505,7 @@ double SKGUnitObject::getDailyChange(const QDate& iDate) const
         QDate d2 = SKGServices::stringToTime(result.at(1).at(0)).date();
         QDate d1 = SKGServices::stringToTime(result.at(2).at(0)).date();
 
-        output = 100 * (exp(log(v2 / v1) / (SKGServices::nbWorkingDays(d1, d2))) - 1);
+        output = 100 * (qExp(qLn(v2 / v1) / (SKGServices::nbWorkingDays(d1, d2))) - 1);
     }
     return output;
 }
@@ -502,7 +551,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
 
             //Compute rate for step
             double step = (iMode == LAST_MONTHLY || ALL_MONTHLY ? 12.0 : (iMode == LAST_WEEKLY || ALL_WEEKLY ? 365.0 / 7.0 : 365));
-            double rate2 = 100.0 * (exp(log(1 + rate / 100.0) / step) - 1.0);
+            double rate2 = 100.0 * (qExp(qLn(1 + rate / 100.0) / step) - 1.0);
 
             //Get last value
             SKGStringListList result;
@@ -831,7 +880,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
         }
     }
 
-    if(!!err) {
+    if(err) {
         err.addError(ERR_FAIL, i18nc("Error message", "Impossible to download unit %1 with Internet code %2.", unitname, code));
     }
 
