@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,29 +21,30 @@
  */
 #include "skgunitvalueobject.h"
 #include "skgunitobject.h"
+#include "skgdocument.h"
 
 #include <klocale.h>
 
 SKGUnitValueObject::SKGUnitValueObject(SKGDocument* iDocument, int iID)
-        : SKGObjectBase(iDocument, "v_unitvalue", iID)
+    : SKGObjectBase(iDocument, "v_unitvalue", iID)
 {
 }
 
 SKGUnitValueObject::SKGUnitValueObject(const SKGUnitValueObject& iObject)
-        : SKGObjectBase(iObject)
+    : SKGObjectBase(iObject)
 {
 }
 
 SKGUnitValueObject::SKGUnitValueObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable()=="unitvalue") {
+    if(iObject.getRealTable() == "unitvalue") {
         copyFrom(iObject);
     } else {
-        *this=SKGObjectBase(iObject.getDocument(), "v_unitvalue", iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), "v_unitvalue", iObject.getID());
     }
 }
 
-const SKGUnitValueObject& SKGUnitValueObject::operator= (const SKGObjectBase& iObject)
+const SKGUnitValueObject& SKGUnitValueObject::operator= (const SKGObjectBase & iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -55,7 +56,7 @@ SKGUnitValueObject::~SKGUnitValueObject()
 
 SKGError SKGUnitValueObject::setQuantity(double iValue)
 {
-    if (iValue<0) return SKGError(ERR_INVALIDARG, i18nc("Error message", "Value of a currency cannot be a negative value"));
+    if(iValue < 0) return SKGError(ERR_INVALIDARG, i18nc("Error message", "Value of a currency cannot be a negative value"));
     return setAttribute("f_quantity", SKGServices::doubleToString(iValue));
 }
 
@@ -78,10 +79,10 @@ QString SKGUnitValueObject::getWhereclauseId() const
 {
     //Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
-    if (output.isEmpty()) {
+    if(output.isEmpty()) {
         //No, so we use the date and parent
-        if (!(getAttribute("d_date").isEmpty()) && !(getAttribute("rd_unit_id").isEmpty())) {
-            output = "d_date='"+getAttribute("d_date")+"' AND rd_unit_id="+getAttribute("rd_unit_id");
+        if(!(getAttribute("d_date").isEmpty()) && !(getAttribute("rd_unit_id").isEmpty())) {
+            output = "d_date='" % getAttribute("d_date") % "' AND rd_unit_id=" % getAttribute("rd_unit_id");
         }
     }
     return output;
@@ -89,7 +90,8 @@ QString SKGUnitValueObject::getWhereclauseId() const
 
 SKGError SKGUnitValueObject::getUnit(SKGUnitObject& oUnit) const
 {
-    SKGError err = getObject(getDocument(), "v_unit", "id=" + getAttribute("rd_unit_id"), oUnit);
+    SKGError err;
+    if(getDocument()) err = getDocument()->getObject("v_unit", "id=" % getAttribute("rd_unit_id"), oUnit);
     return err;
 }
 #include "skgunitvalueobject.moc"
