@@ -87,7 +87,7 @@ public:
      * Get the value
      * @return the value
      */
-    virtual double value() const;
+    virtual double value();
 
 
     /**
@@ -147,6 +147,7 @@ private:
     Q_DISABLE_COPY(SKGCalculatorEdit);
 
     void keyPressEvent(int key);
+    double getEvaluatedValue(bool &iOk);
     double m_lastValue;
     int m_lastOperator;
     Mode m_currentMode;
