@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,7 +23,6 @@
  */
 
 #include "ui_skgcolorbutton.h"
-#include <QtDesigner/QDesignerExportWidget>
 #include "skgbasegui_export.h"
 /**
  * This file is a color selector box with more features.
@@ -34,22 +33,22 @@ class SKGBASEGUI_EXPORT SKGColorButton : public QWidget
     /**
      * Text of the color selector
      */
-    Q_PROPERTY ( QString text READ text WRITE setText USER true )
+    Q_PROPERTY(QString text READ text WRITE setText USER true)
     /**
      * Color of the color selector
      */
-    Q_PROPERTY ( QColor color READ color WRITE setColor)
+    Q_PROPERTY(QColor color READ color WRITE setColor)
     /**
      * Default color of the color selector
      */
-    Q_PROPERTY ( QColor defaultColor READ defaultColor WRITE setDefaultColor)
+    Q_PROPERTY(QColor defaultColor READ defaultColor WRITE setDefaultColor)
 
 public:
     /**
      * Default Constructor
      * @param parent the parent
      */
-    SKGColorButton ( QWidget *parent = 0 );
+    SKGColorButton(QWidget *parent = 0);
 
     /**
      * Default Destructor
@@ -67,7 +66,7 @@ public:
      * Set the text for the color selector
      * @param iText the text
      */
-    virtual void setText ( const QString& iText );
+    virtual void setText(const QString& iText);
 
     /**
      * Get the color for the color selector
@@ -80,7 +79,7 @@ public:
      * Set the color for the color selector
      * @param iColor the color
      */
-    virtual void setColor ( const QColor& iColor );
+    virtual void setColor(const QColor& iColor);
 
     /**
      * Get the default color for the color selector
@@ -93,7 +92,7 @@ public:
      * Set the default color for the color selector
      * @param iColor the color
      */
-    virtual void setDefaultColor ( const QColor& iColor );
+    virtual void setDefaultColor(const QColor& iColor);
 
 Q_SIGNALS:
     /**
@@ -104,7 +103,7 @@ Q_SIGNALS:
 
 private:
     Ui::skgcolorbutton_base ui;
-    QString t;
+    QString m_text;
 };
 
 #endif // SKGCOLORBUTTON_H
