@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -53,7 +53,7 @@ public:
     /**
      * Flags for the picker
      */
-    Q_DECLARE_FLAGS( Items, ItemFlag );
+    Q_DECLARE_FLAGS(Items, ItemFlag);
 
     /**
      *  A constructor for the SKGDatePickerPopup.
@@ -61,9 +61,9 @@ public:
      *  @param date Initial date of datepicker-widget.
      *  @param parent The object's parent.
      */
-    explicit SKGDatePickerPopup( Items items = DatePicker,
-                                 const QDate &date = QDate::currentDate(),
-                                 QWidget *parent = 0 );
+    explicit SKGDatePickerPopup(Items items = DatePicker,
+                                const QDate &date = QDate::currentDate(),
+                                QWidget *parent = 0);
 
     /**
      * Get date picker
@@ -75,14 +75,14 @@ public:
      * Set date
      * @param date the date
      */
-    virtual void setDate( const QDate &date );
+    virtual void setDate(const QDate &date);
 
     /**
      * Returns items
      * @return
      */
     virtual int items() const {
-        return mItems;
+        return m_items;
     }
 
 Q_SIGNALS:
@@ -91,10 +91,10 @@ Q_SIGNALS:
      * This signal emits the new date (selected with datepicker or other
      * menu-items).
      */
-    void dateChanged ( const QDate &date );
+    void dateChanged(const QDate &date);
 
 private Q_SLOTS:
-    void slotDateChanged ( const QDate &date );
+    void slotDateChanged(const QDate &date);
     void slotToday();
     void slotTomorrow();
     void slotNextWeek();
@@ -104,10 +104,10 @@ private Q_SLOTS:
 private:
     void buildMenu();
 
-    KDatePicker *mDatePicker;
-    Items mItems;
+    KDatePicker *m_datePicker;
+    Items m_items;
 };
 
-Q_DECLARE_OPERATORS_FOR_FLAGS( SKGDatePickerPopup::Items )
+Q_DECLARE_OPERATORS_FOR_FLAGS(SKGDatePickerPopup::Items)
 
 #endif
