@@ -141,45 +141,46 @@ int SKGFlowLayout::doLayout(const QRect &rect, bool testOnly) const
 
     foreach(QLayoutItem * item, m_itemList) {
         QWidget *wid = item->widget();
+        if(wid) {
+            //Get spaces
+            int spaceX = horizontalSpacing();
+            if(spaceX == -1) spaceX = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
 
-        //Get spaces
-        int spaceX = horizontalSpacing();
-        if(spaceX == -1) spaceX = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
+            int spaceY = verticalSpacing();
+            if(spaceY == -1) spaceY = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
 
-        int spaceY = verticalSpacing();
-        if(spaceY == -1) spaceY = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
+            //Try option
+            bool optionUsed = false;
+            if(lineHeight && x1) {
+                int nextX = x1 + item->sizeHint().width() + spaceX;
+                if(nextX <= x && y1 - y + item->sizeHint().height() <= lineHeight) {
+                    optionUsed = true;
 
-        //Try option
-        bool optionUsed = false;
-        if(lineHeight && x1) {
-            int nextX = x1 + item->sizeHint().width() + spaceX;
-            if(nextX <= x && y1 - y + item->sizeHint().height() <= lineHeight) {
-                optionUsed = true;
+                    //Position item
+                    if(!testOnly) item->setGeometry(QRect(QPoint(x1, y1), item->sizeHint()));
+
+                    x1 = nextX;
+                }
+            }
+
+            if(!optionUsed) {
+                int nextX = x + item->sizeHint().width() + spaceX;
+                if(nextX - spaceX > effectiveRect.right() && lineHeight > 0) {
+                    x = effectiveRect.x();
+                    y = y + lineHeight + spaceY;
+                    nextX = x + item->sizeHint().width() + spaceX;
+                    lineHeight = 0;
+                }
 
                 //Position item
-                if(!testOnly) item->setGeometry(QRect(QPoint(x1, y1), item->sizeHint()));
+                if(!testOnly) item->setGeometry(QRect(QPoint(x, y), item->sizeHint()));
 
-                x1 = nextX;
+                x1 = x;
+                y1 = y + item->sizeHint().height() + spaceY;
+                x = nextX;
+                lineHeight = qMax(lineHeight, item->sizeHint().height());
             }
         }
-
-        if(!optionUsed) {
-            int nextX = x + item->sizeHint().width() + spaceX;
-            if(nextX - spaceX > effectiveRect.right() && lineHeight > 0) {
-                x = effectiveRect.x();
-                y = y + lineHeight + spaceY;
-                nextX = x + item->sizeHint().width() + spaceX;
-                lineHeight = 0;
-            }
-
-            //Position item
-            if(!testOnly) item->setGeometry(QRect(QPoint(x, y), item->sizeHint()));
-
-            x1 = x;
-            y1 = y + item->sizeHint().height() + spaceY;
-            x = nextX;
-            lineHeight = qMax(lineHeight, item->sizeHint().height());
-        }
     }
     return y + lineHeight - rect.y() + bottom;
 }
@@ -191,7 +192,7 @@ int SKGFlowLayout::smartSpacing(QStyle::PixelMetric pm) const
         return -1;
     } else if(parent->isWidgetType()) {
         QWidget *pw = static_cast<QWidget *>(parent);
-        return pw->style()->pixelMetric(pm, 0, pw);
+        return pw ? pw->style()->pixelMetric(pm, 0, pw) : 0;
     } else {
         return static_cast<QLayout *>(parent)->spacing();
     }
