@@ -113,9 +113,9 @@ bool SKGInterfacePlugin::isEnabled() const
     return true;
 }
 
-QList< SKGInterfacePlugin::SKGAdvice > SKGInterfacePlugin::advices() const
+SKGAdviceList SKGInterfacePlugin::advices() const
 {
-    QList< SKGInterfacePlugin::SKGAdvice > output;
+    SKGAdviceList output;
     return output;
 }
 
