@@ -26,6 +26,7 @@
 
 #include "skgdocument.h"
 #include "skgtabpage.h"
+#include "skgadvice.h"
 #include "skgerror.h"
 #include "skgbasegui_export.h"
 class SKGMainPanel;
@@ -39,17 +40,6 @@ class SKGBASEGUI_EXPORT SKGInterfacePlugin : public KParts::Plugin
 {
     Q_OBJECT ;
 public:
-    /**
-     * Describe a modification of an object
-     */
-    struct SKGAdvice {
-        QString uuid;               /**< The uuid of the advice */
-        int priority;               /**< The priority of the advice (0=low, 10=high) */
-        QString shortMessage;           /**< The short message of the advice */
-        QString longMessage;            /**< The long message of the advice */
-        QStringList autoCorrection;     /**< The message in case of this advice could be auto cleaned. One line per possible solutions */
-    } ;
-
     /**
      * Default constructor
      * @param parent the parent of the plugin
@@ -189,7 +179,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual QList<SKGInterfacePlugin::SKGAdvice> advices() const;
+    virtual SKGAdviceList advices() const;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -208,9 +198,5 @@ private:
  * This plugin interface definition.
  */
 Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0");
-/**
- * Declare the class
- */
-Q_DECLARE_TYPEINFO(SKGInterfacePlugin::SKGAdvice, Q_PRIMITIVE_TYPE);
 
 #endif // SKGINTERFACEPLUGIN_H
