@@ -44,7 +44,8 @@ void SKGLineEdit::setSubstringCompletionMode(bool iMode)
 
 void SKGLineEdit::makeCompletion(const QString& text)
 {
-    if(m_substringCompletionMode) setCompletedItems(completionObject()->substringCompletion(text));
+    if(m_substringCompletionMode && completionMode() == KGlobalSettings::CompletionPopup)
+        setCompletedItems(completionObject()->substringCompletion(text));
     else KLineEdit::makeCompletion(text);
 }
 
