@@ -56,6 +56,7 @@
 #include <ktoolbarpopupaction.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <ktoggleaction.h>
 
 #include <QtGui/QProgressBar>
 #include <QtGui/QHeaderView>
@@ -74,7 +75,8 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
       m_splashScreen(iSplashScreen),
       m_currentDocument(iDocument),
       m_tipOfDayAction(NULL), m_closePageAction(NULL), m_closeAllPagesAction(NULL), m_closeAllOtherPagesAction(NULL),
-      m_fullScreenAction(NULL), m_kSystemTrayIcon(NULL), m_kNormalMessage(NULL),  m_previousAction(NULL), m_nextAction(NULL),
+      m_fullScreenAction(NULL), m_actLock(NULL), m_actUnLock(NULL), m_kSystemTrayIcon(NULL),
+      m_kNormalMessage(NULL), m_zoomSelector(NULL),  m_previousAction(NULL), m_nextAction(NULL), m_buttonMenuAction(NULL),
       m_middleClick(false), m_saveOnClose(false)
 {
     SKGTRACEIN(1, "SKGMainPanel::SKGMainPanel");
@@ -207,12 +209,14 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     setCentralWidget(m_tabWidget);
 
     refreshTabPosition();
-    m_tabWidget->setTabReorderingEnabled(true);
+    m_tabWidget->setMovable(true);
     m_tabWidget->setTabsClosable(true);
     m_tabWidget->setAutomaticResizeTabs(true);
     m_tabWidget->setTabBarHidden(false);
     m_tabWidget->setUsesScrollButtons(true);
-    m_tabWidget->setTabCloseActivatePrevious(true);
+#ifdef SKGKDE46ENABLED
+    m_tabWidget->tabBar()->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
+#endif
     m_tabWidget->setDocumentMode(true);
 
     m_tabWidget->show();
@@ -250,6 +254,10 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     connect(toggle, SIGNAL(toggled(bool)), ui.kDockContext->toggleViewAction(), SLOT(toggle()));
     connect(ui.kDockContext, SIGNAL(visibilityChanged(bool)), toggle, SLOT(setChecked(bool)));*/
 
+    QPalette palette = QApplication::palette();
+    palette.setColor(QPalette::Base, Qt::transparent);
+    ui.kContextList->setPalette(palette);
+
     QAction* toggle = ui.kDockContext->toggleViewAction();
     if(toggle) {
         toggle->setText(i18nc("Noun", "Pages"));
@@ -320,6 +328,12 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
         }
     }
 
+    //Lock docs if needed
+    KConfigGroup pref = getMainConfigGroup();
+    if(pref.readEntry("docks_locked", false)) {
+        actionLockDocks();
+    }
+
     //267773 this->setWindowState(windowState() | Qt::WindowMaximized);
 
     // a call to KXmlGuiWindow::setupGUI() populates the GUI
@@ -374,6 +388,19 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     kCancelButton->setVisible(false);
     connect(kCancelButton, SIGNAL(clicked()), this, SLOT(onCancelCurrentAction()));
 
+    //Add special button in toolbar
+    KToolBar* tb = toolBar();
+    if(tb) {
+        QLabel* label = new QLabel(this);
+        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+        sizePolicy.setHorizontalStretch(0);
+        sizePolicy.setVerticalStretch(0);
+        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
+        label->setSizePolicy(sizePolicy);
+        tb->addWidget(label);
+        tb->addAction(m_buttonMenuAction);
+    }
+
     statusBar()->addPermanentWidget(kCancelButton);
     statusBar()->addPermanentWidget(m_zoomSelector);
 
@@ -561,6 +588,14 @@ void SKGMainPanel::setupActions()
 
     registedGlobalAction("tab-new-background", m_addTabAction);
 
+    m_actLock = new KAction(KIcon("document-encrypt"), i18nc("Verb", "Lock panels"), this);
+    actionCollection()->addAction(QLatin1String("view_lock"), m_actLock);
+    connect(m_actLock, SIGNAL(triggered(bool)), this, SLOT(actionLockDocks()));
+
+    m_actUnLock = new KAction(KIcon("document-decrypt"), i18nc("Verb", "Unlock panels"), this);
+    actionCollection()->addAction(QLatin1String("view_unlock"), m_actUnLock);
+    connect(m_actUnLock, SIGNAL(triggered(bool)), this, SLOT(actionUnlockDocks()));
+
     //
     m_closePageAction = actionCollection()->addAction(KStandardAction::Close, "tab_close", this, SLOT(closePage()));
 
@@ -617,12 +652,31 @@ void SKGMainPanel::setupActions()
 
     m_tipOfDayAction = KStandardAction::tipOfDay(this, SLOT(onTipOfDay()), actionCollection());
 
+    //Menu
+    m_buttonMenuAction = new KToolBarPopupAction(KIcon("configure"), "", this);
+    actionCollection()->addAction(QLatin1String("view_menu"), m_buttonMenuAction);
+
+    m_buttonMenu = static_cast<KMenu*>(m_buttonMenuAction->menu());
+    connect(m_buttonMenu , SIGNAL(aboutToShow()), this, SLOT(onShowButtonMenu()));
+    m_buttonMenuAction->setDelayed(false);
+
+    registedGlobalAction("view_menu", m_buttonMenuAction);
+
+    m_showMenuBarAction = KStandardAction::showMenubar(this, SLOT(onShowMenuBar()), actionCollection());
+
+    KConfigGroup pref = getMainConfigGroup();
+    m_showMenuBarAction->setChecked(pref.readEntry("menubar_shown", true));
+
+    QTimer::singleShot(200, this, SLOT(onShowMenuBar()));
+
     //
     m_previousAction = new KToolBarPopupAction(KIcon("go-previous"), i18nc("Noun, user action", "Previous"), this);
     connect(m_previousAction, SIGNAL(triggered(bool)), this, SLOT(actionPrevious()));
     actionCollection()->addAction(QLatin1String("go_previous"), m_previousAction);
     m_previousAction->setShortcut(Qt::ALT + Qt::Key_Left);
 
+    //m_tabWidget->setCornerWidget(toolBar(), Qt::TopLeftCorner);
+
     m_previousMenu = static_cast<KMenu*>(m_previousAction->menu());
     connect(m_previousMenu , SIGNAL(aboutToShow()), this, SLOT(onShowPreviousMenu()));
 
@@ -747,6 +801,16 @@ void SKGMainPanel::onShowPreviousMenu()
     }
 }
 
+void SKGMainPanel::onShowMenuBar()
+{
+    bool test = m_showMenuBarAction->isChecked();
+    menuBar()->setVisible(test);
+    m_buttonMenuAction->setVisible(!test);
+
+    KConfigGroup pref = getMainConfigGroup();
+    pref.writeEntry("menubar_shown", test);
+}
+
 void SKGMainPanel::actionFullScreen()
 {
     if(!m_fullScreenAction->isChecked()) {
@@ -779,7 +843,7 @@ void SKGMainPanel::actionFullScreen()
         int nb = m_hiddenWidgets.count();
         for(int i = nb - 1; i >= 0; --i) {
             QWidget* w = m_hiddenWidgets.at(i);
-            if(w->isVisible()) w->hide();
+            if(w && w->isVisible()) w->hide();
             else m_hiddenWidgets.removeAt(i);
         }
 
@@ -828,6 +892,36 @@ void SKGMainPanel::actionNext()
     }
 }
 
+void SKGMainPanel::actionLockDocks()
+{
+    QObjectList cs = children();
+    foreach(QObject * c, cs) {
+        QDockWidget* doc = qobject_cast<QDockWidget*>(c);
+        if(doc) {
+            doc->setFeatures(QDockWidget::NoDockWidgetFeatures);
+        }
+    }
+
+    KConfigGroup pref = getMainConfigGroup();
+    pref.writeEntry("docks_locked", true);
+
+    refresh();
+}
+
+void SKGMainPanel::actionUnlockDocks()
+{
+    QObjectList cs = children();
+    foreach(QObject * c, cs) {
+        QDockWidget* doc = qobject_cast<QDockWidget*>(c);
+        if(doc) doc->setFeatures(QDockWidget::AllDockWidgetFeatures);
+    }
+
+    KConfigGroup pref = getMainConfigGroup();
+    pref.writeEntry("docks_locked", false);
+
+    refresh();
+}
+
 void SKGMainPanel::onShowNextMenu()
 {
     if(m_nextMenu) {
@@ -848,6 +942,16 @@ void SKGMainPanel::onShowNextMenu()
     }
 }
 
+void SKGMainPanel::onShowButtonMenu()
+{
+    if(m_buttonMenu) {
+        m_buttonMenu->clear();
+
+        KMenuBar* mb = menuBar();
+        if(mb) m_buttonMenu->addActions(mb->actions());
+    }
+}
+
 bool SKGMainPanel::queryClose()
 {
     SKGTRACEIN(1, "SKGMainPanel::queryClose");
@@ -931,6 +1035,29 @@ int SKGMainPanel::getNbSelectedObjects()
     return nb;
 }
 
+SKGAdviceList SKGMainPanel::getAdvices() const
+{
+    //Get list of ignored advices
+    QString currentMonth = QDate::currentDate().toString("yyyy-MM");
+    QStringList ignoredAdvices = getDocument()->getParameters("advices", "t_value='I' OR t_value='I_" % currentMonth % '\'');
+
+    //Build the list of all advices by requesting all plugins
+    SKGAdviceList globalAdvicesList;
+    int index = 0;
+    while(index >= 0) {
+        SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
+        if(plugin) {
+            foreach(const SKGAdvice & ad, plugin->advices()) {
+                if(!ignoredAdvices.contains(ad.getUUID()) && !ignoredAdvices.contains(SKGServices::splitCSVLine(ad.getUUID(), '|').at(0))) globalAdvicesList.push_back(ad);
+            }
+        } else index = -2;
+        ++index;
+    }
+    qSort(globalAdvicesList.begin(), globalAdvicesList.end(), adviceLessThan);
+
+    return globalAdvicesList;
+}
+
 KConfigGroup SKGMainPanel::getMainConfigGroup()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -1112,7 +1239,8 @@ void SKGMainPanel::refresh()
     m_closeAllOtherPagesAction->setEnabled(m_tabWidget->count() > 1);
 
     SKGTabPage* toSave = currentPage();
-    if(m_saveDefaultStateAction) m_saveDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
+    if(toSave)
+        if(m_saveDefaultStateAction) m_saveDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
     if(m_resetDefaultStateAction) m_resetDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
     if(m_overwriteBookmarkStateAction) m_overwriteBookmarkStateAction->setEnabled(toSave && !toSave->getBookmarkID().isEmpty());
     if(m_enableEditorAction) m_enableEditorAction->setEnabled(toSave && toSave->isEditor());
@@ -1135,6 +1263,9 @@ void SKGMainPanel::refresh()
         }
     }
 
+    if(m_actLock) m_actLock->setVisible(ui.kDockContext->features() == QDockWidget::AllDockWidgetFeatures);
+    if(m_actUnLock) m_actUnLock->setVisible(ui.kDockContext->features() == QDockWidget::NoDockWidgetFeatures);
+
     if(m_previousAction) {
         QList<SKGTabPage::SKGPageHistoryItem> list;
         if(toSave) list = toSave->getPreviousPages();
@@ -1157,7 +1288,8 @@ void SKGMainPanel::refresh()
 
     //Set window title
     QString modified;
-    if(getDocument()->isFileModified()) modified = i18nc("Noun, indicate that current document is modified", " [modified]");
+    if(getDocument()->isFileModified()) modified += i18nc("Noun, indicate that current document is modified", " [modified]");
+    if(getDocument()->isReadOnly()) modified += i18nc("Noun, indicate that current document is loaded in read only", " [read only]");
     QString fileName = getDocument()->getCurrentFileName();
     if(fileName.isEmpty()) fileName = i18nc("Noun, default name for a new document", "Untitled");
     setWindowTitle(i18nc("Title of the main window", "%1%2 - %3", fileName, modified, KGlobal::activeComponent().componentName()));
@@ -1184,7 +1316,7 @@ SKGTabPage::SKGPageHistoryItem SKGMainPanel::currentPageHistoryItem() const
     return page;
 }
 
-SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const QString& parameters, const QString& title, const QString& iID)
+SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const QString& parameters, const QString& title, const QString& iID, bool iSetCurrent)
 {
     SKGTRACEIN(1, "SKGMainPanel::openPage");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -1227,11 +1359,11 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
             if(index == -1) {
                 SKGTRACEIN(20, "SKGMainPanel::openPage-addTab");
                 m_tabWidget->addTab(w, KIcon(plugin->icon()), title2);
-                m_tabWidget->setCurrentWidget(w);
+                if(iSetCurrent) m_tabWidget->setCurrentWidget(w);
             } else {
                 SKGTRACEIN(20, "SKGMainPanel::openPage-insertTab");
                 m_tabWidget->insertTab(index, w, KIcon(plugin->icon()), title2);
-                m_tabWidget->setCurrentWidget(w);
+                if(iSetCurrent) m_tabWidget->setCurrentWidget(w);
 
                 w->setPreviousPages(previousPages);
                 QList<SKGTabPage::SKGPageHistoryItem> empty;
@@ -1244,7 +1376,7 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
         notify(); //Due to sendMessage not in a transaction
     }
     m_tabWidget->blockSignals(previous);
-    Q_EMIT currentPageChanged();
+    if(iSetCurrent) Q_EMIT currentPageChanged();
     QApplication::restoreOverrideCursor();
     return w;
 }
@@ -1269,6 +1401,11 @@ int SKGMainPanel::countPages() const
     return m_tabWidget->count();
 }
 
+SKGTabPage* SKGMainPanel::page(int iIndex) const
+{
+    return (SKGTabPage*) m_tabWidget->widget(iIndex);
+}
+
 void SKGMainPanel::setCurrentPage(int iIndex)
 {
     m_tabWidget->setCurrentIndex(iIndex);
@@ -1494,23 +1631,24 @@ void SKGMainPanel::displayErrorMessage(const SKGError& iError)
 {
     SKGTRACEIN(1, "SKGMainPanel::displayErrorMessage");
     SKGMainPanel* parent = SKGMainPanel::getMainPanel();
-
-    if(!!iError) {
-        QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-        int rc = KMessageBox::Cancel;
-        if(iError.getHistoricalSize()) rc = KMessageBox::warningContinueCancel(parent, iError.getFullMessage(),
-                                                i18nc("Question",  "Error"),
-                                                KStandardGuiItem::cont(),
-                                                KGuiItem(i18nc("Noun", "History"), KIcon("dialog-information")));
-        if(rc == KMessageBox::Cancel) {
-            KMessageBox::error(parent, iError.getFullMessageWithHistorical(), i18nc("Noun", "Error"));
+    if(parent) {
+        if(iError) {
+            QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+            int rc = KMessageBox::Cancel;
+            if(iError.getHistoricalSize()) rc = KMessageBox::warningContinueCancel(parent, iError.getFullMessage(),
+                                                    i18nc("Question",  "Error"),
+                                                    KStandardGuiItem::cont(),
+                                                    KGuiItem(i18nc("Noun", "History"), KIcon("dialog-information")));
+            if(rc == KMessageBox::Cancel) {
+                KMessageBox::error(parent, iError.getFullMessageWithHistorical(), i18nc("Noun", "Error"));
+            }
+            QApplication::restoreOverrideCursor();
+        } else {
+            //Status bar
+            QLabel* label = parent->statusNormalMessage();
+            QString message = iError.getMessage();
+            if(label && !message.isEmpty()) label->setText(message);
         }
-        QApplication::restoreOverrideCursor();
-    } else {
-        //Status bar
-        QLabel* label = parent->statusNormalMessage();
-        QString message = iError.getMessage();
-        if(label && !message.isEmpty()) label->setText(message);
     }
 }
 
@@ -1629,6 +1767,11 @@ bool SKGMainPanel::naturalLessThan(const QString &s1, const QString &s2)
     return (KStringHandler::naturalCompare(s1, s2, Qt::CaseInsensitive) < 0);
 }
 
+bool SKGMainPanel::adviceLessThan(const SKGAdvice& s1, const SKGAdvice& s2)
+{
+    return (s1.getPriority() > s2.getPriority());
+}
+
 SKGMainPanel* SKGMainPanel::getMainPanel()
 {
     return m_mainPanel;
