@@ -26,6 +26,10 @@
 #include "skgbasegui_export.h"
 #include "skgtabpage.h"
 #include "skgbasegui_settings.h"
+#include "skginterfaceplugin.h"
+
+#include "ui_skgmainpanel_base.h"
+#include "ui_skgmainpanel_pref.h"
 
 #include <kparts/mainwindow.h>
 #include <ktabwidget.h>
@@ -33,10 +37,6 @@
 #include <ksystemtrayicon.h>
 #include <ktemporaryfile.h>
 
-#include "ui_skgmainpanel_base.h"
-#include "ui_skgmainpanel_pref.h"
-
-class SKGInterfacePlugin;
 class SKGDocument;
 class SKGZoomSelector;
 
@@ -93,7 +93,7 @@ public:
      * @param iCodec a valid QString to get the codec.
      * @return the file name
      */
-    static QString getSaveFileName(const QString & startDir = KUrl(), const QString & filter = QString(), QWidget * parent = 0,
+    static QString getSaveFileName(const QString & startDir = KUrl().url(), const QString & filter = QString(), QWidget * parent = 0,
                                    const QString & caption = QString(), QString* iCodec = NULL);
 
     /**
@@ -205,6 +205,13 @@ public Q_SLOTS:
      */
     virtual SKGTabPage* currentPage() const;
 
+    /**
+     * Get a page
+     * @param iIndex an index
+     * @return the page
+     */
+    virtual SKGTabPage* page(int iIndex) const;
+
     /**
      * Get then number of pages
      * @return the number of pages
@@ -245,9 +252,10 @@ public Q_SLOTS:
      * @param parameters parameters of the plugin
      * @param title title of the page
      * @param iID id of the new page
+     * @param iSetCurrent to set the new page as the current one
      * @return the opened tab
      */
-    virtual SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = "", const QString& title = "", const QString& iID = "");
+    virtual SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = "", const QString& title = "", const QString& iID = "", bool iSetCurrent = true);
 
     /**
      * Close a page
@@ -308,6 +316,12 @@ public Q_SLOTS:
      */
     virtual void optionsPreferences(const QString& iPluginName = "");
 
+    /**
+     * Get all advices
+     * @return the list of advices
+     */
+    virtual SKGAdviceList getAdvices() const;
+
 Q_SIGNALS:
     /**
      * This signal is sent when the current page change.
@@ -358,8 +372,14 @@ private Q_SLOTS:
     void onShowNextMenu();
     void onZoomChanged();
 
+    void onShowMenuBar();
+    void onShowButtonMenu();
+
     void actionHideContextItem();
     void actionShowAllContextItems();
+
+    void actionLockDocks();
+    void actionUnlockDocks();
 private:
     Q_DISABLE_COPY(SKGMainPanel);
     void setupActions();
@@ -368,6 +388,8 @@ private:
 
     static int progressBarCallBack(int iPos, void* iProgressBar);
     static bool naturalLessThan(const QString &s1, const QString &s2);
+    static bool adviceLessThan(const SKGAdvice &s1, const SKGAdvice &s2);
+
 
     Ui::skgmainpanel_base ui;
     Ui::skgmainpanel_pref uipref;
@@ -396,6 +418,8 @@ private:
     KAction *m_configureAction;
     KAction *m_enableEditorAction;
     KAction* m_fullScreenAction;
+    KAction* m_actLock;
+    KAction* m_actUnLock;
     KTemporaryFile m_tipsFile;
     KSystemTrayIcon* m_kSystemTrayIcon;
     QLabel* m_kNormalMessage;
@@ -403,9 +427,12 @@ private:
 
     KToolBarPopupAction *m_previousAction;
     KToolBarPopupAction *m_nextAction;
+    KToolBarPopupAction *m_buttonMenuAction;
+    KToggleAction* m_showMenuBarAction;
 
     KMenu *m_previousMenu;
     KMenu *m_nextMenu;
+    KMenu *m_buttonMenu;
 
     struct doublePointer {
         void* p1;
