@@ -30,6 +30,7 @@
 #include <klocalizedstring.h>
 #include <klocale.h>
 #include <kicon.h>
+#include <kcolorscheme.h>
 
 #include <QApplication>
 #include <QMimeData>
@@ -39,7 +40,7 @@
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
                                        const QString& iWhereClause,
-                                       QObject *parent,
+                                       QWidget *parent,
                                        const QString& iParentAttribute,
                                        bool iResetOnCreation)
     : QAbstractItemModel(parent), m_isResetRealyNeeded(iResetOnCreation), m_document(iDocument),
@@ -51,7 +52,7 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
     setTable(iTable);
 
     connect((const QObject*) m_document, SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)));
-    refresh();
+    connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
 }
 
 SKGObjectModelBase::~SKGObjectModelBase()
@@ -117,7 +118,7 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList & iListAttribu
         if(nbValues > 0 && !m_listSupported.contains(att) && attributesAvailables.contains(att)) {
             m_listSupported.push_back(att);
             bool visible = true;
-            if(nbValues > 1) visible = (values.at(1) == "Y");
+            if(nbValues > 1) visible = (i == 0 || values.at(1) == "Y"); //First column is always visible to support grouping
             m_listVisibility.push_back(visible);
             if(nbValues > 2) m_listSize.push_back(SKGServices::stringToInt(values.at(2)));
             else m_listSize.push_back(-1);
@@ -127,10 +128,11 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList & iListAttribu
     m_isResetRealyNeeded = true;
 }
 
-void SKGObjectModelBase::setFilter(const QString & iWhereClause)
+bool SKGObjectModelBase::setFilter(const QString & iWhereClause)
 {
     if(iWhereClause != m_whereClause) m_isResetRealyNeeded = true;
     m_whereClause = iWhereClause;
+    return m_isResetRealyNeeded;
 }
 
 void SKGObjectModelBase::setTable(const QString & iTable)
@@ -148,6 +150,24 @@ QString SKGObjectModelBase::getTable() const
     return m_table;
 }
 
+void SKGObjectModelBase::setGroupBy(const QString& iAttribute)
+{
+    if(iAttribute != m_groupby) {
+        m_isResetRealyNeeded = true;
+        m_groupby = iAttribute;
+    }
+}
+
+QString SKGObjectModelBase::getGroupBy() const
+{
+    return m_groupby;
+}
+
+QString SKGObjectModelBase::getParentChildAttribute() const
+{
+    return m_parentAttribute;
+}
+
 QString SKGObjectModelBase::getRealTable() const
 {
     return m_realTable;
@@ -168,6 +188,10 @@ void SKGObjectModelBase::buidCache()
     SKGTRACEIN(1, "SKGObjectModelBase::buidCache");
     m_doctransactionTable = (getRealTable() == "doctransaction");
     m_nodeTable = (getRealTable() == "node");
+
+    //Get std colors
+    KColorScheme scheme(QPalette::Normal);
+    m_fontNegativeColor = qVariantFromValue(scheme.foreground(KColorScheme::NegativeText).color());
 }
 
 bool SKGObjectModelBase::blockRefresh(bool iBlocked)
@@ -244,12 +268,18 @@ void SKGObjectModelBase::refresh()
             }
 
             //Get objects
-            if(m_document) m_document->getObjects(m_table, m_whereClause, m_listObjects);
-
-            QList<SKGObjectBase*> listObjectToTreat;
-            QList<int> listObjectToTreatId;
+            QString wc = m_whereClause;
+            if(!m_groupby.isEmpty()) {
+                if(wc.isEmpty()) wc = "1=1";
+                wc += " ORDER BY " % m_groupby;
+            }
+            if(m_document) m_document->getObjects(m_table, wc , m_listObjects);
 
             //Initialize object to treat
+            QString currentGroup;
+            int currentGoupId = 0;
+            bool groupByDate = (m_groupby.startsWith(QLatin1String("d_")));
+            bool groupByNum = (m_groupby.startsWith(QLatin1String("f_")) || m_groupby.startsWith(QLatin1String("i_")));
             int nb = m_listObjects.count();
             SKGTRACEL(1) << nb << " objects found" << endl;
             for(int t = 0; t < nb; ++t) {
@@ -257,13 +287,68 @@ void SKGObjectModelBase::refresh()
                 int id = getID(c, t);
 
                 int idparent = 0;
-                if(!m_parentAttribute.isEmpty()) {
-                    int idp = SKGServices::stringToInt(c->getAttribute(m_parentAttribute));
-                    if(idp > 0) idparent = idp;
-                }
+                if(m_groupby.isEmpty()) {
+                    //Grouping by tree
+                    if(!m_parentAttribute.isEmpty()) {
+                        int idp = SKGServices::stringToInt(c->getAttribute(m_parentAttribute));
+                        if(idp > 0) idparent = idp;
+                    }
+                } else {
+                    //Grouping on specified attribute
+                    QString att = getAttributeForGrouping(*c, m_groupby);
+                    if(groupByDate) {
+                        QDate date = SKGServices::stringToTime(att).date();
+                        if(date == QDate::currentDate()) att = i18nc("A group name for grouping by date attibute", "Today");
+                        else if(date > QDate::currentDate()) {
+                            //In future
+                            if(date < QDate::currentDate().addDays(7)) att = i18nc("A group name for grouping by date attibute", "Next 7 days");
+                            else if(date < QDate::currentDate().addDays(15)) att = i18nc("A group name for grouping by date attibute", "Next 15 days");
+                            else if(date < QDate::currentDate().addMonths(1)) att = i18nc("A group name for grouping by date attibute", "Next month");
+                            else if(date < QDate::currentDate().addYears(1)) att = i18nc("A group name for grouping by date attibute", "Next year");
+                            else att = i18nc("A group name for grouping by date attibute", "Far away in the future");
+                        } else {
+                            //In the past
+                            if(date > QDate::currentDate().addDays(-7)) att = i18nc("A group name for grouping by date attibute", "Last 7 days");
+                            else if(date > QDate::currentDate().addDays(-15)) att = i18nc("A group name for grouping by date attibute", "Last 15 days");
+                            else if(date > QDate::currentDate().addMonths(-1)) att = i18nc("A group name for grouping by date attibute", "Last month");
+                            else if(date > QDate::currentDate().addYears(-1)) att = i18nc("A group name for grouping by date attibute", "Last year");
+                            else att = i18nc("A group name for grouping by date attibute", "Far away in the past");
+                        }
+                    } else if(groupByNum) {
+                        if(att != QChar(8734)) {
+                            double d = SKGServices::stringToDouble(att);
+                            if(d > 10000.0) att = i18nc("A group name for grouping by numerical attibute", "> 10000");
+                            else if(d > 1000.0) att = i18nc("A group name for grouping by numerical attibute", "> 1000");
+                            else if(d > 100.0) att = i18nc("A group name for grouping by numerical attibute", "> 100");
+                            else if(d > 10.0) att = i18nc("A group name for grouping by numerical attibute", "> 10");
+                            else if(d > 0.0) att = i18nc("A group name for grouping by numerical attibute", "> 0");
+                            else if(d < -10000.0) att = i18nc("A group name for grouping by numerical attibute", "< -10000");
+                            else if(d < -1000.0) att = i18nc("A group name for grouping by numerical attibute", "< -1000");
+                            else if(d < -100.0) att = i18nc("A group name for grouping by numerical attibute", "< -100");
+                            else if(d < -10.0) att = i18nc("A group name for grouping by numerical attibute", "< -10");
+                            else if(d < 0.0) att = i18nc("A group name for grouping by numerical attibute", "< 0");
+                            else att = i18nc("A group name for grouping by numerical attibute", "= 0");
+                        }
+                    }
+                    if(att != currentGroup || currentGoupId == 0) {
+                        //Addition of a new group
+                        currentGroup = att;
+                        currentGoupId--;
+                        SKGObjectBase* group = new SKGObjectBase(NULL, "", currentGoupId);
+                        group->setAttribute("t_title", currentGroup);
 
-                listObjectToTreat.push_back(c);
-                listObjectToTreatId.push_back(id);
+                        m_childParentRelations.insert(currentGoupId, 0);
+
+                        QList<int> childrensids = m_parentChildRelations.value(0);
+                        childrensids.push_back(currentGoupId);
+
+                        m_parentChildRelations.insert(0, childrensids);
+                        m_objectsHashTableRows.insert(currentGoupId, childrensids.count() - 1);
+                        m_objectsHashTable.insert(currentGoupId, group);
+                    }
+
+                    idparent = currentGoupId;
+                }
 
                 m_childParentRelations.insert(id, idparent);
 
@@ -414,53 +499,87 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
     _SKGTRACEIN(10, "SKGObjectModelBase::data");
 
     switch(role) {
+    case Qt::BackgroundRole: {
+        SKGObjectBase* obj = getObjectPointer(index);
+        if(obj->getTable().isEmpty()) {
+            //This is a group
+            return QApplication::palette().brush(QPalette::Button);
+        }
+        break;
+    }
     case Qt::DisplayRole:
     case Qt::EditRole:
     case Qt::UserRole: {
         SKGObjectBase* obj = getObjectPointer(index);
         QString att = m_listAttibutes[index.column()];
-        QString val;
-
-        if(att.startsWith(QLatin1String("p_"))) {
-            //This is a property
-            val = obj->getProperty(att.right(att.count() - 2));
+        if(obj->getTable().isEmpty()) {
+            //This is a group
+            if(index.column() == 0) {
+                if(role == Qt::UserRole) return -obj->getID(); //For sorting
+                else return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
+                                      getDocument()->getDisplay(m_groupby),
+                                      obj->getAttribute("t_title"),
+                                      rowCount(SKGObjectModelBase::index(index.row(), 0)));
+            }
+            return "";
         } else {
-            //This is a real attribute
-            val = obj->getAttribute(att);
-        }
-
-        switch(getAttributeType(index.column())) {
-        case SKGServices::FLOAT: {
-            double dval = SKGServices::stringToDouble(val);
-            return dval;
-        }
-        case SKGServices::INTEGER: {
-            return SKGServices::stringToInt(val);
-        }
-        case SKGServices::DATE: {
-            QDate dval = SKGServices::stringToTime(val).date();
-            if(role == Qt::DisplayRole) {
-                return KGlobal::locale()->formatDate(dval, (KLocale::DateFormat) skgbasegui_settings::date_format());
+            QString val;
+            if(att.startsWith(QLatin1String("p_"))) {
+                //This is a property
+                val = obj->getProperty(att.right(att.count() - 2));
             } else {
+                //This is a real attribute
+                val = obj->getAttribute(att);
+            }
+
+            switch(getAttributeType(index.column())) {
+            case SKGServices::FLOAT: {
+                double dval = SKGServices::stringToDouble(val);
                 return dval;
             }
-        }
-        default: {}
-        }
+            case SKGServices::INTEGER: {
+                return SKGServices::stringToInt(val);
+            }
+            case SKGServices::DATE: {
+                QDate dval = SKGServices::stringToTime(val).date();
+                if(role == Qt::DisplayRole) {
+                    return KGlobal::locale()->formatDate(dval, (KLocale::DateFormat) skgbasegui_settings::date_format());
+                } else {
+                    return dval;
+                }
+            }
+            default: {}
+            }
 
-        if(m_doctransactionTable && att == "t_savestep") return "";
+            if(m_doctransactionTable && att == "t_savestep") return "";
 
-        //return val+"("+SKGServices::intToString(rowCount(index))+")";
-        return val;
+            //return val+"("+SKGServices::intToString(rowCount(index))+")";
+            return val;
+        }
     }
 
+    case Qt::FontRole: {
+        SKGObjectBase* obj = getObjectPointer(index);
+        //Text color
+        if(obj->getTable().isEmpty()) {
+            //This is a group
+            if(index.column() == 0) {
+                QFont f;
+                f.setBold(true);
+
+                return qVariantFromValue(f);
+            }
+            return "";
+        }
+        break;
+    }
     case Qt::TextColorRole: {
         //Text color
         if(getAttributeType(index.column()) == SKGServices::FLOAT) {
             QVariant value_displayed = SKGObjectModelBase::data(index, Qt::UserRole);
             bool ok = false;
             double value_double = value_displayed.toDouble(&ok);
-            if(ok && value_double < 0) return qVariantFromValue(QColor(Qt::red));
+            if(ok && value_double < 0) return m_fontNegativeColor;
         }
         break;
     }
@@ -473,39 +592,45 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
         //Decoration
         SKGObjectBase* obj = getObjectPointer(index);
         QString att = m_listAttibutes[index.column()];
-        if(index.column() == 0 && m_nodeTable) {
-            SKGNodeObject node = *obj;
-            return qVariantFromValue(node.getIcon());
-        } else if(index.column() == 0 && m_doctransactionTable) {
-            return qVariantFromValue((QIcon) KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo"));
-        } else if(m_doctransactionTable && att == "t_savestep") {
-            if(obj->getAttribute("t_savestep") == "Y") return qVariantFromValue((QIcon) KIcon("document-save"));
-        }
-        /*TODO else if (att.startsWith(QLatin1String("p_")))
-        {
-            //This attribute is a property
-            QVariant blob=obj->getPropertyBlob(att.right(att.count()-2));
-            //Is it a file ?
-            if (!blob.isNull()) {
-                //Yes, this is a file
-                QByteArray blob_bytes=blob.toByteArray();
-
-                //Save temporary file
-                QString fileName=QDir::tempPath ()+'/'+obj->getAttribute("t_value");
-
-                QFile file(fileName);
-                if (file.open(QIODevice::WriteOnly))
-                {
-                    file.write(blob_bytes);
-                    file.flush();
-                    file.close();
-
-                    ui.kPicture->show();
-                     ui.kOpenBtn->show();
-                     ui.kPicture->showPreview(KUrl(fileName));
-                }
+        if(obj->getTable().isEmpty()) {
+            //This is a group
+            if(index.column() == 0) return qVariantFromValue((QIcon) KIcon("arrow-right"));;
+            return "";
+        } else {
+            if(index.column() == 0 && m_nodeTable) {
+                SKGNodeObject node = *obj;
+                return qVariantFromValue(node.getIcon());
+            } else if(index.column() == 0 && m_doctransactionTable) {
+                return qVariantFromValue((QIcon) KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo"));
+            } else if(m_doctransactionTable && att == "t_savestep") {
+                if(obj->getAttribute("t_savestep") == "Y") return qVariantFromValue((QIcon) KIcon("document-save"));
             }
-        }*/
+            /*TODO else if (att.startsWith(QLatin1String("p_")))
+            {
+                //This attribute is a property
+                QVariant blob=obj->getPropertyBlob(att.right(att.count()-2));
+                //Is it a file ?
+                if (!blob.isNull()) {
+                    //Yes, this is a file
+                    QByteArray blob_bytes=blob.toByteArray();
+
+                    //Save temporary file
+                    QString fileName=QDir::tempPath ()+'/'+obj->getAttribute("t_value");
+
+                    QFile file(fileName);
+                    if (file.open(QIODevice::WriteOnly))
+                    {
+                        file.write(blob_bytes);
+                        file.flush();
+                        file.close();
+
+                        ui.kPicture->show();
+                         ui.kOpenBtn->show();
+                         ui.kPicture->showPreview(KUrl(fileName));
+                    }
+                }
+            }*/
+        }
         break;
     }
     case Qt::ToolTipRole: {
@@ -577,6 +702,8 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex &index) const
     if(index.isValid()) {
         QString att = m_listAttibutes[index.column()];
         if(att.toLower() == att || !getDocument()->getRealAttribute(att).isEmpty()) flags |= Qt::ItemIsEditable;
+        SKGObjectBase* obj = getObjectPointer(index);
+        if(obj->getTable().isEmpty()) flags = Qt::ItemIsEnabled;
     }
 
     return flags;
@@ -600,7 +727,7 @@ bool SKGObjectModelBase::setData(const QModelIndex & index, const QVariant& valu
 
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Update object"), err);
             SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID()); //To be sure this is not a complex object
-            err = obj2.setAttribute(m_listAttibutes[index.column()], value.toString());
+            err = obj2.setAttribute(m_listAttibutes[index.column()], value.canConvert<QDateTime>() ? SKGServices::dateToSqlString(value.toDateTime()) : value.toString());
             if(!err) err = obj2.save();
         }
 
@@ -617,7 +744,7 @@ Qt::DropActions SKGObjectModelBase::supportedDragActions() const
 
 Qt::DropActions SKGObjectModelBase::supportedDropActions() const
 {
-    return Qt::MoveAction;
+    return Qt::MoveAction | Qt::LinkAction;
 }
 
 QStringList SKGObjectModelBase::mimeTypes() const
@@ -676,7 +803,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData *data,
                     index++;
                     name = i18n("File") % " (" % SKGServices::intToString(index) % ')';
                 }
-                err = obj.setProperty(name, urls.at(i).toLocalFile(), urls.at(i).toLocalFile());
+                err = obj.setProperty(name, urls.at(i).toLocalFile(), action == Qt::LinkAction ? "" : urls.at(i).toLocalFile());
                 if(!err) err = getDocument()->stepForward(i + 1);
             }
         }
@@ -747,12 +874,23 @@ bool SKGObjectModelBase::canFetchMore(const QModelIndex & parent) const
     return false;
 }
 
+void SKGObjectModelBase::pageChanged()
+{
+    if(m_isResetRealyNeeded) dataModified("", 0);
+}
+
 void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransaction)
 {
     if(getTable() == iTableName || iTableName.isEmpty()) {
         SKGTRACEIN(1, "SKGObjectModelBase::dataModified");
         SKGTRACEL(1) << "getTable=" << getRealTable() << endl;
         SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << endl;
+        SKGTabPage* page = SKGTabPage::parentTabPage(qobject_cast< QWidget* >(this->QObject::parent()));
+        SKGTabPage* cpage = SKGMainPanel::getMainPanel()->currentPage();
+        if(page != NULL && page != cpage) {
+            m_isResetRealyNeeded = true;
+            return;
+        }
 
         //Full refresh
         m_isResetRealyNeeded = true;
@@ -762,5 +900,10 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
     }
 }
 
+QString SKGObjectModelBase::getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const
+{
+    return iObject.getAttribute(iAttribute);
+}
+
 #include "skgobjectmodelbase.moc"
 
