@@ -29,7 +29,7 @@
 #include <QAbstractItemModel>
 #include <QStringList>
 
-
+class QWidget;
 /**
  * The Table model managing SKGObjectBase
  */
@@ -54,7 +54,7 @@ public:
     SKGObjectModelBase(SKGDocument* iDocument,
                        const QString& iTable,
                        const QString& iWhereClause,
-                       QObject *parent = NULL,
+                       QWidget *parent = NULL,
                        const QString& iParentAttribute = "",
                        bool iResetOnCreation = true);
 
@@ -63,11 +63,6 @@ public:
      */
     virtual ~SKGObjectModelBase();
 
-    /**
-     * Refresh the model.
-     */
-    virtual void refresh();
-
     /**
      * Allows to block a refresh
      * @param iBlocked blocking status
@@ -198,6 +193,25 @@ public:
      */
     virtual QString getTable() const;
 
+    /**
+     * Set the attribute used for grouping
+     * @param iAttribute the attibute name
+     */
+    virtual void setGroupBy(const QString & iAttribute = "");
+
+    /**
+     * Get the attribute used for grouping
+     * @return attibute name
+     */
+    virtual QString getGroupBy() const;
+
+    /**
+     * Get the attribute used for parent / child relationship
+     * @return attibute name
+     */
+    virtual QString getParentChildAttribute() const;
+
+
     /**
      * Get real table name
      * @return real table name
@@ -226,8 +240,9 @@ public:
     /**
      * Set the filter. Don't forget to do a reset after that.
      * @param iWhereClause the where clause
+     * @return true is the filter is really changed
      */
-    virtual void setFilter(const QString & iWhereClause);
+    virtual bool setFilter(const QString & iWhereClause);
 
     /**
      * Returns the actions supported by the data in this model.
@@ -289,11 +304,11 @@ Q_SIGNALS:
      */
     void afterReset();
 
-protected Q_SLOTS:
+public Q_SLOTS:
     /**
-     * This method is called by refresh to build the cache (to improve performance)
+     * Refresh the model.
      */
-    virtual void buidCache();
+    virtual void refresh();
 
     /**
      * data are modified
@@ -301,7 +316,13 @@ protected Q_SLOTS:
      * @param iIdTransaction the id of the transaction for direct modifications of the table (update of modify objects is enough)
      *or 0 in case of modifications by impact (full table must be refreshed)
      */
-    virtual void dataModified(const QString& iTableName, int iIdTransaction);
+    virtual void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
+
+protected Q_SLOTS:
+    /**
+     * This method is called by refresh to build the cache (to improve performance)
+     */
+    virtual void buidCache();
 
 protected:
 
@@ -325,6 +346,22 @@ protected:
      */
     bool m_isResetRealyNeeded;
 
+    /**
+     * Get the attribute value for grouping
+     * @param iObject the object
+     * @param iAttribute the attribute name
+     * @return the value of the attribute
+     */
+    virtual QString getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const;
+
+    /**
+     *The negative color
+     */
+    QVariant m_fontNegativeColor;
+
+private Q_SLOTS:
+    void pageChanged();
+
 private:
     Q_DISABLE_COPY(SKGObjectModelBase);
     void clear();
@@ -335,6 +372,7 @@ private:
     QString m_realTable;
     QString m_whereClause;
     QString m_parentAttribute;
+    QString m_groupby;
 
     SKGObjectBase::SKGListSKGObjectBase m_listObjects;
     QHash<int, SKGIntList> m_parentChildRelations;
