@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,21 +27,21 @@
 #include <QtPlugin>
 
 SKGTableViewDesignerPlugin::SKGTableViewDesignerPlugin(QObject *parent)
-        : QObject(parent)
+    : QObject(parent)
 {
-    initialized = false;
+    m_initialized = false;
 }
 
 void SKGTableViewDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
 {
-    if (initialized) return;
+    if(m_initialized) return;
 
-    initialized = true;
+    m_initialized = true;
 }
 
 bool SKGTableViewDesignerPlugin::isInitialized() const
 {
-    return initialized;
+    return m_initialized;
 }
 
 QWidget *SKGTableViewDesignerPlugin::createWidget(QWidget *parent)
