@@ -57,6 +57,9 @@ protected:
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
     virtual bool eventFilter(QObject *object, QEvent *event);
+
+private slots:
+    void copy();
 };
 
 #endif // SKGTABLEWIDGET_H
