@@ -32,6 +32,7 @@
 #include <kfiledialog.h>
 #include <kstringhandler.h>
 #include <kstandarddirs.h>
+#include <kcolorscheme.h>
 
 #include <QtGui/QHeaderView>
 #include <QtGui/QGraphicsLineItem>
@@ -44,11 +45,11 @@
 #include <QTimer>
 #include <QScriptEngine>
 #include <QGraphicsDropShadowEffect>
-
-#include <math.h>
+#include <qmath.h>
 #include <qtextcodec.h>
 #include <qpropertyanimation.h>
 
+
 /**
   * Data identifier for value
   */
@@ -69,6 +70,10 @@ static const int DATA_COLOR_V = 13;
   * Data identifier for Z value
   */
 static const int DATA_Z_VALUE = 14;
+/**
+  * Alpha value
+  */
+static const int ALPHA = 200;
 /**
   * Box size
   */
@@ -84,7 +89,7 @@ int SKGTableWithGraph::m_sortColumn = 0;
 SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
     : QWidget(parent), m_scene(NULL), m_additionalInformation(NONE), m_nbVirtualColumns(0),
       m_selectable(true), m_toolBarVisible(true), m_graphTypeVisible(true), m_limitVisible(true),
-      m_linearRegressionVisible(true), m_legendVisible(false), m_graphVisible(true), m_tableVisible(true), m_testVisible(false), m_zeroVisible(true),
+      m_linearRegressionVisible(true), m_legendVisible(false), m_graphVisible(true), m_tableVisible(true), m_textVisible(false), m_zeroVisible(true),
       m_mainMenu(NULL),
       m_indexSum(-1), m_indexAverage(-1), m_indexMin(-1), m_indexLinearRegression(-1)
 {
@@ -96,11 +101,11 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
     m_tendencyColor = Qt::darkYellow;
     m_backgroundColor = Qt::white;
     m_textColor = Qt::black;
+    m_NegativeColor = KColorScheme(QPalette::Normal).foreground(KColorScheme::NegativeText);
 
     ui.setupUi(this);
     ui.kTextEdit->hide();
 
-    //TODO
 #ifdef SKGKDE46ENABLED
     ui.kFilterEdit->setPlaceholderText(i18n("Search"));
 #endif
@@ -205,7 +210,11 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
 
     //Set headers parameters
     QHeaderView* verticalHeader = ui.kTable->verticalHeader();
-    if(verticalHeader)  verticalHeader->hide();
+    if(verticalHeader) {
+        verticalHeader->hide();
+        verticalHeader->setDefaultSectionSize(verticalHeader->minimumSectionSize());
+        verticalHeader->setResizeMode(QHeaderView::ResizeToContents);
+    }
 
     ui.kTable->setSortingEnabled(false);    //sort must be enable for refresh method
     QHeaderView* horizontalHeader = ui.kTable->horizontalHeader();
@@ -216,7 +225,6 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
         horizontalHeader->setSortIndicator(m_sortColumn, m_sortOrder);
         connect(horizontalHeader, SIGNAL(sortIndicatorChanged(int, Qt::SortOrder)), this, SLOT(refresh()));
     }
-    ui.kTable->verticalHeader()->setDefaultSectionSize(ui.kTable->verticalHeader()->minimumSectionSize());
 
     connect(m_displayMode, SIGNAL(currentIndexChanged(int)), this, SLOT(redrawGraphDelayed()), Qt::QueuedConnection);
     connect(ui.graphicView, SIGNAL(resized()), this, SLOT(redrawGraphDelayed()), Qt::QueuedConnection);
@@ -242,6 +250,23 @@ SKGTableWithGraph::~SKGTableWithGraph()
     m_mainMenu = NULL;
     m_actShowLimits = NULL;
     m_actShowLinearRegression = NULL;
+    m_displayModeWidget = NULL;
+    m_displayMode = NULL;
+}
+
+bool SKGTableWithGraph::isGraphVisible() const
+{
+    return m_graphVisible;
+}
+
+bool SKGTableWithGraph::isTableVisible() const
+{
+    return m_tableVisible;
+}
+
+bool SKGTableWithGraph::isTextReportVisible() const
+{
+    return m_textVisible;
 }
 
 SKGShow* SKGTableWithGraph::getShowWidget() const
@@ -301,8 +326,8 @@ void SKGTableWithGraph::setAntialiasing(bool iAntialiasing)
 void SKGTableWithGraph::setGraphTypeSelectorVisible(bool iVisible)
 {
     m_graphTypeVisible = iVisible;
-    m_displayMode->setVisible(m_graphTypeVisible);
-    m_displayModeWidget->setVisible(m_graphTypeVisible);
+    if(m_displayMode) m_displayMode->setVisible(m_graphTypeVisible);
+    if(m_displayModeWidget) m_displayModeWidget->setVisible(m_graphTypeVisible);
 }
 
 bool SKGTableWithGraph::isGraphTypeSelectorVisible() const
@@ -313,7 +338,7 @@ bool SKGTableWithGraph::isGraphTypeSelectorVisible() const
 void SKGTableWithGraph::onSwitchLimits()
 {
     m_limitVisible = !m_limitVisible;
-    redrawGraphDelayed();
+    refresh();
 }
 
 void SKGTableWithGraph::onSwitchLegend()
@@ -331,7 +356,7 @@ void SKGTableWithGraph::onSwitchZero()
 void SKGTableWithGraph::onSwitchLinearRegression()
 {
     m_linearRegressionVisible = !m_linearRegressionVisible;
-    redrawGraphDelayed();
+    refresh();
 }
 
 KMenu* SKGTableWithGraph::getTableContextualMenu() const
@@ -354,6 +379,16 @@ QTableWidget* SKGTableWithGraph::table() const
     return ui.kTable;
 }
 
+SKGGraphicsView* SKGTableWithGraph::graph() const
+{
+    return ui.graphicView;
+}
+
+SKGWebView* SKGTableWithGraph::textReport() const
+{
+    return ui.kTextEdit;
+}
+
 SKGStringListList SKGTableWithGraph::getTable()
 {
     //Build table
@@ -362,14 +397,14 @@ SKGStringListList SKGTableWithGraph::getTable()
     //Get header names
     int nb = ui.kTable->columnCount();
     QStringList cols;
-    for(int i = 0; i < nb; i++) {
+    for(int i = 0; i < nb; ++i) {
         cols.append(ui.kTable->horizontalHeaderItem(i)->text());
     }
     table.append(cols);
 
     //Get content
     int nb2 = ui.kTable->rowCount();
-    for(int i = 0; i < nb2; i++) {
+    for(int i = 0; i < nb2; ++i) {
         QStringList row;
 
         for(int j = 0; j < nb; j++) {
@@ -459,7 +494,7 @@ void SKGTableWithGraph::setState(const QString& iState)
 
     //Set
     setGraphType(SKGTableWithGraph::HISTOGRAM);
-    m_displayMode->setCurrentIndex(1);
+    if(m_displayMode) m_displayMode->setCurrentIndex(1);
     setGraphType((SKGTableWithGraph::GraphType) SKGServices::stringToInt(graphMode));
     m_allPositiveMenu->setChecked(allPositive == "Y");
     ui.kFilterEdit->setText(root.attribute("filter"));
@@ -512,7 +547,7 @@ void SKGTableWithGraph::onDisplayModeChanged()
     ui.kTable->blockSignals(p);
     m_graphVisible = false;
     m_tableVisible = false;
-    m_testVisible = false;
+    m_textVisible = false;
     m_mapItemGraphic.clear();
 
     //Show needed widget
@@ -526,8 +561,8 @@ void SKGTableWithGraph::onDisplayModeChanged()
         redrawGraphDelayed();
     }
     if(mode.contains("text")) {
-        ui.kTextEdit->show();
-        m_testVisible = true;
+        QTimer::singleShot(100, ui.kTextEdit, SLOT(show()));
+        m_textVisible = true;
         redrawText();
     }
 }
@@ -705,7 +740,7 @@ void SKGTableWithGraph::refresh()
     m_indexAverage = -1;
     m_indexMin = -1;
     m_indexLinearRegression = -1;
-    if(nbCols > 2 && (m_additionalInformation & SUM || m_additionalInformation & AVERAGE || m_additionalInformation & LIMITS)) {
+    if(nbCols > 2 && (m_additionalInformation & SUM || (m_limitVisible && m_additionalInformation & AVERAGE) || (m_limitVisible && m_additionalInformation & LIMITS))) {
         SKGTRACEIN(10, "SKGTableWithGraph::refresh-computation");
         //Add title
         QStringList newLine = groupedTable.at(0);
@@ -713,18 +748,20 @@ void SKGTableWithGraph::refresh()
             m_indexSum = newLine.count();
             newLine.push_back(i18nc("Noun, the numerical sum of a list of values", "Sum"));
         }
-        if(m_additionalInformation & AVERAGE) {
+        if(m_limitVisible && m_additionalInformation & AVERAGE) {
             m_indexAverage = newLine.count();
             newLine.push_back(i18nc("Noun, the numerical average of a list of values", "Average"));
         }
-        if(m_additionalInformation & LIMITS) {
+        if(m_limitVisible && m_additionalInformation & LIMITS) {
             m_indexMin = newLine.count();
             newLine.push_back(i18nc("Noun, the minimum value of a list of values", "Min"));
             newLine.push_back(i18nc("Noun, the maximum value of a list of values", "Max"));
         }
 
-        m_indexLinearRegression = newLine.count();
-        newLine.push_back(i18nc("Noun", "Tendency line"));
+        if(m_linearRegressionVisible) {
+            m_indexLinearRegression = newLine.count();
+            newLine.push_back(i18nc("Noun", "Tendency line"));
+        }
 
         groupedTable.replace(0, newLine);
 
@@ -751,8 +788,8 @@ void SKGTableWithGraph::refresh()
                 }
             }
             if(m_additionalInformation & SUM) newLine.push_back(SKGServices::doubleToString(sumy));
-            if(m_additionalInformation & AVERAGE && nbVals) newLine.push_back(SKGServices::doubleToString(sumy / nbVals));
-            if(m_additionalInformation & LIMITS) {
+            if(m_limitVisible && m_additionalInformation & AVERAGE && nbVals) newLine.push_back(SKGServices::doubleToString(sumy / nbVals));
+            if(m_limitVisible && m_additionalInformation & LIMITS) {
                 newLine.push_back(SKGServices::doubleToString(min));
                 newLine.push_back(SKGServices::doubleToString(max));
             }
@@ -769,10 +806,10 @@ void SKGTableWithGraph::refresh()
 
             groupedTable.replace(i, newLine);
         }
-        ++nbCols;
+        if(m_linearRegressionVisible) ++nbCols;
         if(m_additionalInformation & SUM) ++nbCols;
-        if(m_additionalInformation & AVERAGE) ++nbCols;
-        if(m_additionalInformation & LIMITS) nbCols += 2;
+        if(m_limitVisible && m_additionalInformation & AVERAGE) ++nbCols;
+        if(m_limitVisible && m_additionalInformation & LIMITS) nbCols += 2;
     }
 
     //Sort lines
@@ -819,9 +856,6 @@ void SKGTableWithGraph::refresh()
                 SKGTRACEIN(10, "SKGTableWithGraph::refresh-sethorizontalheaderlabels");
                 //Set header
                 ui.kTable->setHorizontalHeaderLabels(line);
-
-                //Hide linear regression
-                ui.kTable->hideColumn(m_indexLinearRegression);
             } else {
                 for(int j = 0; j < nbCols; ++j) {
                     QString val = line.at(j);
@@ -855,6 +889,7 @@ void SKGTableWithGraph::refresh()
 
                             SKGColorButton* colorSelector = new SKGColorButton(this);
                             colorSelector->setText(val);
+                            colorSelector->setToolTip(val);
                             colorSelector->setColor(color);
                             colorSelector->setDefaultColor(defaultColor);
                             connect(colorSelector, SIGNAL(changed(QColor)), this, SLOT(onChangeColor()));
@@ -882,7 +917,7 @@ void SKGTableWithGraph::refresh()
 
                                 item->setData(DATA_VALUE, vald);
                                 item->setTextAlignment(Qt::AlignRight);
-                                if(vald < 0) item->setForeground(QBrush(QColor(Qt::red)));
+                                if(vald < 0) item->setForeground(m_NegativeColor);
                                 if(m_sumRows[i]) {
                                     QFont f = item->font();
                                     f.setBold(true);
@@ -909,7 +944,13 @@ void SKGTableWithGraph::refresh()
         redrawText();
 
         if(horizontalHeader) horizontalHeader->setResizeMode(QHeaderView::ResizeToContents);
+
         if(m_tableVisible) ui.kTable->show();
+
+        if(horizontalHeader && horizontalHeader->count()) {
+            horizontalHeader->resizeSection(0, 100);
+            horizontalHeader->setResizeMode(0, QHeaderView::Interactive);
+        }
     }
 
     QApplication::restoreOverrideCursor();
@@ -945,18 +986,23 @@ void SKGTableWithGraph::onSelectionChanged()
                     if(val) {
                         QAbstractGraphicsShapeItem * graphicItem = dynamic_cast<QAbstractGraphicsShapeItem *>(val);
                         if(graphicItem) {
-                            graphicItem->setBrush(QBrush(QColor::fromHsv(graphicItem->data(DATA_COLOR_H).toInt(),
-                                                         graphicItem->data(DATA_COLOR_S).toInt(),
-                                                         graphicItem->data(DATA_COLOR_V).toInt())));
+                            QColor color = QColor::fromHsv(graphicItem->data(DATA_COLOR_H).toInt(),
+                                                           graphicItem->data(DATA_COLOR_S).toInt(),
+                                                           graphicItem->data(DATA_COLOR_V).toInt());
+                            color.setAlpha(ALPHA);
+
+                            graphicItem->setBrush(QBrush(color));
                             graphicItem->setZValue(graphicItem->data(DATA_Z_VALUE).toReal());
                             if(graphicItem->isSelected()) graphicItem->setSelected(false);
                         } else {
                             QGraphicsLineItem * graphicItem = dynamic_cast<QGraphicsLineItem *>(val);
                             if(graphicItem) {
                                 QPen pen = graphicItem->pen();
-                                pen.setColor(QColor::fromHsv(graphicItem->data(DATA_COLOR_H).toInt(),
-                                                             graphicItem->data(DATA_COLOR_S).toInt(),
-                                                             graphicItem->data(DATA_COLOR_V).toInt()));
+                                QColor color = QColor::fromHsv(graphicItem->data(DATA_COLOR_H).toInt(),
+                                                               graphicItem->data(DATA_COLOR_S).toInt(),
+                                                               graphicItem->data(DATA_COLOR_V).toInt());
+                                color.setAlpha(ALPHA);
+                                pen.setColor(color);
                                 graphicItem->setZValue(graphicItem->data(DATA_Z_VALUE).toReal());
                                 graphicItem->setPen(pen);
                             }
@@ -1040,29 +1086,19 @@ void SKGTableWithGraph::redrawGraphDelayed()
 
 void SKGTableWithGraph::redrawText()
 {
-    if(!m_testVisible) return;
+    if(!m_textVisible) return;
     SKGTRACEIN(10, "SKGTableWithGraph::redrawText");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    //Set style sheet
-    QDir dirCss(KStandardDirs::locate("data", QString::fromLatin1("skrooge/css/")));
-    QFile file(dirCss.absoluteFilePath("skrooge_monthly-default.css"));
-    if(!file.open(QIODevice::ReadOnly | QIODevice::Text))
-        return;
-
-    QString style;
-    QTextStream in(&file);
-    while(!in.atEnd()) {
-        style += in.readLine();
-    }
-
     QString html = "<? xml version = \"1.0\" encoding=\"utf-8\"?>"
                    "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">"
                    "<html xmlns=\"http://www.w3.org/1999/xhtml\">"
                    "<head>"
                    "<meta http-equiv=\"content-type\" content=\"text/html;charset=utf-8\" />"
                    "<meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />"
-                   "<style type=\"text/css\">" % style % "</style>"
+                   "<style type=\"text/css\">"
+                   "body{background-color: #FFFFFF; font-size : small;} h1{text-decoration: underline; color: #FF3333;} h2{text-decoration: underline; color: #FF9933;} .table{border: thin solid #000000; border-collapse: collapse; background-color: #000000;} .tabletitle{background-color: #6495ed; color : #FFFF33; font-weight : bold; font-size : normal} .tabletotal{background-color: #D0E3FA;font-weight : bold;} tr{background-color: #FFFFFF;padding: 2px;} td{padding: 2px;}"
+                   "</style>"
                    "</head>"
                    "<body>"
                    "<table class=\"table\"><tr class=\"tabletitle\">";
@@ -1176,7 +1212,7 @@ void SKGTableWithGraph::redrawGraph()
                             if(valQ.type() == QVariant::Double) {
                                 double val = valQ.toDouble();
                                 if(inPositive || val >= 0) {
-                                    sumPositive += fabs(val);
+                                    sumPositive += qAbs(val);
                                 } else {
                                     sumNegative += val;
                                 }
@@ -1201,7 +1237,7 @@ void SKGTableWithGraph::redrawGraph()
                             if(valQ.type() == QVariant::Double) {
                                 double val = valQ.toDouble();
                                 if(inPositive || val >= 0) {
-                                    sumPositive += fabs(val);
+                                    sumPositive += qAbs(val);
                                 } else {
                                     sumNegative += val;
                                 }
@@ -1224,8 +1260,8 @@ void SKGTableWithGraph::redrawGraph()
                             if(valQ.type() == QVariant::Double) {
                                 double val = valQ.toDouble();
                                 if(inPositive) {
-                                    maxLimit = qMax(maxLimit, fabs(val));
-                                    minLimit = qMin(minLimit, fabs(val));
+                                    maxLimit = qMax(maxLimit, qAbs(val));
+                                    minLimit = qMin(minLimit, qAbs(val));
                                 } else {
                                     minLimit = qMin(minLimit, val);
                                     maxLimit = qMax(maxLimit, val);
@@ -1244,7 +1280,7 @@ void SKGTableWithGraph::redrawGraph()
                             QVariant valQ = tableItem->data(DATA_VALUE);
                             if(valQ.type() == QVariant::Double) {
                                 double val = valQ.toDouble();
-                                maxLimit = qMax(maxLimit, fabs(val));
+                                maxLimit = qMax(maxLimit, qAbs(val));
                             }
                         }
                     }
@@ -1275,9 +1311,9 @@ void SKGTableWithGraph::redrawGraph()
         int jstep = qMax(computeStepSize(nbColumns, 10), double(1.0));
         double ystep = computeStepSize(maxLimit - minLimit, 10);
         if(mode != BUBBLE && mode != PIE && mode != CONCENTRICPIE && ystep) {
-            double newMinLimit = ystep * round(minLimit / ystep);
+            double newMinLimit = ystep * qRound(minLimit / ystep);
             minLimit = (minLimit - newMinLimit < -EPSILON ? newMinLimit - ystep : newMinLimit);
-            double newMaxLimit = ystep * round(maxLimit / ystep);
+            double newMaxLimit = ystep * qRound(maxLimit / ystep);
             maxLimit = (maxLimit - newMaxLimit > EPSILON  ? newMaxLimit + ystep : newMaxLimit);
         }
 
@@ -1287,8 +1323,8 @@ void SKGTableWithGraph::redrawGraph()
                 margin = (maxLimit - minLimit) * 0.3;
 
                 if(!showOrigin) {
-                    if(minLimit > 0) yorigin = ystep * (round(minLimit / ystep));
-                    else if(maxLimit < 0) yorigin = ystep * (round(maxLimit / ystep));
+                    if(minLimit > 0) yorigin = ystep * (qRound(minLimit / ystep));
+                    else if(maxLimit < 0) yorigin = ystep * (qRound(maxLimit / ystep));
                 }
 
                 width = (maxLimit - minLimit) / (nbRealRows + 1);
@@ -1302,8 +1338,8 @@ void SKGTableWithGraph::redrawGraph()
                 margin = (maxLimit - minLimit) * 0.3;
 
                 if(!showOrigin) {
-                    if(minLimit > 0) yorigin = ystep * (round(minLimit / ystep));
-                    else if(maxLimit < 0) yorigin = ystep * (round(maxLimit / ystep));
+                    if(minLimit > 0) yorigin = ystep * (qRound(minLimit / ystep));
+                    else if(maxLimit < 0) yorigin = ystep * (qRound(maxLimit / ystep));
                 }
 
                 width = (maxLimit - minLimit) / ((nbRealRows + 1) * (nbColumns - 1));
@@ -1388,7 +1424,7 @@ void SKGTableWithGraph::redrawGraph()
                             double val = valQ.toDouble();
                             QString valstring = tableItem->text();
 
-                            if(inPositive)  val = fabs(val);
+                            if(inPositive)  val = qAbs(val);
 
                             int color_h;
                             int color_s;
@@ -1407,21 +1443,22 @@ void SKGTableWithGraph::redrawGraph()
                             if(x == crow && j == ccolumn) color = QApplication::palette().color(QPalette::Highlight);
                             else color = QColor::fromHsv(color_h, color_s, color_v);
 
+                            color.setAlpha(ALPHA);
                             QBrush brush(color);
 
                             QGraphicsItem* graphItem = NULL;
                             if(mode == STACK) {
                                 //STACK
                                 if(val >= 0) {
-                                    graphItem = m_scene->addRect(width * x, -yPlus - fabs(val), width, fabs(val), QPen(m_outlineColor), brush);
-                                    yPlus += fabs(val);
+                                    graphItem = m_scene->addRect(width * x, -yPlus - qAbs(val), width, qAbs(val), QPen(m_outlineColor), brush);
+                                    yPlus += qAbs(val);
                                     if(yPlus > ymax) ymax = yPlus;
                                 } else {
                                     graphItem = m_scene->addRect(width * x, -yMoins, width, -val, QPen(m_outlineColor), brush);
                                     yMoins += val;
                                     if(yMoins < ymin) ymin = yMoins;
                                 }
-                                graphItem->setZValue(5 + nbColumns - j);
+                                if(graphItem) graphItem->setZValue(5 + nbColumns - j);
                             } if(mode == STACKAREA) {
                                 //STACKAREA
                                 //Empty cells are ignored
@@ -1436,9 +1473,9 @@ void SKGTableWithGraph::redrawGraph()
                                         if(!val2string.isEmpty()) {
                                             double val2 = tableItem2->data(DATA_VALUE).toDouble();
                                             if(j == jprevious) val2 = 0;
-                                            if(inPositive) val2 = fabs(val2);
+                                            if(inPositive) val2 = qAbs(val2);
 
-                                            if(val > EPSILON || (fabs(val) <= EPSILON && val2 >= EPSILON)) {
+                                            if(val > EPSILON || (qAbs(val) <= EPSILON && val2 >= EPSILON)) {
                                                 double xp = width * (jprevious - 1) * (nbRealRows + 1) - (jprevious == j ? width / 20.0 : 0);
                                                 double xn = width * (j - 1) * (nbRealRows + 1);
                                                 double yp = (previousStackedPlus.contains(jprevious) ? previousStackedPlus[jprevious] : -val2);
@@ -1470,15 +1507,15 @@ void SKGTableWithGraph::redrawGraph()
                             } if(mode == STACKCOLUMNS) {
                                 //STACKCOLUMNS
                                 if(val >= 0) {
-                                    graphItem = m_scene->addRect(width * (j - 1) * (nbRealRows + 1), -previousStackedPlus[j] - fabs(val), width * (nbRealRows + 1), fabs(val), QPen(m_outlineColor), brush);
-                                    previousStackedPlus[j] += fabs(val);
+                                    graphItem = m_scene->addRect(width * (j - 1) * (nbRealRows + 1), -previousStackedPlus[j] - qAbs(val), width * (nbRealRows + 1), qAbs(val), QPen(m_outlineColor), brush);
+                                    previousStackedPlus[j] += qAbs(val);
                                     if(previousStackedPlus[j] > ymax) ymax = previousStackedPlus[j];
                                 } else {
                                     graphItem = m_scene->addRect(width * (j - 1) * (nbRealRows + 1), -previousStackedMoins[j], width * (nbRealRows + 1), -val, QPen(m_outlineColor), brush);
                                     previousStackedMoins[j] += val;
                                     if(previousStackedMoins[j] < ymin) ymin = previousStackedMoins[j];
                                 }
-                                graphItem->setZValue(5 + nbRows - x);
+                                if(graphItem) graphItem->setZValue(5 + nbRows - x);
                             } else if(mode == HISTOGRAM) {
                                 //HISTOGRAM
                                 if(j == 1) x0 = width * ((j - 1) * (nbRealRows + 1) + x) + width;
@@ -1514,7 +1551,7 @@ void SKGTableWithGraph::redrawGraph()
                                         QString val2string = tableItem->text();
                                         if(!val2string.isEmpty()) {
                                             double val2 = tableItem2->data(DATA_VALUE).toDouble();
-                                            if(inPositive) val2 = fabs(val2);
+                                            if(inPositive) val2 = qAbs(val2);
 
                                             graphItem = m_scene->addLine(width * (jprevious - 1) * (nbRealRows + 1) - (jprevious == j ? width / 20.0 : 0), -val2, width * (j - 1) * (nbRealRows + 1), -val, pen);
                                             if(val > ymax) ymax = val;
@@ -1528,14 +1565,14 @@ void SKGTableWithGraph::redrawGraph()
                                 ymin = 0;
                                 ymax = ystep * nbRealRows;
 
-                                radius =  sqrt(fabs(val) / maxLimit) * qMin(ystep , jstep * xstep);
+                                radius =  sqrt(qAbs(val) / maxLimit) * qMin(ystep , jstep * xstep);
                                 double xmin = width * (j - 1) * (nbRealRows + 1) - radius;
 
                                 graphItem = m_scene->addEllipse(xmin, -ystep * x - radius, 2 * radius, 2 * radius, QPen(m_outlineColor), brush);
-                                graphItem->setZValue(5 + 5 *(maxLimit - fabs(val)) / maxLimit);
+                                if(graphItem) graphItem->setZValue(5 + 5 *(maxLimit - qAbs(val)) / maxLimit);
                             }  else if(mode == PIE || mode == CONCENTRICPIE) {
                                 //PIE
-                                val = fabs(val);
+                                val = qAbs(val);
 
                                 //Compute absolute sum of the column
                                 double previousSum = 0;
@@ -1543,7 +1580,7 @@ void SKGTableWithGraph::redrawGraph()
                                     if(!m_sumRows[x2+1]) {
                                         QTableWidgetItem* tableItem = ui.kTable->item(x2, j);
                                         if(tableItem) {
-                                            double absVal = fabs(tableItem->data(DATA_VALUE).toDouble());
+                                            double absVal = qAbs(tableItem->data(DATA_VALUE).toDouble());
                                             if(x2 < xx) previousSum += absVal;
                                         }
                                     }
@@ -1642,7 +1679,7 @@ void SKGTableWithGraph::redrawGraph()
                 //Compute scale text
                 KLocale* locale = KGlobal::locale();
                 if(mode != BUBBLE) {
-                    QGraphicsTextItem* t = m_scene->addText(locale->formatMoney(-qMax(fabs(ymax), fabs(ymin)) , m_primaryUnit.Symbol, m_primaryUnit.NbDecimal));
+                    QGraphicsTextItem* t = m_scene->addText(locale->formatMoney(-qMax(qAbs(ymax), qAbs(ymin)) , m_primaryUnit.Symbol, m_primaryUnit.NbDecimal));
                     QRectF rect = t->boundingRect();
                     scaleText = 0.8 * qMin(marginLeft / rect.width(), qMin(marginLeft / rect.height(), ystep / rect.height()));
                     m_scene->removeItem(t);
@@ -1756,7 +1793,7 @@ void SKGTableWithGraph::redrawGraph()
             QTableWidgetItem* tableItem = ui.kTable->item(0, averageCol);
             if(tableItem) {
                 double y = tableItem->data(DATA_VALUE).toDouble();
-                if(inPositive) y = fabs(y);
+                if(inPositive) y = qAbs(y);
                 KLocale* locale = KGlobal::locale();
                 QGraphicsLineItem* item = m_scene->addLine(0, -y, maxX, -y);
                 dotPen.setColor(m_averageColor);
@@ -1785,7 +1822,7 @@ void SKGTableWithGraph::redrawGraph()
                 QTableWidgetItem* tableItem = ui.kTable->item(0, minCol);
                 if(tableItem) {
                     double y = tableItem->data(DATA_VALUE).toDouble();
-                    if(inPositive) y = fabs(y);
+                    if(inPositive) y = qAbs(y);
                     KLocale* locale = KGlobal::locale();
                     QGraphicsLineItem* item = m_scene->addLine(0, -y, maxX, -y);
                     dotPen.setColor(m_minColor);
@@ -1811,7 +1848,7 @@ void SKGTableWithGraph::redrawGraph()
                 QTableWidgetItem* tableItem = ui.kTable->item(0, minCol + 1);
                 if(tableItem) {
                     double y = tableItem->data(DATA_VALUE).toDouble();
-                    if(inPositive) y = fabs(y);
+                    if(inPositive) y = qAbs(y);
                     KLocale* locale = KGlobal::locale();
                     QGraphicsLineItem* item = m_scene->addLine(0, -y, maxX, -y);
                     dotPen.setColor(m_maxColor);
@@ -1969,6 +2006,7 @@ void SKGTableWithGraph::addLegend(const QPointF& iPosition, double iSize, double
                             color1 = QColor::fromHsv(graphicItem->data(DATA_COLOR_H).toInt(),
                                                      graphicItem->data(DATA_COLOR_S).toInt(),
                                                      graphicItem->data(DATA_COLOR_V).toInt());
+                            color1.setAlpha(ALPHA);
                         }
                     }
                     QColor color2;
@@ -1980,6 +2018,7 @@ void SKGTableWithGraph::addLegend(const QPointF& iPosition, double iSize, double
                             color2 = QColor::fromHsv(graphicItem->data(DATA_COLOR_H).toInt(),
                                                      graphicItem->data(DATA_COLOR_S).toInt(),
                                                      graphicItem->data(DATA_COLOR_V).toInt());
+                            color2.setAlpha(ALPHA);
                         }
                     }
 
@@ -2008,8 +2047,10 @@ void SKGTableWithGraph::addLegend(const QPointF& iPosition, double iSize, double
                     } else {
                         item = m_scene->addRect(currentXPos, currentYPos , iSize, iSize, QPen(m_outlineColor), QBrush(grandient));
                     }
-                    item->setFlag(QGraphicsItem::ItemIsSelectable, false);
-                    item->setToolTip(title);
+                    if(item) {
+                        item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                        item->setToolTip(title);
+                    }
 
                     //Draw text
                     QGraphicsTextItem* textItem = m_scene->addText(title);
@@ -2050,61 +2091,63 @@ void SKGTableWithGraph::addArrow(const QPointF& iPeak, double iSize, double iArr
 QGraphicsItem* SKGTableWithGraph::drawPoint(qreal iX, qreal iY, qreal iRadius, int iMode, const QBrush& iBrush)
 {
     QGraphicsItem* graphItem = NULL;
-    switch(iMode % 8) {
-    case 0: {
-        graphItem = m_scene->addEllipse(iX, iY - iRadius, 2 * iRadius, 2 * iRadius, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 1: {
-        graphItem = m_scene->addRect(iX, iY - iRadius, 2 * iRadius, 2 * iRadius, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 2: {
-        QPolygonF polygon;
-        polygon << QPointF(iX, iY - iRadius) << QPointF(iX + 2 * iRadius, iY + iRadius)
-                << QPointF(iX + 2 * iRadius, iY - iRadius) << QPointF(iX, iY + iRadius);
-        graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 3: {
-        QPolygonF polygon;
-        polygon << QPointF(iX + iRadius, iY + iRadius) << QPointF(iX + 2 * iRadius, iY - iRadius)
-                << QPointF(iX , iY - iRadius) << QPointF(iX + iRadius, iY + iRadius);
-        graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 4: {
-        QPolygonF polygon;
-        polygon << QPointF(iX , iY) << QPointF(iX + iRadius, iY + iRadius)
-                << QPointF(iX + 2 * iRadius, iY) << QPointF(iX + iRadius, iY - iRadius) << QPointF(iX, iY);
-        graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 5: {
-        QPolygonF polygon;
-        polygon << QPointF(iX, iY - iRadius) << QPointF(iX + 2 * iRadius, iY - iRadius)
-                << QPointF(iX, iY + iRadius) << QPointF(iX + 2 * iRadius, iY + iRadius);
-        graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 6: {
-        QPolygonF polygon;
-        polygon << QPointF(iX + iRadius, iY - iRadius) << QPointF(iX + 2 * iRadius, iY + iRadius)
-                << QPointF(iX , iY + iRadius) << QPointF(iX + iRadius, iY - iRadius);
-        graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
-        break;
-    }
-    case 7: {
-        QPainterPath path;
-        path.addEllipse(iX, iY - iRadius, 2 * iRadius, 2 * iRadius);
-        path.closeSubpath();
+    if(m_scene) {
+        switch(iMode % 8) {
+        case 0: {
+            graphItem = m_scene->addEllipse(iX, iY - iRadius, 2 * iRadius, 2 * iRadius, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 1: {
+            graphItem = m_scene->addRect(iX, iY - iRadius, 2 * iRadius, 2 * iRadius, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 2: {
+            QPolygonF polygon;
+            polygon << QPointF(iX, iY - iRadius) << QPointF(iX + 2 * iRadius, iY + iRadius)
+                    << QPointF(iX + 2 * iRadius, iY - iRadius) << QPointF(iX, iY + iRadius);
+            graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 3: {
+            QPolygonF polygon;
+            polygon << QPointF(iX + iRadius, iY + iRadius) << QPointF(iX + 2 * iRadius, iY - iRadius)
+                    << QPointF(iX , iY - iRadius) << QPointF(iX + iRadius, iY + iRadius);
+            graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 4: {
+            QPolygonF polygon;
+            polygon << QPointF(iX , iY) << QPointF(iX + iRadius, iY + iRadius)
+                    << QPointF(iX + 2 * iRadius, iY) << QPointF(iX + iRadius, iY - iRadius) << QPointF(iX, iY);
+            graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 5: {
+            QPolygonF polygon;
+            polygon << QPointF(iX, iY - iRadius) << QPointF(iX + 2 * iRadius, iY - iRadius)
+                    << QPointF(iX, iY + iRadius) << QPointF(iX + 2 * iRadius, iY + iRadius);
+            graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 6: {
+            QPolygonF polygon;
+            polygon << QPointF(iX + iRadius, iY - iRadius) << QPointF(iX + 2 * iRadius, iY + iRadius)
+                    << QPointF(iX , iY + iRadius) << QPointF(iX + iRadius, iY - iRadius);
+            graphItem = m_scene->addPolygon(polygon, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        case 7: {
+            QPainterPath path;
+            path.addEllipse(iX, iY - iRadius, 2 * iRadius, 2 * iRadius);
+            path.closeSubpath();
 
-        QPainterPath path2;
-        path2.addEllipse(iX + iRadius / 2.0, iY - iRadius / 2.0, iRadius, iRadius);
-        path -= path2;
-        graphItem = m_scene->addPath(path, QPen(m_outlineColor), iBrush);
-        break;
-    }
+            QPainterPath path2;
+            path2.addEllipse(iX + iRadius / 2.0, iY - iRadius / 2.0, iRadius, iRadius);
+            path -= path2;
+            graphItem = m_scene->addPath(path, QPen(m_outlineColor), iBrush);
+            break;
+        }
+        }
     }
 
     return graphItem;
@@ -2166,7 +2209,7 @@ void SKGTableWithGraph::onExport()
 
 void SKGTableWithGraph::setGraphType(SKGTableWithGraph::GraphType iType) const
 {
-    m_displayMode->setCurrentIndex(m_displayMode->findData(iType));
+    if(m_displayMode) m_displayMode->setCurrentIndex(m_displayMode->findData(iType));
 }
 
 SKGTableWithGraph::GraphType SKGTableWithGraph::getGraphType() const
