@@ -129,10 +129,22 @@ public Q_SLOTS:
 
     /**
      * Returns the table.
-     * @return vertical table
+     * @return table
      */
     virtual QTableWidget* table() const;
 
+    /**
+     * Returns the graph.
+     * @return graph
+     */
+    virtual SKGGraphicsView* graph() const;
+
+    /**
+     * Returns the text report.
+     * @return text report
+     */
+    virtual SKGWebView* textReport() const ;
+
     /**
      * Set Data
      * @param iData the data
@@ -292,6 +304,24 @@ public Q_SLOTS:
      */
     virtual void redrawGraphDelayed();
 
+    /**
+     * To know if the table is visible
+     * @return the visibility
+     */
+    virtual bool isTableVisible() const;
+
+    /**
+     * To know if the graph is visible
+     * @return the visibility
+     */
+    virtual bool isGraphVisible() const;
+
+    /**
+     * To know if the text report is visible
+     * @return the visibility
+     */
+    virtual bool isTextReportVisible() const;
+
 Q_SIGNALS:
     /**
      * Selection changed
@@ -348,7 +378,7 @@ private:
     bool m_legendVisible;
     bool m_graphVisible;
     bool m_tableVisible;
-    bool m_testVisible;
+    bool m_textVisible;
     bool m_zeroVisible;
 
     KMenu* m_mainMenu;
@@ -377,6 +407,7 @@ private:
     QColor m_averageColor;
     QColor m_tendencyColor;
     QColor m_outlineColor;
+    QBrush m_NegativeColor;
 
     SKGComboBox* m_displayMode;
 };
