@@ -33,6 +33,7 @@
 #include <QtGui/QWidget>
 #include <QWebView>
 
+#include <qmath.h>
 #include "math.h"
 
 SKGTabPage::SKGTabPage(SKGDocument* iDocument)
@@ -56,34 +57,6 @@ bool SKGTabPage::close()
     return QWidget::close();
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGTabPage::getSelectedObjects()
-{
-    SKGObjectBase::SKGListSKGObjectBase selection;
-    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(zoomableWidget());
-    if(treeView) selection = treeView->getSelectedObjects();
-
-    return selection;
-}
-
-SKGObjectBase SKGTabPage::getFirstSelectedObject()
-{
-    SKGObjectBase first;
-    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(zoomableWidget());
-    if(treeView) first = treeView->getFirstSelectedObject();
-
-    return first;
-}
-
-int SKGTabPage::getNbSelectedObjects()
-{
-    int output = 0;
-    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(zoomableWidget());
-    if(treeView) output = treeView->getNbSelectedObjects();
-    else output = getSelectedObjects().count();
-
-    return output;
-}
-
 void SKGTabPage::setBookmarkID(const QString& iId)
 {
     m_bookmarkID = iId;
@@ -232,16 +205,18 @@ bool SKGTabPage::isEditor()
 
 void SKGTabPage::activateEditor() {}
 
-QWidget* SKGTabPage::mainWidget() const
-{
-    return (QWidget*) this;
-}
-
 QWidget* SKGTabPage::zoomableWidget() const
 {
     return mainWidget();
 }
 
+QList< QWidget* > SKGTabPage::printableWidgets() const
+{
+    QList< QWidget* > output;
+    output.push_back(mainWidget());
+    return output;
+}
+
 bool SKGTabPage::isZoomable() const
 {
     return (zoomableWidget() != NULL);
@@ -255,7 +230,7 @@ void SKGTabPage::setZoomPosition(int iValue)
     else {
         QWebView* webView = qobject_cast<QWebView*>(widget);
         if(webView) {
-            webView->setZoomFactor(pow(10, ((qreal) iValue) / 30.0));
+            webView->setZoomFactor(qPow(10, ((qreal) iValue) / 30.0));
         } else if(widget) {
             QFont font = widget->font();
             font.setPointSize(qMax(1, m_fontOriginalPointSize + iValue));
@@ -271,10 +246,21 @@ int SKGTabPage::zoomPosition() const
     if(treeView) return treeView->zoomPosition();
     else {
         QWebView* webView = qobject_cast<QWebView*>(widget);
-        if(webView) return round(30.0 * log10(webView->zoomFactor()));
+        if(webView) return qRound(30.0 * log10(webView->zoomFactor()));
         else if(widget) return widget->font().pointSize() - m_fontOriginalPointSize;
     }
     return 0;
 }
 
+SKGTabPage* SKGTabPage::parentTabPage(QWidget* iWidget)
+{
+    SKGTabPage* output = qobject_cast< SKGTabPage* >(iWidget);
+    if(!output && iWidget) {
+        QWidget* parent = iWidget->parentWidget();
+        if(parent)  output = SKGTabPage::parentTabPage(parent);
+    }
+
+    return output;
+}
+
 #include "skgtabpage.moc"
