@@ -28,6 +28,7 @@
 #include "skgtransactionmng.h"
 #include "skgobjectbase.h"
 #include "skgmainpanel.h"
+#include "skgtableview.h"
 
 #include <ksavefile.h>
 #include <kicon.h>
@@ -48,14 +49,22 @@
 #include <QDesktopServices>
 #include <QTimer>
 #include <QSvgGenerator>
+#include <QClipboard>
 #include <qtextcodec.h>
+#include <QPushButton>
+#include <kstandardaction.h>
 
 SKGTreeView::SKGTreeView(QWidget *parent)
     : QTreeView(parent),
       m_autoResize(true), m_actAutoResize(NULL),
-      m_document(NULL), m_textResizable(true)
+      m_document(NULL), m_textResizable(true),
+      m_model(NULL), m_proxyModel(NULL)
 {
-    //Delayed resize
+    //Initialize
+    setTextElideMode(Qt::ElideMiddle);
+    setAutoExpandDelay(300);
+    setAnimated(true);
+
     m_timerDelayedResize.setSingleShot(true);
     connect(&m_timerDelayedResize, SIGNAL(timeout()), this, SLOT(resizeColumnsToContents()), Qt::QueuedConnection);
 
@@ -72,18 +81,34 @@ SKGTreeView::SKGTreeView(QWidget *parent)
 
     setContextMenuPolicy(Qt::ActionsContextMenu);
     connect(hori, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(showHeaderMenu(const QPoint&)));
-    connect(hori, SIGNAL(sortIndicatorChanged(int , Qt::SortOrder)), this, SLOT(onSortChanged()));
+    connect(hori, SIGNAL(sortIndicatorChanged(int , Qt::SortOrder)), this, SLOT(onSortChanged(int , Qt::SortOrder)));
+
+    //
+    KAction* actCopy = KStandardAction::copy(this, SLOT(copy()), NULL);
+    if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_copy", actCopy);
+    insertGlobalAction("edit_copy");
+
+    m_actExpandAll = new KAction(KIcon("format-indent-more"), i18nc("Noun, user action", "Expand all"), this);
+    connect(m_actExpandAll, SIGNAL(triggered(bool)), this, SLOT(expandAll()));
+    if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_expandall", m_actExpandAll);
+    insertGlobalAction("edit_expandall");
+
+    m_actCollapseAll = new KAction(KIcon("format-indent-less"), i18nc("Noun, user action", "Collapse all"), this);
+    connect(m_actCollapseAll, SIGNAL(triggered(bool)), this, SLOT(collapseAll()));
+    if(SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_collapseal", m_actCollapseAll);
+    insertGlobalAction("edit_collapseal");
 
     //Headers
     hori->setMovable(true);
-
-    header()->setResizeMode(QHeaderView::Fixed);
+    hori->setResizeMode(QHeaderView::Fixed);
     setWordWrap(false);
 
-    connect(header(), SIGNAL(sectionMoved(int, int, int)), this, SLOT(moveSection()), Qt::QueuedConnection);
+    connect(header(), SIGNAL(sectionMoved(int, int, int)), this, SLOT(setupHeaderMenu()), Qt::QueuedConnection);
 
     connect(this, SIGNAL(collapsed(QModelIndex)), this, SLOT(onCollapse(QModelIndex)), Qt::QueuedConnection);
     connect(this, SIGNAL(expanded(QModelIndex)), this, SLOT(onExpand(QModelIndex)), Qt::QueuedConnection);
+    connect(this, SIGNAL(clicked(const QModelIndex &)), this, SLOT(onClick(const QModelIndex &)), Qt::QueuedConnection);
+
 
     QAbstractScrollArea *scrollArea = qobject_cast<QAbstractScrollArea*>(this);
     if(scrollArea) {
@@ -104,6 +129,10 @@ SKGTreeView::~SKGTreeView()
 {
     m_document = NULL;
     m_headerMenu = NULL;
+    m_proxyModel = NULL;
+    m_model = NULL;
+    m_actExpandAll = NULL;
+    m_actCollapseAll = NULL;
 }
 
 bool SKGTreeView::isAutoResized()
@@ -118,17 +147,13 @@ QString SKGTreeView::getState()
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
 
-
-    SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-    if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-
     QHeaderView* hHeader = header();
-    if(hHeader && model) {
+    if(hHeader && m_model) {
         if(isSortingEnabled()) {
             root.setAttribute("sortOrder", SKGServices::intToString((int) hHeader->sortIndicatorOrder()));
-            root.setAttribute("sortColumn", model->getAttribute(hHeader->sortIndicatorSection()));
+            root.setAttribute("sortColumn", m_model->getAttribute(hHeader->sortIndicatorSection()));
         }
+        root.setAttribute("groupBy", m_groupby);
 
         //Memorize order
         int nb = hHeader->count();
@@ -139,7 +164,7 @@ QString SKGTreeView::getState()
             for(int i = 0; i < nb; ++i) {
                 int idx = hHeader->logicalIndex(i);
                 if(i) columns += ';';
-                columns += model->getAttribute(idx);
+                columns += m_model->getAttribute(idx);
 
                 if(i) columnsSize += ';';
                 columnsSize += SKGServices::intToString(hHeader->sectionSize(idx));
@@ -171,16 +196,13 @@ void SKGTreeView::setState(const QString& iState)
         viewState = m_document->getParameter(m_parameterName);
     }
 
-    SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-    if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-
     Qt::SortOrder qtsortorder = Qt::AscendingOrder;
     if(doc.setContent(viewState)) {
         QDomElement root = doc.documentElement();
 
         QString sortOrder = root.attribute("sortOrder");
         QString sortColumn = root.attribute("sortColumn");
+        m_groupby = root.attribute("groupBy");
         QString columns = root.attribute("columns");
         QString columnsSize = root.attribute("columnsSize");
         QString columnsVisibility = root.attribute("columnsVisibility");
@@ -205,43 +227,59 @@ void SKGTreeView::setState(const QString& iState)
                         listAtt[i] = listAtt[i] % '|' % sizes[i];
                     }
                 }
-
             }
         }
-        if(model) {
-            model->setSupportedAttributes(listAtt);
-            model->refresh();
+        if(m_model) {
+            m_model->setSupportedAttributes(listAtt);
         }
 
         //Set autoResize
         if(!columnsAutoResize.isEmpty()) {
             m_autoResize = (columnsAutoResize == "Y");
             header()->setResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
+            if(!m_autoResize)  m_timerDelayedResize.stop();
         }
 
         //Set sort
-        if(model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
+        if(m_model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
             int index = SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
-            if(index == -1) index = model->getIndexAttribute(sortColumn);
+            if(index == -1) index = m_model->getIndexAttribute(sortColumn);
             if(index == -1) index = 0;
             qtsortorder = (Qt::SortOrder) SKGServices::stringToInt(sortOrder);
             this->sortByColumn(index, qtsortorder);
         }
 
+        if(m_model) {
+            QString att = m_groupby;
+            if(att == "#") att = sortColumn;
+            m_model->setGroupBy(att);
+            m_model->dataModified();
+
+            bool treeMode = !m_model->getParentChildAttribute().isEmpty();
+            setRootIsDecorated(treeMode && m_groupby.isEmpty());
+            if(m_actExpandAll) m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+            if(m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+        }
+
         //Set alternatingRowColors
         if(!alternatingRowColors.isEmpty()) setAlternatingRowColors(alternatingRowColors == "Y");
         if(!zoomPosition.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPosition));
     } else {
-        if(model) {
-            model->setSupportedAttributes(QStringList());
-            model->refresh();
+        if(m_model) {
+            m_model->setSupportedAttributes(QStringList());
+            m_groupby = "";
+            m_model->setGroupBy(m_groupby);
+            m_model->dataModified();
+
+            bool treeMode = !m_model->getParentChildAttribute().isEmpty();
+            setRootIsDecorated(treeMode && m_groupby.isEmpty());
+            if(m_actExpandAll) m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+            if(m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
         }
 
         this->sortByColumn(0, qtsortorder);
     }
 
-    setupHeaderMenu();
-
     if(qtsortorder == Qt::AscendingOrder) scrollToBottom();
     else scrollToTop();
 }
@@ -252,7 +290,7 @@ void SKGTreeView::insertGlobalAction(const QString& iRegisteredAction)
         QAction* sep = new QAction(this);
         sep->setSeparator(true);
         this->insertAction(0, sep);
-    } else {
+    } else if(SKGMainPanel::getMainPanel()) {
         KAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(iRegisteredAction);
         this->insertAction(0, act);
     }
@@ -272,6 +310,11 @@ void SKGTreeView::resizeColumnsToContents()
         resizeColumnToContents(i);
 }
 
+void SKGTreeView::showHeaderMenu()
+{
+    showHeaderMenu(header()->mapFromGlobal(QCursor::pos()));
+}
+
 void SKGTreeView::showHeaderMenu(const QPoint& pos)
 {
     if(m_headerMenu) m_headerMenu->popup(header()->mapToGlobal(pos));
@@ -283,29 +326,56 @@ void SKGTreeView::setDefaultSaveParameters(SKGDocument* iDocument, const QString
     m_parameterName = iParameterName;
 }
 
-void SKGTreeView::moveSection()
-{
-    setupHeaderMenu(false);
-}
-
-void SKGTreeView::setupHeaderMenu(bool iRefreshColumnSize)
+void SKGTreeView::setupHeaderMenu()
 {
     SKGTRACEIN(10, "SKGTreeView::setupHeaderMenu");
-    SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-    if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
+    if(m_model && m_model->isRefreshBlocked()) return;
 
-    if(model && model->isRefreshBlocked()) return;
+    bool iRefreshColumnSize = !(sender() == header());
+
+    setCornerWidget(NULL);
+    if(m_model && m_headerMenu) {
+        //Corner button on tables to show the contextual menu
+        QPushButton* btn = new QPushButton(this);
+        btn->setIcon(KIcon("configure"));
+        connect(btn, SIGNAL(clicked()), this, SLOT(showHeaderMenu()));
+        setCornerWidget(btn);
 
-    if(m_headerMenu) {
         m_headerMenu->clear();
 
         //Processing
         QMenu* columns = m_headerMenu->addMenu(i18nc("Noun, Menu name", "Columns"));
 
+        //Get current groupby column
+        QMenu* groupbymenu = NULL;
+        QActionGroup* groupby = NULL;
+        if(!m_model->getWhereClause().contains("ORDER BY")) {
+            groupbymenu = m_headerMenu->addMenu(i18nc("Noun, Menu name", "Group by"));
+            groupby = new QActionGroup(groupbymenu);
+            QAction* actNone = groupbymenu->addAction(i18nc("Noun, grouping option", "None"));
+            if(actNone) {
+                actNone->setIcon(KIcon("dialog-cancel"));
+                actNone->setCheckable(true);
+                actNone->setChecked(m_groupby == "");
+                actNone->setData("");
+                groupby->addAction(actNone);
+            }
+            if(m_proxyModel) {
+                QAction* actSort = groupbymenu->addAction(i18nc("Noun, grouping option", "Sorted column"));
+                if(actSort) {
+                    actSort->setIcon(KIcon("view-sort-ascending"));
+                    actSort->setCheckable(true);
+                    actSort->setChecked(m_groupby == "#");
+                    actSort->setData("#");
+                    groupby->addAction(actSort);
+                }
+            }
+            groupbymenu->addSeparator();
+        }
+
         // Set right click menu
-        if(model) {
-            QList<SKGDocument::SKGModelTemplate> schemas = model->getSchemas();
+        if(m_model) {
+            QList<SKGDocument::SKGModelTemplate> schemas = m_model->getSchemas();
             int nbSchemas = schemas.count();
             if(nbSchemas) {
                 QMenu* viewAppearanceMenu = columns->addMenu(KIcon("view-file-columns"), i18nc("Noun, user action", "View appearance"));
@@ -343,12 +413,13 @@ void SKGTreeView::setupHeaderMenu(bool iRefreshColumnSize)
 
         columns->addSeparator();
 
-        if(model) {
+        if(m_model) {
+            //Build menus for columns
             QHeaderView* hHeader = header();
             int nbcol = hHeader->count();
             for(int i = 0; i < nbcol; ++i) {
                 int idx = hHeader->logicalIndex(i);
-                QString col = model->headerData(idx, Qt::Horizontal, Qt::UserRole).toString();
+                QString col = m_model->headerData(idx, Qt::Horizontal, Qt::UserRole).toString();
                 QStringList values = col.split('|');
 
                 if(iRefreshColumnSize) {
@@ -358,17 +429,43 @@ void SKGTreeView::setupHeaderMenu(bool iRefreshColumnSize)
                         if(s > 0) hHeader->resizeSection(idx, s);
                     }
                 }
+
+                //Column menu
                 QAction* act = columns->addAction(values.at(0));
                 if(act) {
                     act->setCheckable(true);
                     act->setChecked(!hHeader->isSectionHidden(idx));
-                    act->setIcon(model->headerData(idx, Qt::Horizontal, Qt::DecorationRole).value<QIcon>());
+                    act->setIcon(m_model->headerData(idx, Qt::Horizontal, Qt::DecorationRole).value<QIcon>());
                     act->setData(idx);
+                    act->setEnabled(i > 0);
 
                     connect(act, SIGNAL(triggered(bool)), this, SLOT(showHideColumn()));
+
+                    //Group by menu
+                    QString att = m_model->getAttribute(idx);
+                    if(act->isChecked() && groupbymenu && groupby) {
+                        QAction* act2 = groupbymenu->addAction(values.at(0));
+                        if(act2) {
+                            act2->setCheckable(true);
+                            act2->setChecked(att == m_groupby);
+                            act2->setIcon(act->icon());
+                            act2->setData(att);
+                            groupby->addAction(act2);
+                        }
+                    }
+                }
+            }
+
+            //Span first column
+            if(m_proxyModel) {
+                bool treeMode = !m_model->getParentChildAttribute().isEmpty();
+                int grouped_rows_count = m_proxyModel->rowCount(rootIndex());
+                for(int row = 0 ; row < grouped_rows_count ; row++) {
+                    setFirstColumnSpanned(row, rootIndex(), treeMode || !m_groupby.isEmpty());
                 }
             }
         }
+        if(groupby) connect(groupby, SIGNAL(triggered(QAction*)), this, SLOT(groupByChanged(QAction*)));
         m_headerMenu->addSeparator();
 
         QAction* actExport = m_headerMenu->addAction(KIcon("document-export"), i18nc("Noun, user action", "Export..."));
@@ -387,7 +484,23 @@ void SKGTreeView::setSelectionModel(QItemSelectionModel * selectionModel)
 
 void SKGTreeView::onSelectionChanged()
 {
-    m_timerSelectionChanged.start(300);
+    SKGObjectBase::SKGListSKGObjectBase selection;
+    QItemSelectionModel *selModel = selectionModel();
+    if(selModel) {
+        if(m_model) {
+            QModelIndexList indexes = selModel->selectedRows();
+            foreach(const QModelIndex & index, indexes) {
+                QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
+                SKGObjectBase obj = m_model->getObject(idxs);
+                selection.push_back(obj);
+            }
+        }
+    }
+
+    if(selection != m_lastSelection) {
+        m_lastSelection = selection;
+        m_timerSelectionChanged.start(300);
+    }
 }
 
 void SKGTreeView::saveDefaultClicked()
@@ -404,17 +517,55 @@ void SKGTreeView::switchAutoResize()
     m_autoResize = m_actAutoResize->isChecked();
     header()->setResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
     if(m_autoResize) resizeColumnsToContentsDelayed();
+    else m_timerDelayedResize.stop();
+}
+
+void SKGTreeView::groupByChanged(QAction* iAction)
+{
+    if(m_model && m_model->isRefreshBlocked()) return;
+
+    if(iAction && m_model) {
+        m_groupby = iAction->data().toString();;
+        QString att = m_groupby;
+        if(att == "#" && m_proxyModel) att = m_model->getAttribute(m_proxyModel->sortColumn());
+        m_model->setGroupBy(att);
+        m_model->refresh();
+
+        bool treeMode = !m_model->getParentChildAttribute().isEmpty();
+        setRootIsDecorated(treeMode && m_groupby.isEmpty());
+        if(m_actExpandAll) m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+        if(m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+    }
+}
+
+void SKGTreeView::onSortChanged(int iIndex, Qt::SortOrder iOrder)
+{
+    Q_UNUSED(iOrder);
+    if(m_groupby == "#" && m_model) {
+        m_model->setGroupBy(m_model->getAttribute(iIndex));
+        m_model->refresh();
+    }
+
+    m_timerScrollSelection.start(300);
 }
 
 void SKGTreeView::showHideColumn()
 {
     QAction* sender = static_cast<QAction*>(this->sender());
-    if(sender) {
+    if(sender && m_model) {
         QHeaderView* hHeader = header();
 
         int idx = sender->data().toInt();
-        hHeader->setSectionHidden(idx, !hHeader->isSectionHidden(idx));
-        resizeColumnToContents(idx);
+        bool hidden = !hHeader->isSectionHidden(idx);
+        hHeader->setSectionHidden(idx, hidden);
+
+        m_model->setSupportedAttributes(getCurrentSchema());
+        if(!hidden) resizeColumnToContents(idx);
+
+        //If the group by attibute is hidden the the group is removed
+        if(hidden && m_model->getAttribute(idx) == m_model->getGroupBy()) m_model->setGroupBy("");
+
+        m_model->dataModified();
     }
 }
 
@@ -435,22 +586,36 @@ void SKGTreeView::changeSchema()
     QAction* sender = static_cast<QAction*>(this->sender());
     if(sender)  list = SKGServices::splitCSVLine(sender->data().toString(), ';');
 
-    SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-    if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-    if(model) {
+    if(m_model) {
         //Reset column oder
         resetColumnsOrder();
 
-        model->setSupportedAttributes(list);
-        model->refresh();
+        m_model->setSupportedAttributes(list);
+        m_model->dataModified();
         header()->setSortIndicator(0, Qt::AscendingOrder);
-
-        setupHeaderMenu();
     }
-
 }
 
+QStringList SKGTreeView::getCurrentSchema() const
+{
+    QStringList list;
+    QHeaderView* hHeader = header();
+    if(hHeader && m_model) {
+        int nb = hHeader->count();
+        if(nb) {
+            QString att;
+            for(int i = 0; i < nb; ++i) {
+                int idx = hHeader->logicalIndex(i);
+                att = m_model->getAttribute(idx);
+                att += QString("|") % (hHeader->isSectionHidden(idx) ? "N" : "Y");
+                att += QString("|") % SKGServices::intToString(hHeader->sectionSize(idx));
+
+                list.push_back(att);
+            }
+        }
+    }
+    return list;
+}
 void SKGTreeView::setAlternatingRowColors(bool enable)
 {
     QTreeView::setAlternatingRowColors(enable);
@@ -458,51 +623,17 @@ void SKGTreeView::setAlternatingRowColors(bool enable)
 
 SKGObjectBase SKGTreeView::getFirstSelectedObject()
 {
-    SKGObjectBase output;
-    QItemSelectionModel *selModel = selectionModel();
-    if(selModel) {
-        QModelIndexList indexes = selModel->selectedRows();
-        if(indexes.count()) {
-            SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-            QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-            if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-
-            if(model) {
-                QModelIndex index = indexes.at(0);
-                QModelIndex idxs = (proxyModel ? proxyModel->mapToSource(index) : index);
-                output = model->getObject(idxs);
-            }
-        }
-    }
-    return output;
+    return m_lastSelection.at(0);
 }
 
 SKGObjectBase::SKGListSKGObjectBase SKGTreeView::getSelectedObjects()
 {
-    SKGObjectBase::SKGListSKGObjectBase selection;
-    QItemSelectionModel *selModel = selectionModel();
-    if(selModel) {
-        SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-        if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-
-        if(model) {
-            QModelIndexList indexes = selModel->selectedRows();
-            foreach(const QModelIndex & index, indexes) {
-                QModelIndex idxs = (proxyModel ? proxyModel->mapToSource(index) : index);
-                SKGObjectBase obj = model->getObject(idxs);
-                selection.push_back(obj);
-            }
-        }
-    }
-
-    return selection;
+    return m_lastSelection;
 }
 
 int SKGTreeView::getNbSelectedObjects()
 {
-    QItemSelectionModel *selModel = selectionModel();
-    return (selModel ? selModel->selectedRows().count() : 0);
+    return m_lastSelection.count();
 }
 
 void SKGTreeView::saveSelection()
@@ -523,7 +654,7 @@ void SKGTreeView::saveSelection()
     SKGTRACEL(10) << m_selection.count() << " objects saved" << endl;
 }
 
-void SKGTreeView::selectObject(const QString& iUniqueID)
+void SKGTreeView::selectObject(const QString & iUniqueID)
 {
     SKGTRACEIN(10, "SKGTreeView::selectObject");
     QStringList tmp;
@@ -531,7 +662,7 @@ void SKGTreeView::selectObject(const QString& iUniqueID)
     selectObjects(tmp, true);
 }
 
-void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirstOne)
+void SKGTreeView::selectObjects(const QStringList & iUniqueIDs, bool iFocusOnFirstOne)
 {
     SKGTRACEIN(10, "SKGTreeView::selectObjects");
     int nbset = 0;
@@ -541,19 +672,15 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
 
         selModel->clearSelection();
 
-        SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-        if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-
-        if(model) {
+        if(m_model) {
             //Get all indexes
             QList<QModelIndex> items;
             items.push_back(QModelIndex());
             for(int i = 0; i < items.count(); ++i) {  //Dynamic size because the list is modified
                 QModelIndex mi = items.at(i);
-                int nbRows = model->rowCount(mi);
+                int nbRows = m_model->rowCount(mi);
                 for(int j = 0; j < nbRows; ++j) {
-                    items.push_back(model->index(j, 0, mi));
+                    items.push_back(m_model->index(j, 0, mi));
                 }
             }
             items.removeAt(0);
@@ -565,9 +692,9 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
                 foreach(const QString & exp, m_expandedNodes) {
                     for(int i = 0; i < nbRows; ++i) {
                         QModelIndex index = items.at(i);
-                        SKGObjectBase obj = model->getObject(index);
+                        SKGObjectBase obj = m_model->getObject(index);
                         if(obj.getUniqueID() == exp) {
-                            QModelIndex idxs = (proxyModel ? proxyModel->mapFromSource(index) : index);
+                            QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
                             setExpanded(idxs, true);
                             break;
                         }
@@ -580,9 +707,9 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
                 foreach(const QString & sel, iUniqueIDs) {
                     for(int i = 0; i < nbRows; ++i) {
                         QModelIndex index = items.at(i);
-                        SKGObjectBase obj = model->getObject(index);
+                        SKGObjectBase obj = m_model->getObject(index);
                         if(obj.getUniqueID() == sel) {
-                            QModelIndex idxs = (proxyModel ? proxyModel->mapFromSource(index) : index);
+                            QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
                             selModel->select(idxs, QItemSelectionModel::Select | QItemSelectionModel::Rows);
                             ++nbset;
                             if(iFocusOnFirstOne && !focusDone) {
@@ -600,6 +727,8 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
 
     SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << endl;
     SKGTRACEL(10) << nbset << " objects selected" << endl;
+
+    onSelectionChanged();
 }
 
 void SKGTreeView::resetSelection()
@@ -609,21 +738,12 @@ void SKGTreeView::resetSelection()
     selectObjects(m_selection);
 }
 
-void SKGTreeView::onSortChanged()
-{
-    m_timerScrollSelection.start(300);
-}
-
 void SKGTreeView::scroolOnSelection()
 {
     SKGObjectBase::SKGListSKGObjectBase selection;
     QItemSelectionModel *selModel = selectionModel();
     if(selModel) {
-        SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(this->model());
-        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (this->model());
-        if(proxyModel) model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
-
-        if(model) {
+        if(m_model) {
             QModelIndexList indexes = selModel->selectedRows();
             if(indexes.count()) scrollTo(indexes.at(0));
         }
@@ -632,35 +752,88 @@ void SKGTreeView::scroolOnSelection()
 
 void SKGTreeView::onExpand(const QModelIndex & index)
 {
+    SKGTRACEIN(10, "SKGTreeView::onExpand");
     if(index.isValid()) {
-        SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(this->model());
-        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (this->model());
-        if(proxyModel) model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
-        if(model) {
-            QModelIndex idxs = (proxyModel ? proxyModel->mapToSource(index) : index);
+        if(m_model) {
+            QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
 
-            SKGObjectBase obj = model->getObject(idxs);
+            SKGObjectBase obj = m_model->getObject(idxs);
             QString id = obj.getUniqueID();
             m_expandedNodes.push_back(id);
         }
     }
+
+    if(m_autoResize) resizeColumnsToContentsDelayed();
+}
+
+void SKGTreeView::expandAll()
+{
+    SKGTRACEIN(10, "SKGTreeView::onExpandAll");
+    QTreeView::expandAll();
+
+    if(m_autoResize) resizeColumnsToContentsDelayed();
 }
 
 void SKGTreeView::onCollapse(const QModelIndex & index)
 {
+    SKGTRACEIN(10, "SKGTreeView::onCollapse");
     if(index.isValid()) {
-        SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(this->model());
-        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (this->model());
-        if(proxyModel) model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
-        if(model) {
-            QModelIndex idxs = (proxyModel ? proxyModel->mapToSource(index) : index);
+        if(m_model) {
+            QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
 
-            SKGObjectBase obj = model->getObject(idxs);
+            SKGObjectBase obj = m_model->getObject(idxs);
 
             QString id = obj.getUniqueID();
             m_expandedNodes.removeOne(id);
         }
     }
+
+    if(m_autoResize) resizeColumnsToContentsDelayed();
+}
+
+void SKGTreeView::onClick(const QModelIndex& index)
+{
+    SKGTRACEIN(10, "SKGTreeView::onCollapse");
+    if(index.isValid()) {
+        if(this->isExpanded(index)) this->collapse(index);
+        else this->expand(index);
+    }
+}
+
+void SKGTreeView::copy()
+{
+    QItemSelectionModel * selection = selectionModel();
+    if(selection) {
+        QModelIndexList indexes = selection->selectedIndexes();
+
+        if(indexes.size() < 1) return;
+
+        qSort(indexes.begin(), indexes.end());
+
+        // You need a pair of indexes to find the row changes
+        QModelIndex previous = indexes.first();
+        indexes.removeFirst();
+        QString header_text;
+        bool header_done = false;
+        QString selected_text;
+        foreach(const QModelIndex & current, indexes) {
+            selected_text.append(model()->data(previous).toString());
+            if(!header_done) header_text.append(model()->headerData(previous.column(), Qt::Horizontal).toString());
+            if(current.row() != previous.row()) {
+                selected_text.append(QLatin1Char('\n'));
+                header_done = true;
+            } else {
+                selected_text.append(QLatin1Char(';'));
+                if(!header_done) header_text.append(QLatin1Char(';'));
+            }
+            previous = current;
+        }
+
+        // add last element
+        selected_text.append(model()->data(previous).toString());
+        selected_text.append(QLatin1Char('\n'));
+        QApplication::clipboard()->setText(header_text + '\n' + selected_text);
+    }
 }
 
 void SKGTreeView::setZoomPosition(int iZoomPosition)
@@ -673,7 +846,7 @@ void SKGTreeView::setZoomPosition(int iZoomPosition)
 
         this->setFont(font);
         this->setIconSize(QSize(iconSize, iconSize));
-        this->header()->setIconSize(QSize(iconSize, iconSize));
+        header()->setIconSize(QSize(iconSize, iconSize));
 
         if(m_autoResize) resizeColumnsToContentsDelayed();
 
@@ -703,7 +876,16 @@ bool SKGTreeView::eventFilter(QObject * object, QEvent * event)
         e->setAccepted(true);
         return true;
     }
-
+    if(object == this) {
+        QKeyEvent* kevent = dynamic_cast<QKeyEvent*>(event);
+        if(kevent) {
+            if(kevent->matches(QKeySequence::Copy)) {
+                copy();
+                if(event) event->accept();
+                return true; //stop the process
+            }
+        }
+    }
     return QTreeView::eventFilter(object, event);
 }
 
@@ -732,25 +914,22 @@ SKGStringListList SKGTreeView::getTable()
     SKGStringListList table;
 
     //Get header names
-    SKGObjectModelBase* model = (SKGObjectModelBase*) this->model();
-    QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> (model);
-    if(proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
-    if(model) {
-        int nb = model->columnCount();
+    if(m_model) {
+        int nb = m_model->columnCount();
         QStringList cols;
-        for(int i = 0; i < nb; i++) {
-            cols.append(model->headerData(i, Qt::Horizontal, Qt::UserRole).toString().split('|').at(0));
+        for(int i = 0; i < nb; ++i) {
+            cols.append(m_model->headerData(i, Qt::Horizontal, Qt::UserRole).toString().split('|').at(0));
         }
         table.append(cols);
 
         //Get content
-        int nb2 = model->rowCount();
-        for(int i = 0; i < nb2; i++) {
+        int nb2 = m_model->rowCount();
+        for(int i = 0; i < nb2; ++i) {
             QStringList row;
             for(int j = 0; j < nb; j++) {
                 //We have to check the type for 214849
-                SKGServices::AttributeType type = model->getAttributeType(j);
-                QString display = model->data(model->index(i, j), type == SKGServices::FLOAT ?  Qt::DisplayRole : Qt::UserRole).toString();
+                SKGServices::AttributeType type = m_model->getAttributeType(j);
+                QString display = m_model->data(m_model->index(i, j), type == SKGServices::FLOAT ?  Qt::DisplayRole : Qt::UserRole).toString();
                 row.append(display);
             }
             table.append(row);
@@ -840,4 +1019,19 @@ void SKGTreeView::onExport()
     QDesktopServices::openUrl(QUrl(fileName));
 }
 
+void SKGTreeView::setModel(QAbstractItemModel* iModel)
+{
+    if(iModel != this->model()) {
+        m_model = qobject_cast<SKGObjectModelBase *> (iModel);
+        m_proxyModel = qobject_cast<QSortFilterProxyModel *> (iModel);
+        if(m_proxyModel) m_model = (SKGObjectModelBase*) m_proxyModel->sourceModel();
+
+        if(m_model) {
+            connect(m_model, SIGNAL(afterReset()), this, SLOT(setupHeaderMenu()));
+            connect(m_model, SIGNAL(afterReset()), this, SLOT(onSelectionChanged()));
+        }
+        QTreeView::setModel(iModel);
+    }
+}
+
 #include "skgtreeview.moc"
