@@ -32,6 +32,8 @@
 #include <kmenu.h>
 #include "skgmainpanel.h"
 
+class SKGObjectModelBase;
+class QSortFilterProxyModel;
 class SKGDocument;
 class QTimer;
 
@@ -129,6 +131,14 @@ public:
      */
     virtual void insertGlobalAction(const QString& iRegisteredAction = "");
 
+    /**
+     * @brief Set model
+     *
+     * @param iModel the model
+     * @return void
+     **/
+    virtual void setModel(QAbstractItemModel* iModel);
+
 Q_SIGNALS:
     /**
      * Emitted when the empty area
@@ -234,6 +244,11 @@ public Q_SLOTS:
      */
     virtual void onSelectionChanged();
 
+    /**
+     * Expand all and resize columns if needed
+     */
+    virtual void expandAll();
+
 protected:
     /**
       * Event filtering
@@ -245,29 +260,36 @@ protected:
 
 private Q_SLOTS:
     void onExport();
-    void moveSection();
-    void setupHeaderMenu(bool iRefreshColumnSize = true);
+    void setupHeaderMenu();
+    void showHeaderMenu();
     void showHeaderMenu(const QPoint& pos);
     void showHideColumn();
     void switchAutoResize();
     void changeSchema();
     void saveDefaultClicked();
+    void groupByChanged(QAction*);
 
-    void onSortChanged();
+    void onSortChanged(int , Qt::SortOrder);
 
     void onExpand(const QModelIndex & index);
     void onCollapse(const QModelIndex & index);
+    void onClick(const QModelIndex & index);
+    void copy();
 
 private:
     Q_DISABLE_COPY(SKGTreeView);
+    QStringList getCurrentSchema() const;
 
     KMenu* m_headerMenu;
     bool m_autoResize;
     QAction* m_actAutoResize;
+    KAction* m_actExpandAll;
+    KAction* m_actCollapseAll;
     SKGDocument* m_document;
     QString m_parameterName;
     QStringList m_selection;
     QStringList m_expandedNodes;
+    QString m_groupby;
 
     QTimer m_timerDelayedResize;
     QTimer m_timerSelectionChanged;
@@ -275,6 +297,11 @@ private:
     bool m_textResizable;
     int m_fontOriginalPointSize;
     int m_iconOriginalSize;
+
+    SKGObjectModelBase* m_model;
+    QSortFilterProxyModel* m_proxyModel;
+
+    SKGObjectBase::SKGListSKGObjectBase m_lastSelection;
 };
 
 #endif // SKGTREEVIEW_H
