@@ -100,9 +100,11 @@ int SKGUniqueApplication::newInstance()
     }
 
     if(m_splash) {
+        SKGTRACEIN(1, "SKGUniqueApplication::newInstance-finish splash screen");
+
         m_splash->clearMessage();
-        m_splash->finish(m_widget);
-        m_timer.start(5000);
+        //m_splash->finish(m_widget); wait 2s
+        m_timer.start(300);
     }
 
     return 0;
