@@ -20,6 +20,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgwidget.h"
+#include "skgtreeview.h"
 #include "skgtraces.h"
 
 #include <QtGui/QWidget>
@@ -61,5 +62,37 @@ QWidget* SKGWidget::getDragWidget()
     if(!w) w = this;
     return w;
 }
+SKGObjectBase::SKGListSKGObjectBase SKGWidget::getSelectedObjects()
+{
+    SKGObjectBase::SKGListSKGObjectBase selection;
+    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
+    if(treeView) selection = treeView->getSelectedObjects();
+
+    return selection;
+}
+
+SKGObjectBase SKGWidget::getFirstSelectedObject()
+{
+    SKGObjectBase first;
+    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
+    if(treeView) first = treeView->getFirstSelectedObject();
+
+    return first;
+}
+
+int SKGWidget::getNbSelectedObjects()
+{
+    int output = 0;
+    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
+    if(treeView) output = treeView->getNbSelectedObjects();
+    else output = getSelectedObjects().count();
+
+    return output;
+}
+
+QWidget* SKGWidget::mainWidget() const
+{
+    return (QWidget*) this;
+}
 
 #include "skgwidget.moc"
