@@ -42,6 +42,7 @@
 #include <QDBusConnection>
 #include <QDBusMetaType>
 #include <QApplication>
+#include <qtconcurrentmap.h>
 
 SKGError SKGDocument::m_lastCallbackError;
 int SKGDocument::m_databaseUniqueIdentifier = 0;
@@ -49,7 +50,7 @@ int SKGDocument::m_databaseUniqueIdentifier = 0;
 SKGDocument::SKGDocument()
     : QObject(), m_lastSavedTransaction(0), m_progressFunction(NULL), m_progressData(NULL),
       m_currentFileName(""), m_currentDatabase(NULL),  m_inundoRedoTransaction(0), m_currentTransaction(0),
-      m_inProgress(false), m_directAccessDb(false)
+      m_inProgress(false), m_directAccessDb(false), m_modeReadOnly(false)
 {
     SKGTRACEIN(10, "SKGDocument::SKGDocument");
 
@@ -73,7 +74,6 @@ SKGDocument::SKGDocument()
     setBackupParameters("", ".old");
 }
 
-
 SKGDocument::~SKGDocument()
 {
     SKGTRACEIN(10, "SKGDocument::~SKGDocument");
@@ -131,12 +131,12 @@ SKGError SKGDocument::stepForward(int iPosition)
             ++posIt;
         }
 
-        int posPourcent = (int) min;
+        int posPercent = (int) min;
 
         //Call the call back
         if(emitevent) {
             m_inProgress = true;
-            if((*(int (*)(int, void*)) m_progressFunction)(posPourcent, m_progressData) != 0) {
+            if((*(int (*)(int, void*)) m_progressFunction)(posPercent, m_progressData) != 0) {
                 err.setReturnCode(ERR_ABORT);
                 err.setMessage(i18nc("User interrupted something that Skrooge was performing", "The current operation has been interrupted"));
 
@@ -149,7 +149,7 @@ SKGError SKGDocument::stepForward(int iPosition)
     return err;
 }
 
-SKGError SKGDocument::beginTransaction(const QString & iName, int iNbStep, const QDateTime& iDate)
+SKGError SKGDocument::beginTransaction(const QString & iName, int iNbStep, const QDateTime& iDate, bool iRefreshViews)
 {
     SKGError err;
     SKGTRACEINRC(5, "SKGDocument::beginTransaction", err);
@@ -160,11 +160,15 @@ SKGError SKGDocument::beginTransaction(const QString & iName, int iNbStep, const
         err = executeSqliteOrder("BEGIN;");
         if(!err) {
             //Create undo redo transaction
-            err = executeSqliteOrder("insert into doctransaction "
-                                     "(d_date, t_name, i_parent) values "
+            err = executeSqliteOrder(QString("insert into doctransaction (d_date, t_name, i_parent") %
+                                     (!iRefreshViews ? ", t_refreshviews" : "") %
+                                     ") values "
                                      "('" % SKGServices::timeToString(iDate) %
                                      "','" % SKGServices::stringToSqlString(iName) %
-                                     "', " % SKGServices::intToString(getTransactionToProcess(SKGDocument::UNDO)) % ");");
+                                     "', " % SKGServices::intToString(getTransactionToProcess(SKGDocument::UNDO)) %
+                                     (!iRefreshViews ? ",'N'" : "") %
+                                     ");");
+            addValueInCache("SKG_REFRESH_VIEW", (iRefreshViews ? "Y" : "N"));
             m_currentTransaction = getTransactionToProcess(SKGDocument::UNDO);
         }
     } else {
@@ -288,7 +292,7 @@ SKGError SKGDocument::endTransaction(bool succeedded)
 
             }
 
-            if(!succeedded || !!err) {
+            if(!succeedded || err) {
                 //Rollback the transaction
                 SKGError err2 = executeSqliteOrder("ROLLBACK;");
                 if(!err2) {
@@ -296,7 +300,7 @@ SKGError SKGDocument::endTransaction(bool succeedded)
                     err2 = executeSqliteOrder("delete from doctransaction where id=" % currentTransactionString);
                 }
 
-                if(!!err2) err.addError(err2.getReturnCode(), err2.getMessage());
+                if(err2) err.addError(err2.getReturnCode(), err2.getMessage());
             } else {
                 //For better performance, events are submitted only for the first recursive undo
                 if(m_inundoRedoTransaction <= 1) {
@@ -310,25 +314,29 @@ SKGError SKGDocument::endTransaction(bool succeedded)
                     Q_EMIT tableModified("doctransactionitem", getCurrentTransaction());
 
                     //WARNING: list is modified during treatement
-                    for(int i = 0; i < listModifiedTables.count(); ++i) {
+                    for(int i = 0; !err && i < listModifiedTables.count(); ++i) {
                         QString table = listModifiedTables[i];
-                        if(!tablesRefreshed.contains(table)) {
-                            Q_EMIT tableModified(table, 0);
-                            tablesRefreshed.push_back(table);
-                        }
-
-                        QStringList toAdd = getImpactedTables(table);
+                        QStringList toAdd = getImpactedViews(table);
                         int nbToAdd = toAdd.count();
-                        for(int j = 0; j < nbToAdd; ++j) {
-                            if(!listModifiedTables.contains(toAdd.at(j)))
-                                listModifiedTables.push_back(toAdd.at(j));
+                        for(int j = 0; !err &&  j < nbToAdd; ++j) {
+                            QString toAddTable = toAdd.at(j);
+                            if(!listModifiedTables.contains(toAddTable)) {
+                                //Compute materialized view of modified table
+                                if(getCachedValue("SKG_REFRESH_VIEW") == "Y") err = computeMaterializedViews(toAddTable);
+                                listModifiedTables.push_back(toAddTable);
+                            }
                         }
                     }
 
+                    //Emit events
+                    for(int i = tablesRefreshed.count(); i < listModifiedTables.count(); ++i) {
+                        Q_EMIT tableModified(listModifiedTables[i], 0);
+                    }
+
                     Q_EMIT transactionSuccessfullyEnded(getCurrentTransaction());
 
                     //Remove temporary transaction if needed
-                    err = executeSqliteOrder("delete from doctransaction where id=" % currentTransactionString % " and t_name='#INTERNAL#';");
+                    if(!err) err = executeSqliteOrder("delete from doctransaction where id=" % currentTransactionString % " and t_name='#INTERNAL#';");
                 }
             }
 
@@ -367,6 +375,45 @@ SKGError SKGDocument::removeAllTransactions()
     return err;
 }
 
+SKGError SKGDocument::computeMaterializedViews(const QString& iTable)
+{
+    SKGError err;
+    SKGTRACEINRC(5, "SKGDocument::computeMaterializedViews", err);
+
+    //Compute additional where clause
+    QStringList tables;
+    if(m_MaterializedViews.contains(iTable)) {
+        tables = m_MaterializedViews[iTable];
+    } else {
+        QString wc;
+        if(!iTable.isEmpty()) {
+            QString t = iTable;
+            if(t.startsWith(QLatin1String("v_"))) t.replace(0, 2, "vm_");
+            wc = " AND name='" % t % '\'';
+        }
+
+        //Get list of materialized table
+        err = getDistinctValues("sqlite_master", "name", "type='table' AND name LIKE 'vm_%' " % wc, tables);
+        m_MaterializedViews[iTable] = tables;
+    }
+
+    //Refresh tables
+    int nb = tables.count();
+    for(int i = 0; !err && i < nb; ++i) {
+        QString table = tables.at(i);
+        QString view = table;
+        view.replace(0, 3, "v_");
+
+        //Remove previous table
+        err = executeSqliteOrder("DROP TABLE IF EXISTS " % table);
+
+        //Recreate table
+        if(!err) err = executeSqliteOrder("CREATE TABLE " % table % " AS SELECT * FROM " % view);
+    }
+
+    return err;
+}
+
 SKGError SKGDocument::sendMessage(const QString& iMessage, bool iPopup)
 {
     SKGError err;
@@ -434,9 +481,9 @@ SKGError SKGDocument::getModifications(int iIdTransaction, SKGObjectModification
     return err;
 }
 
-QStringList SKGDocument::getImpactedTables(const QString& iTable)
+QStringList SKGDocument::getImpactedViews(const QString& iTable)
 {
-    SKGTRACEIN(10, "SKGDocument::getImpactedTables");
+    SKGTRACEIN(10, "SKGDocument::getImpactedViews");
     if(m_ImpactedViews.count() == 0) {
         //Get list of tables and views
         QStringList tables;
@@ -460,6 +507,7 @@ QStringList SKGDocument::getImpactedTables(const QString& iTable)
             int nbWords = words.count();
             for(int j = 0; j < nbWords; ++j) {
                 QString word = words.at(j);
+                if(word.startsWith(QLatin1String("vm_"))) word.replace(0, 3, "v_");
                 if(word != name && tables.contains(word, Qt::CaseInsensitive)) {
                     QStringList l = m_ImpactedViews[word];
                     if(!l.contains(name)) l.push_back(name);
@@ -591,7 +639,8 @@ SKGError SKGDocument::undoRedoTransaction(const UndoRedoMode& iMode)
             QString name;
             bool saveStep = false;
             QDateTime date;
-            int id = getTransactionToProcess(iMode, &name, &saveStep, &date);
+            bool refreshViews;
+            int id = getTransactionToProcess(iMode, &name, &saveStep, &date, &refreshViews);
             if(id == 0) {
                 //No transaction found ==> generate an error
                 err = SKGError(ERR_INVALIDARG, "No transaction found. Undo / Redo impossible.");
@@ -607,7 +656,7 @@ SKGError SKGDocument::undoRedoTransaction(const UndoRedoMode& iMode)
                           listSqlOrder);
                 if(!err) {
                     int nb = listSqlOrder.count();
-                    err = SKGDocument::beginTransaction(name, nb + 3, date);
+                    err = SKGDocument::beginTransaction(name, nb + 3, date, refreshViews);
                     if(!err) {
                         ++m_inundoRedoTransaction; //Because we will be in a undo/redo transaction
                         //Normal the first element is ignored because it is the header
@@ -695,14 +744,14 @@ int SKGDocument::getNbTransaction(const UndoRedoMode& iMode) const
     return output;
 }
 
-int SKGDocument::getTransactionToProcess(const UndoRedoMode& iMode, QString* oName, bool* oSaveStep, QDateTime* oDate) const
+int SKGDocument::getTransactionToProcess(const UndoRedoMode& iMode, QString* oName, bool* oSaveStep, QDateTime* oDate, bool* oRefreshViews) const
 {
     SKGTRACEIN(10, "SKGDocument::getTransactionToProcess");
     //initialisation
     int output = 0;
     if(oName) *oName = "";
     if(getDatabase()) {
-        QString sqlorder = "select A.id , A.t_name, A.t_savestep, A.d_date from doctransaction A where "
+        QString sqlorder = "select A.id , A.t_name, A.t_savestep, A.d_date, A.t_refreshviews from doctransaction A where "
                            "NOT EXISTS(select 1 from doctransaction B where B.i_parent=A.id) "
                            "and A.t_mode='";
         sqlorder += (iMode == SKGDocument::UNDO || iMode == SKGDocument::UNDOLASTSAVE ? "U" : "R");
@@ -713,6 +762,7 @@ int SKGDocument::getTransactionToProcess(const UndoRedoMode& iMode, QString* oNa
             if(oName != NULL) *oName = query.value(1).toString();
             if(oSaveStep != NULL) *oSaveStep = (query.value(2).toString() == "Y");
             if(oDate != NULL) *oDate = SKGServices::stringToTime(query.value(3).toString());
+            if(oRefreshViews != NULL) *oRefreshViews = (query.value(4).toString() == "Y");
         }
     }
     return output;
@@ -775,6 +825,9 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
     if(!err) {
         if(!name.isEmpty()) {
             //File exist
+            QFileInfo fi(name);
+            m_modeReadOnly = !fi.permission(QFile::WriteUser);
+
             //Temporary file
             m_temporaryFile = SKGDocument::getTemporaryFile(name);
             if(!restoreTmpFile) {
@@ -801,7 +854,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
                 QFile::remove(temporaryFile2);
 
                 //To avoid deletion of temporary file during next try
-                if(!!err) m_temporaryFile = "";
+                if(err) m_temporaryFile = "";
                 //BUG 249955: Check if password protected ^^^
             }
 
@@ -845,6 +898,8 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
                      ;
         if(!err) err = executeSqliteOrders(optimization);
 
+        if(err) err.setReturnCode(ERR_ENCRYPTION);
+
         if(!m_directAccessDb) {
             //Create parameter and undo redo table
             /**
@@ -874,7 +929,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
                              "f_sortorder FLOAT,"
                              "t_autostart VARCHAR(1) DEFAULT 'N' CHECK (t_autostart IN ('Y', 'N')),"
                              "t_data TEXT,"
-                             "r_node_id INT CONSTRAINT fk_id REFERENCES node(id) ON DELETE CASCADE)"
+                             "rd_node_id INT CONSTRAINT fk_id REFERENCES node(id) ON DELETE CASCADE)"
 
                              // ==================================================================
                              //Table doctransaction
@@ -884,6 +939,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
                              "t_mode VARCHAR(1) DEFAULT 'U' CHECK (t_mode IN ('U', 'R')),"
                              "d_date DATE NOT NULL,"
                              "t_savestep VARCHAR(1) DEFAULT 'N' CHECK (t_savestep IN ('Y', 'N')),"
+                             "t_refreshviews VARCHAR(1) DEFAULT 'Y' CHECK (t_refreshviews IN ('Y', 'N')),"
                              "i_parent INTEGER)"
 
                              // ==================================================================
@@ -912,6 +968,13 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
     if(!err) {
         bool mig = false;
         err = migrate(mig);
+
+        //To authorize manual repair of document in case of error during migration
+        //the error is not caught if traces are activated
+        if(SKGTraces::SKGLevelTrace) {
+            err = sendMessage(i18nc("Popup message", "Warning: The migration failed but the document has been loaded without error because debug mode is activated"));
+        }
+
         if(!err && mig && !name.isEmpty()) err = sendMessage(i18nc("The document has been upgraded to the latest Skrooge version format", "The document has been migrated"));
     }
 
@@ -924,7 +987,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
     //Creation undo/redo triggers
     if(!err) err = createUndoRedoTemporaryTriggers();
 
-    if(!!err && !name.isEmpty()) {
+    if(err && !name.isEmpty()) {
         close();
     } else {
         //Send event
@@ -935,6 +998,11 @@ SKGError SKGDocument::load(const QString & name, const QString & password, bool
     return err;
 }
 
+bool SKGDocument::isReadOnly() const
+{
+    return m_modeReadOnly;
+}
+
 bool SKGDocument::isFileModified() const
 {
     //Get last executed transaction
@@ -1045,7 +1113,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                         if(!err) err = executeSqliteOrder("PRAGMA synchronous = OFF");
 
                         //Restore backup in case of failure
-                        if(!!err) {
+                        if(err) {
                             QFile::remove(name);
                             QFile(backupFileName).rename(name);
                         }
@@ -1057,6 +1125,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                         //The document is not modified
                         QString oldtemporaryFile = m_temporaryFile;
                         m_currentFileName = name;
+                        m_modeReadOnly = false;
                         m_temporaryFile = getTemporaryFile(m_currentFileName);
                         if(oldtemporaryFile != m_temporaryFile) QFile(oldtemporaryFile).rename(m_temporaryFile);
                         m_lastSavedTransaction = getTransactionToProcess(SKGDocument::UNDO);
@@ -1109,6 +1178,10 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
     /**
     * This constant is used to initialized the data model (trigger creation)
     */
+    QString rd_node_id = "r_node_id";
+    double v = SKGServices::stringToDouble(getParameter("SKG_DB_VERSION"));
+    if(v == 0 || v >= 1.4) rd_node_id = "rd_node_id";
+
     QStringList InitialDataModelTrigger;
     InitialDataModelTrigger
     DELETECASCADEPARAMETER("parameters")
@@ -1118,33 +1191,27 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
             << "DROP TRIGGER IF EXISTS cpt_node_fullname3"
             /*<< "CREATE TRIGGER cpt_node_fullname1 " //This trigger must be the first
             "AFTER UPDATE OF t_fullname ON node BEGIN "
-            "UPDATE node SET t_name=t_name WHERE r_node_id=new.id;"
+            "UPDATE node SET t_name=t_name WHERE rd_node_id=new.id;"
             "END"*/
 
             << "DROP TRIGGER IF EXISTS cpt_node_fullname1"
             << "CREATE TRIGGER cpt_node_fullname1 "
             "AFTER INSERT ON node BEGIN "
             "UPDATE node SET t_fullname="
-            "CASE WHEN r_node_id IS NULL OR r_node_id=0 THEN new.t_name ELSE (SELECT c.t_fullname from node c where c.id=new.r_node_id)||'" % OBJECTSEPARATOR % "'||new.t_name END "
+            "CASE WHEN new.rd_node_id IS NULL OR new." % rd_node_id % "='' OR new." % rd_node_id % "=0 THEN new.t_name ELSE (SELECT c.t_fullname from node c where c.id=new." % rd_node_id % ")||'" % OBJECTSEPARATOR % "'||new.t_name END "
             "WHERE id=new.id;"
             "END"
 
             << "DROP TRIGGER IF EXISTS cpt_node_fullname2"
             << "CREATE TRIGGER cpt_node_fullname2 "
-            "AFTER UPDATE OF t_name ON node BEGIN "
+            "AFTER UPDATE OF t_name, " % rd_node_id % " ON node BEGIN "
             "UPDATE node SET t_fullname="
-            "CASE WHEN r_node_id IS NULL OR r_node_id='' THEN new.t_name ELSE (SELECT c.t_fullname from node c where c.id=new.r_node_id)||'" % OBJECTSEPARATOR % "'||new.t_name END "
+            "CASE WHEN new." % rd_node_id % " IS NULL OR new." % rd_node_id % "='' OR new." % rd_node_id % "=0 THEN new.t_name ELSE (SELECT c.t_fullname from node c where c.id=new." % rd_node_id % ")||'" % OBJECTSEPARATOR % "'||new.t_name END "
             "WHERE id=new.id;"
-            "UPDATE node SET t_name=t_name WHERE r_node_id=new.id;"
+            "UPDATE node SET t_name=t_name WHERE " % rd_node_id % "=new.id;"
             "END"
 
-            //-- Cascading delete - WARNING rewriten to support recursive mode
             << "DROP TRIGGER IF EXISTS fkdc_node_parent_id_node_id"
-            << "CREATE TRIGGER fkdc_node_parent_id_node_id "
-            "BEFORE DELETE ON node "
-            "FOR EACH ROW BEGIN "
-            "    DELETE FROM node WHERE node.t_fullname LIKE OLD.t_fullname||'" % OBJECTSEPARATOR % "%'; "
-            "END"
             ;
 
     /**
@@ -1155,7 +1222,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
                           << "CREATE UNIQUE INDEX uidx_parameters_uuid_parent_name ON parameters (t_uuid_parent, t_name)"
 
                           << "DROP INDEX IF EXISTS uidx_node_parent_id_name"
-                          << "CREATE UNIQUE INDEX uidx_node_parent_id_name ON node(t_name,r_node_id)"
+                          << "CREATE UNIQUE INDEX uidx_node_parent_id_name ON node(t_name," % rd_node_id % ")"
 
                           << "DROP INDEX IF EXISTS uidx_node_fullname"
                           << "CREATE UNIQUE INDEX uidx_node_fullname ON node(t_fullname)"
@@ -1232,7 +1299,8 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers()
                     QStringList sqlOrders;
                     sqlOrders FOREIGNCONSTRAINTUPDATE(tab2, att2, table, att);
                     err = executeSqliteOrders(sqlOrders);
-                    if(!err) err = executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % ')');
+                    //The following sql order error is not caught because this repair order is not mandatory
+                    executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % ')');
                 }
             }
         }
@@ -1261,10 +1329,10 @@ SKGError SKGDocument::migrate(bool& oMigrationDone)
 
     if(!err && version.isEmpty()) {
         //First creation
-        SKGTRACEL(10) << "Migration from 0 to 1.0" << endl;
+        SKGTRACEL(10) << "Migration from 0 to 1.4" << endl;
 
         //Set new version
-        version = "1.1";
+        version = "1.4";
         if(!err) err = setParameter("SKG_DB_VERSION", version);
 
         //Set sqlite creation version
@@ -1412,17 +1480,83 @@ SKGError SKGDocument::migrate(bool& oMigrationDone)
         if(!err) err = SKGDocument::setParameter("SKG_DB_VERSION", version);
         oMigrationDone = true;
     }
+    if(!err && version == "1.1") {
+        //Migration from version 1.0 to 1.1
+        SKGTRACEL(10) << "Migration from 1.1 to 1.2" << endl;
+
+        QStringList sql;
+        sql << "ALTER TABLE doctransaction ADD COLUMN t_refreshviews VARCHAR(1) DEFAULT 'Y' CHECK (t_refreshviews IN ('Y', 'N'))"
+            << "UPDATE doctransaction set t_refreshviews='Y'"
+            ;
+
+        err = executeSqliteOrders(sql);
+
+        //Set new version
+        version = "1.2";
+        if(!err) err = SKGDocument::setParameter("SKG_DB_VERSION", version);
+        oMigrationDone = true;
+    }
+    if(!err && version == "1.2") {
+        //Migration from version 1.0 to 1.1
+        SKGTRACEL(10) << "Migration from 1.2 to 1.3" << endl;
+
+        err = SKGDocument::refreshViewsIndexesAndTriggers();
+
+        QStringList sql;
+        sql << "DELETE FROM node WHERE (r_node_id IS NULL OR r_node_id='') AND EXISTS (SELECT 1 FROM node n WHERE n.t_name=node.t_name AND r_node_id=0)"
+            << "UPDATE node SET t_name=t_name"
+            ;
+        if(!err) err = executeSqliteOrders(sql);
+
+        //Set new version
+        version = "1.3";
+        if(!err) err = SKGDocument::setParameter("SKG_DB_VERSION", version);
+        oMigrationDone = true;
+    }
+    if(!err && version == "1.3") {
+        //Migration from version 1.0 to 1.1
+        SKGTRACEL(10) << "Migration from 1.3 to 1.4" << endl;
+
+        QStringList sql;
+        sql   << "CREATE TABLE node2 ("
+              "id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,"
+              "t_name TEXT NOT NULL DEFAULT '' CHECK (t_name NOT LIKE '%" % OBJECTSEPARATOR % "%'),"
+              "t_fullname TEXT,"
+              "t_icon TEXT DEFAULT '',"
+              "f_sortorder FLOAT,"
+              "t_autostart VARCHAR(1) DEFAULT 'N' CHECK (t_autostart IN ('Y', 'N')),"
+              "t_data TEXT,"
+              "rd_node_id INT CONSTRAINT fk_id REFERENCES node(id) ON DELETE CASCADE)"
+
+              << "INSERT INTO node2 (id, t_name, t_fullname, t_icon, f_sortorder, t_autostart, t_data, rd_node_id) "
+              "SELECT id, t_name, t_fullname, t_icon, f_sortorder, t_autostart, t_data, r_node_id FROM node"
+
+              << "DROP TABLE IF EXISTS node"
+              << "ALTER TABLE node2 RENAME TO node"
+              ;
+
+        err = executeSqliteOrders(sql);
+
+        //Set new version
+        version = "1.4";
+        if(!err) err = SKGDocument::setParameter("SKG_DB_VERSION", version);
+        oMigrationDone = true;
+    }
+
 
     //Refresh views
     if(!err)  err = refreshViewsIndexesAndTriggers();
 
+    //Refresh materialized views
+    if(!err) err = computeMaterializedViews();
+
     //Set sqlite last version
     SKGStringListList listTmp;
     if(!err) err = executeSelectSqliteOrder("select sqlite_version()", listTmp);
     if(!err && listTmp.count() == 2) err = setParameter("SKG_SQLITE_LAST_VERSION", listTmp.at(1).at(0));
 
 
-    if(!!err) err.addError(ERR_FAIL, i18nc("Error message: Could not perform database migration", "Database migration from version %1 to version %2 failed", initialversion, version));
+    if(err) err.addError(ERR_FAIL, i18nc("Error message: Could not perform database migration", "Database migration from version %1 to version %2 failed", initialversion, version));
 
     //close temporary transaction
     if(!err) err = endTransaction(true);
@@ -1446,7 +1580,7 @@ SKGError SKGDocument::createUndoRedoTemporaryTriggers()
         QString table = tables[i];
 
         //Do we have to treat this table
-        if(!SKGListNotUndoable.contains("T." % table)) {
+        if(!SKGListNotUndoable.contains("T." % table) && !table.startsWith(QLatin1String("vm_"))) {
             //YES
             //Get attributes name
             QStringList attributes;
@@ -1839,6 +1973,8 @@ SKGError SKGDocument::getConsolidatedView(const QString& iTable,
             for(int c = 1; c < oTable[0].count() - 1; ++c) {  //Dynamic size
                 bool forecast = false;
                 QString title = oTable.at(0).at(c);
+                if(!title.isEmpty()) title = "0000";
+
                 if(title.endsWith(QLatin1String("999"))) {
                     title = title.left(title.count() - 3);
                     forecast = true;
@@ -2017,7 +2153,8 @@ QString SKGDocument::getTemporaryFile(const QString iFileName)
 {
     QString output;
     QFileInfo fi(iFileName);
-    if(!KUrl(iFileName).isLocalFile()) output = QDir::tempPath();
+    QFileInfo di(fi.dir().path());
+    if(!KUrl(iFileName).isLocalFile() || !di.permission(QFile::WriteUser)) output = QDir::tempPath();
     else output = fi.absolutePath();
     return output += "/." % fi.fileName() % ".wrk";
 }
@@ -2037,9 +2174,6 @@ QString SKGDocument::getBackupFile(const QString iFileName)
 SKGError SKGDocument::getObjects(const QString& iTable, const QString& iWhereClause, SKGObjectBase::SKGListSKGObjectBase& oListObject) const
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGDocument::getObjects", err);
-    SKGTRACEL(20) << "Input parameter [iTable]=[" << iTable << ']' << endl;
-    SKGTRACEL(20) << "Input parameter [iWhereClause]=[" << iWhereClause << ']' << endl;
 
     //Initialisation
     oListObject.clear();
@@ -2069,9 +2203,6 @@ SKGError SKGDocument::getObjects(const QString& iTable, const QString& iWhereCla
 SKGError SKGDocument::existObjects(const QString& iTable, const QString& iWhereClause, bool& oExist) const
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGDocument::existObjects", err);
-    SKGTRACEL(20) << "Input parameter [iTable]=[" << iTable << ']' << endl;
-    SKGTRACEL(20) << "Input parameter [iWhereClause]=[" << iWhereClause << ']' << endl;
 
     //Initialisation
     oExist = false;
@@ -2091,9 +2222,6 @@ SKGError SKGDocument::existObjects(const QString& iTable, const QString& iWhereC
 SKGError SKGDocument::getNbObjects(const QString& iTable, const QString& iWhereClause, int& oNbObjects) const
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGDocument::getNbObjects", err);
-    SKGTRACEL(20) << "Input parameter [iTable]=[" << iTable << ']' << endl;
-    SKGTRACEL(20) << "Input parameter [iWhereClause]=[" << iWhereClause << ']' << endl;
 
     //Initialisation
     oNbObjects = 0;
