@@ -48,15 +48,36 @@ class SKGBASEMODELER_EXPORT SKGDocument : public QObject
      * This enumerate defines a type of modification
      */
     Q_ENUMS(ModificationType);
+
     /**
      * This enumerate defines the direction of the UNDO / REDO mechanism
      */
     Q_ENUMS(UndoRedoMode);
+
     /**
      * This enumerate defines the mode of file
      */
     Q_ENUMS(DatabaseMode);
 
+    /**
+     * The unique identifier
+     */
+    Q_PROPERTY(QString uuid READ getUniqueIdentifier)
+
+    /**
+     * The current file name
+     */
+    Q_PROPERTY(QString fileName READ getCurrentFileName)
+
+    /**
+     * To know if the document is read only
+     */
+    Q_PROPERTY(bool readOnly READ isReadOnly)
+
+    /**
+     * To know if the document is modifier
+     */
+    Q_PROPERTY(bool modified READ isFileModified)
 public:
     /**
      * This enumerate defines a type of modification
@@ -152,10 +173,15 @@ public Q_SLOTS:
      * @param iNbStep the number of step in this transaction.
      * It's used to call the progress callback.
      * @param iDate date of the transaction.
+     * @param iRefreshViews at the end of the transaction, computed views will be recomputed.
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError beginTransaction(const QString & iName, int iNbStep = 0, const QDateTime& iDate = QDateTime::currentDateTime());
+    virtual SKGError beginTransaction(const QString & iName,
+                                      int iNbStep = 0,
+                                      const QDateTime& iDate = QDateTime::currentDateTime(),
+                                      bool iRefreshViews = true
+                                     );
 
     /**
      * Close the current transaction.
@@ -235,11 +261,12 @@ public Q_SLOTS:
      * @param oName if you want also the name of the transaction
      * @param oSaveStep if you want also to know if it's a save step
      * @param oDate if you want also the date of the transaction
+     * @param oRefreshViews if you want also to know if views must be refreshed
      * @return the internal identifier of the last transaction
      * 0 if no transaction found
      */
     virtual int getTransactionToProcess(const UndoRedoMode& iMode = SKGDocument::UNDO, QString* oName = NULL,
-                                        bool* oSaveStep = NULL, QDateTime* oDate = NULL) const;
+                                        bool* oSaveStep = NULL, QDateTime* oDate = NULL, bool* oRefreshViews = NULL) const;
 
     /**
      * Return the identifier of the current transaction
@@ -307,6 +334,13 @@ public Q_SLOTS:
      */
     virtual bool isFileModified() const;
 
+    /**
+     * To know if the document is loaded in read only.
+     * @return true: the document is loaded in read only.
+     *         false: the document is loaded in read write.
+     */
+    virtual bool isReadOnly() const;
+
     /**
      * Return the file name of the current document.
      * To set it, you must use saveAs.
@@ -684,7 +718,6 @@ public Q_SLOTS:
      */
     virtual SKGError getAttributesList(const QString& iTable, QStringList& oResult) const;
 
-
 Q_SIGNALS:
     /**
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
@@ -745,11 +778,19 @@ protected:
     QStringList SKGListNotUndoable;
 
     /**
-     * Get impacted tables if one object of @p iTable is modifier.
+     * Get impacted views if one object of @p iTable is modifier.
      * @param iTable name of a table
-     * @return impacted tables
+     * @return impacted views
      */
-    virtual QStringList getImpactedTables(const QString& iTable);
+    virtual QStringList getImpactedViews(const QString& iTable);
+
+    /**
+     * Compute all materialized views.
+     * @param iTable Compute only materialized views linked to this table. If empty then compute all materialized views
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError computeMaterializedViews(const QString &iTable = "");
 
 private:
     Q_DISABLE_COPY(SKGDocument);
@@ -774,13 +815,20 @@ private:
     QString m_uniqueIdentifier;
     QStringList m_unTransactionnalMessages;
     QMap<QString, QStringList> m_ImpactedViews;
+    QMap<QString, QStringList> m_MaterializedViews;
 
     QHash<QString, QString> m_cache;
     bool m_inProgress;
     QString m_backupPrefix;
     QString m_backupSuffix;
     bool m_directAccessDb;
+    bool m_modeReadOnly;
 };
+/**
+ * Declare the class
+ */
+Q_DECLARE_TYPEINFO(SKGDocument, Q_MOVABLE_TYPE);
+
 /**
  * Declare the class
  */
