@@ -92,6 +92,12 @@ public:
     */
     virtual bool operator!() const;
 
+    /**
+    * To know if this is an error or not. Equivalent to @see isFailed
+    * @return true or false
+    */
+    virtual operator bool() const;
+
 public slots:
     /**
     * To know if it's an error or not
