@@ -66,10 +66,10 @@ QString SKGNodeObject::getWhereclauseId() const
         if(!(getAttribute("t_name").isEmpty())) {
             output = "t_name='" % SKGServices::stringToSqlString(getAttribute("t_name")) % '\'';
         }
-        QString r_node_id = getAttribute("r_node_id");
+        QString rd_node_id = getAttribute("rd_node_id");
         if(!output.isEmpty()) output += " AND ";
-        if(r_node_id.isEmpty()) output += "(r_node_id=0 OR r_node_id IS NULL OR r_node_id='')";
-        else output += "r_node_id=" % r_node_id;
+        if(rd_node_id.isEmpty()) output += "(rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id='')";
+        else output += "rd_node_id=" % rd_node_id;
     }
     return output;
 }
@@ -209,14 +209,14 @@ SKGError SKGNodeObject::addNode(SKGNodeObject& oNode)
     if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message: Something failed because of a database issue", "%1 failed because linked object is not yet saved in the database.", QString("SKGNodeObject::addNode")));
     else {
         oNode = SKGNodeObject(getDocument());
-        err = oNode.setAttribute("r_node_id", SKGServices::intToString(getID()));
+        err = oNode.setAttribute("rd_node_id", SKGServices::intToString(getID()));
     }
     return err;
 }
 
 SKGError SKGNodeObject::removeParentNode()
 {
-    return setAttribute("r_node_id", "");
+    return setAttribute("rd_node_id", "");
 }
 
 SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
@@ -237,7 +237,7 @@ SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
             }
         } while(!err && current.getID() != 0);
 
-        if(!err) err = setAttribute("r_node_id", SKGServices::intToString(iNode.getID()));
+        if(!err) err = setAttribute("rd_node_id", SKGServices::intToString(iNode.getID()));
     }
     return err;
 }
@@ -245,14 +245,14 @@ SKGError SKGNodeObject::setParentNode(const SKGNodeObject& iNode)
 SKGError SKGNodeObject::getParentNode(SKGNodeObject& oNode) const
 {
     SKGError err;
-    QString parent_id = getAttribute("r_node_id");
+    QString parent_id = getAttribute("rd_node_id");
     if(!parent_id.isEmpty()) err = getDocument()->getObject("v_node", "id=" % parent_id , oNode);
     return err;
 }
 
 SKGError SKGNodeObject::getNodes(SKGListSKGObjectBase& oNodeList) const
 {
-    return getDocument()->getObjects("v_node", "r_node_id=" % SKGServices::intToString(getID()) % " ORDER BY f_sortorder, t_name", oNodeList);
+    return getDocument()->getObjects("v_node", "rd_node_id=" % SKGServices::intToString(getID()) % " ORDER BY f_sortorder, t_name", oNodeList);
 }
 
 #include "skgnodeobject.moc"
