@@ -370,7 +370,7 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
                 err = SKGError(ERR_ABORT, ""); //Just to go in UPDATE code
             }
 
-            if(!!err && iInsertOrUpdate) {
+            if(err && iInsertOrUpdate) {
                 //INSERT failed, could we try an update ?
                 QString wc = this->getWhereclauseId();
                 if(!wc.isEmpty()) {
@@ -440,27 +440,27 @@ SKGError SKGObjectBase::dump()
 
 QStringList SKGObjectBase::getProperties() const
 {
-    return getDocument()->getParameters(getUniqueID());
+    return !getDocument() ? QStringList() : getDocument()->getParameters(getUniqueID());
 }
 
 QString SKGObjectBase::getProperty(const QString& iName) const
 {
-    return getDocument()->getParameter(iName, getUniqueID());
+    return !getDocument() ? QString() : getDocument()->getParameter(iName, getUniqueID());
 }
 
 QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
 {
-    return getDocument()->getParameterBlob(iName, getUniqueID());
+    return !getDocument() ? QVariant() : getDocument()->getParameterBlob(iName, getUniqueID());
 }
 
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated) const
 {
-    return getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
+    return !getDocument() ? SKGError() : getDocument()->setParameter(iName, iValue, iFileName, getUniqueID(), oObjectCreated);
 }
 
 SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGPropertyObject* oObjectCreated) const
 {
-    return getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
+    return!getDocument() ? SKGError() :  getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
 
 }
 
