@@ -304,8 +304,18 @@ protected:
 private:
     SKGObjectBasePrivate* const d;
 };
+/**
+ * Declare the meta type
+ */
+Q_DECLARE_METATYPE(SKGObjectBase);
+
 /**
  * Declare the class
  */
 Q_DECLARE_TYPEINFO(SKGObjectBase, Q_MOVABLE_TYPE);
+
+/**
+ * Declare the meta type
+ */
+Q_DECLARE_METATYPE(QList<SKGObjectBase>);
 #endif
