@@ -209,12 +209,16 @@ QString SKGServices::doubleToString(double iNumber)
 
 QString SKGServices::timeToString(const QDateTime& iDateTime)
 {
-    return iDateTime.toString("yyyy-MM-dd HH:mm:ss");
+    QDateTime d = iDateTime;
+    if(!d.isValid()) d = QDateTime::currentDateTime();
+    return d.toString("yyyy-MM-dd HH:mm:ss");
 }
 
 QString SKGServices::dateToSqlString(const QDateTime& iDateTime)
 {
-    return iDateTime.toString("yyyy-MM-dd");
+    QDateTime d = iDateTime;
+    if(!d.isValid()) d = QDateTime::currentDateTime();
+    return d.toString("yyyy-MM-dd");
 }
 
 int SKGServices::nbWorkingDays(const QDate& iFrom, const QDate& iTo)
@@ -281,6 +285,8 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
 
     if(oRealSeparator) *oRealSeparator = realSeparator;
 
+    if(isInBlock) items.clear();
+
     return items;
 }
 
@@ -305,6 +311,7 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
 
         QString val = iDates.at(i);
         val = val.replace('/', '-');
+        val = val.replace('\\', '-');
         val = val.replace("'20", "-20");
         val = val.replace("' ", "-200");
         val = val.replace('\'', "-20");
@@ -394,8 +401,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     }
 
     if(f_YYYYMMDD) return "YYYYMMDD";
-    else if(f_DDMMYYYY) return "DDMMYYYY";
     else if(f_MMDDYYYY) return "MMDDYYYY";
+    else if(f_DDMMYYYY) return "DDMMYYYY";
     else if(f_DD_MM_YY && f_MM_DD_YY) {
         KLocale* locale = KGlobal::locale();
         if(locale) {
@@ -403,8 +410,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
             if(sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YY";
         }
         return "DD-MM-YY";
-    } else if(f_DD_MM_YY) return "DD-MM-YY";
-    else if(f_MM_DD_YY) return "MM-DD-YY";
+    } else if(f_MM_DD_YY) return "MM-DD-YY";
+    else if(f_DD_MM_YY) return "DD-MM-YY";
     else if(f_DD_MM_YYYY && f_MM_DD_YYYY) {
         KLocale* locale = KGlobal::locale();
         if(locale) {
@@ -412,8 +419,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
             if(sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YYYY";
         }
         return "DD-MM-YYYY";
-    } else if(f_DD_MM_YYYY) return "DD-MM-YYYY";
-    else if(f_MM_DD_YYYY) return "MM-DD-YYYY";
+    } else if(f_MM_DD_YYYY) return "MM-DD-YYYY";
+    else if(f_DD_MM_YYYY) return "DD-MM-YYYY";
     else if(f_YYYY_MM_DD) return "YYYY-MM-DD";
 
     return "";
@@ -445,6 +452,7 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
 
     } else {
         QString val = iDate;
+        val = val.replace('\\', '-');
         val = val.replace('/', '-');
         val = val.replace("'20", "-20");
         val = val.replace("' ", "-200");
@@ -754,7 +762,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-DETACH", err);
             SKGError err2 = SKGServices::executeSqliteOrder(iMemoryDb, "DETACH DATABASE source");
-            if(!err && !!err2) err = err2;
+            if(!err && err2) err = err2;
         }
 
         //Optimization
@@ -823,7 +831,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             err.setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
         }
     }
-    if(!!err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("copySqliteDatabase::copySqliteDatabase()")));
+    if(err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("copySqliteDatabase::copySqliteDatabase()")));
     return err;
 }
 
@@ -1008,9 +1016,9 @@ double SKGServices::getMicroTime()
 #endif
 }
 
-SKGStringListList SKGServices::getPourcentTable(const SKGStringListList& iTable)
+SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable)
 {
-    SKGTRACEIN(10, "SKGServices::getPourcentTable");
+    SKGTRACEIN(10, "SKGServices::getPercentTable");
 
     //Build history
     SKGStringListList output;
