@@ -172,7 +172,7 @@ public:
 
     /**
      * Get list of search criteria of a string (exxample: +cat1 -abc +auto)
-     * @param iString a string to analyse
+     * @param iString a string to analyze
      * @return the search criteria list
      */
     static QList<SKGSearchCriteria> stringToSearchCriterias(const QString& iString);
@@ -304,7 +304,7 @@ public:
      * @param iSeparator the csv separator
      * @param iCoteDefineBlock to indicate if the character double cote define a block
      * @param oRealSeparator the real csv separator. If the csv string is strictly all enclosed then oRealSeparator will contain the real separator
-     * @return the list of all values in this csv line
+     * @return the list of all values in this csv line. Return an empty list if some cote are opened and not closed
      */
     static QStringList splitCSVLine(const QString& iString, const QChar& iSeparator = ';', bool iCoteDefineBlock = true, QChar* oRealSeparator = NULL);
 
@@ -436,7 +436,7 @@ public:
      * Create a table with all values expressed in % of the column
      * @param iTable table
      */
-    static SKGStringListList getPourcentTable(const SKGStringListList& iTable);
+    static SKGStringListList getPercentTable(const SKGStringListList& iTable);
 
     /**
      * Create an historized table.
